<?php
/**
 * The template for displaying Comments
 *
 * The area of the page that contains comments and the comment form.
 *
 * @since Yaga 1.0
 */

/*
 * If the current post is protected by a password and the visitor has not yet
 * entered the password we will return early without loading the comments.
 */
if ( post_password_required() )
	return;
?>

<?php if ( !( comments_open() || have_comments() ) ) return;

$display_mode = get_theme_mod( 'yaga_comments_display', 'toggle_closed' );
$avatars_mode = get_theme_mod( 'yaga_avatar_display', 'visible_circle' );
$title_string = get_theme_mod( 'yaga_comments_area_title', esc_html__( 'Discussion', 'yaga' ) );

if ( 'show' === $display_mode ) {
	$header_class = $data_to_toggle = $data_toggle_container = $comments_class = '';
	$container_class = 'comments-opened';
} else {
	$header_class = 'pointer js-toggle-trigger bg-expand-compress-block__trigger pht-transition';
	$data_to_toggle = '#js-toggle-comments';
	$data_toggle_container = '#comments';
	$container_class = 'bg-expand-compress-block pht-box pht-box--highlight';
	if ( 'toggle_closed' === $display_mode ) {
		$comments_class = ' js-toggle--hidden';
	} else {
		$comments_class = '';
		$container_class .= ' js-opened';
	}
} ?>

<section id="comments" class="comments-area <?php echo esc_attr( $container_class ); ?> pht-mb pht-mt pht-zeta">
	<header class="parent comments-header <?php echo esc_attr( $header_class ); ?>" data-to-toggle="<?php echo esc_attr( $data_to_toggle );?>" data-toggle-container="<?php echo esc_attr( $data_toggle_container );?>">
		<h2 class="pht-heading pointer pht-mb0"><?php echo esc_html( $title_string ); ?></h2>
		<h3 class="pht-subtitle pht-subheading pht-mb0 pointer">
		<?php if ( have_comments() ) {
			printf( esc_html__( 'Comments (%1$s)', 'yaga' ), get_comments_number() );
		} else {
			echo get_theme_mod( 'yaga_comments_area_subtitle', esc_html__( 'Leave a reply', 'yaga' ) );
		} ?>
		</h3>
		<?php if ( $data_to_toggle ) { ?>
			<span class="pht-delta toggle__icon--expand pht-ic-f1-arrow-expand"></span><span class="pht-delta toggle__icon--contract pht-ic-f1-arrow-condense"></span>
		<?php } ?>
	</header>

	<div id="js-toggle-comments" class="<?php echo esc_attr( $comments_class );?>">

		<?php if ( have_comments() ) {

			$args = array(
				'style'       => 'ol',
				'short_ping'  => true,
				'avatar_size' => 'hidden' === $avatars_mode ? 0 : '96'
			);

			if ( class_exists( 'Yaga_Walker_Comment' ) ) $args['walker'] = new Yaga_Walker_Comment(); ?>

			<ol class="comment-list pht-mt">
				<?php wp_list_comments( $args ); ?>
			</ol><!-- .comment-list -->

			<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) { ?>
			<nav class="navigation comment-navigation">
				<h1 class="screen-reader-text section-heading"><?php esc_html_e( 'Comment navigation', 'yaga' ); ?></h1>
				<div class="nav-previous">
					<?php previous_comments_link( '<i class="pht-ic-f1-arrow-left"></i> ' . esc_html__( 'Older Comments', 'yaga' ) ); ?>
				</div>
				<div class="nav-next">
					<?php next_comments_link( esc_html__( 'Newer Comments', 'yaga' ) . ' <i class="pht-ic-f1-arrow-left"></i>' ); ?>
				</div>
			</nav><!-- .comment-navigation -->
			<?php } // Check for comment navigation 

			if ( ! comments_open() && get_comments_number() ) { ?>
				<p class="comments-closed"><?php esc_html_e( 'Comments are closed.' , 'yaga' ); ?></p>
			<?php }
		} // have_comments() 

		$comment_form_args = array();
		$comment_form_args['title_reply'] = have_comments() ? esc_html( get_theme_mod( 'yaga_comments_area_subtitle', esc_html__( 'Leave a reply', 'yaga' ) ) ) : '';
		$notes_before = get_theme_mod( 'yaga_comment_notes_before', '' );
		if ( $notes_before ) {
			$comment_form_args['comment_notes_before'] = '<p class="comment-notes">' . esc_html( $notes_before ) . '</p>';
		}
		$comment_form_args['comment_field'] = '<p class="comment-form-comment"><textarea id="comment" name="comment" cols="45" rows="8" required="required"></textarea></p>';
		comment_form( $comment_form_args ); ?>
	</div><!--#js-toggle-comments -->

</section><!-- #comments -->