<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists ( 'Yaga_Customizer' ) ) {

class Yaga_Customizer {

	private static $instance = null;

	private $fields = array();

	private $plugin_screen_hook_suffix = array( '' );

	private $template_name;

	private function __construct() {

		$weights = array(
			'100' => '100',
			'200' => '200',
			'300' => '300',
			'400' => '400',
			'500' => '500',
			'600' => '600',
			'700' => '700',
			'800' => '800',
			'900' => '900',
		);
 
		$this->fields = array(
			'yaga_logo_title_tagline' => array(
				'section' => array(
					'title' => esc_html__( 'Logo, Title and Tagline', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_hide_title' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Hide Site Title', 'yaga' ),
							'type' => 'checkbox',
							'description' =>  esc_html__( 'If checked the site title will not be displayed in the site header area.', 'yaga' ),
						),
					),
					'yaga_hide_tagline' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Hide Site Tagline', 'yaga' ),
							'type' => 'checkbox',
							'description' =>  esc_html__( 'If checked the site tagline will not be displayed in the site header area.', 'yaga' ),
						),
					),
					'yaga_logo' => array(
						'setting_array' => array(
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_image',
						),
						'control_array' => array(
							'type' => 'image',
							'label' =>  esc_html__( 'Logo (Standard)', 'yaga' ),
							'description' => sprintf( esc_html__( 'Upload your logo.  The default display height is %s px. We recommend to create it two times bigger (%s) than you want it to be displayed (for retina screens).', 'yaga'), PeHaaThemes_Theme_Config::$logo_height, 2*PeHaaThemes_Theme_Config::$logo_height ),
						),
					),
					'yaga_logo_alt' => array(
						'setting_array' => array(
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_image',
						),
						'control_array' => array(
							'type' => 'image',
							'label' =>  esc_html__( 'Logo (Alternative)', 'yaga' ),
							'description' => sprintf( esc_html__( 'Upload an alternative version of your logo. Your image should have the same dimensions as the standard logo.', 'yaga'), PeHaaThemes_Theme_Config::$logo_height, 2*PeHaaThemes_Theme_Config::$logo_height ),
						),
					),
					'yaga_logo_height' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$logo_height,
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_text_with_int'
						),
						'control_array' => array(
							'type' => 'text',
							'label' => esc_html__( 'Logo display height', 'yaga' ),
							'description' =>  esc_html__( 'Type your logo display height here (your logo should be twice as high for a crispy look on retina screens).', 'yaga'),
						),
					),
					'yaga_mini_logo' => array(
						'setting_array' => array(
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_image',
						),
						'control_array' => array(
							'type' => 'image',
							'label' => esc_html__( 'Mini Logo', 'yaga' ),
							'description' => sprintf( __( 'Upload your reduced logo version, the default height is %s px. It will be used <strong>only</strong> if you choose the Sticky or Fixed Bar navigation option (see the "Border & Navigation" panel).', 'yaga' ), 2*PeHaaThemes_Theme_Config::$mini_logo_height ),
						),
					),
				)
			),
			'yaga_misc' => array(
				'section' => array(
					'title' => esc_html__( 'Border & Navigation', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_ml' => array(
						'setting_array' => array(
							'default' => 'normal'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Pages Border', 'yaga' ),
							'type' => 'select',
							'choices' => array(
								'normal' => esc_html__( 'Default, 32px on large screens.', 'yaga' ),
								'tiny' => esc_html__( 'Tiny, 12px.', 'yaga' ),
								'no' => esc_html__( 'None.', 'yaga' ),
							),
							'description' =>  esc_html__( 'You can set the width of the pages border here.', 'yaga' ),
						),
					),
					'yaga_navigation' => array(
						'setting_array' => array(
							'default' => 'default'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Type of Navigation', 'yaga' ),
							'type' => 'select',
							'choices' => array(
								'default' => esc_html__( 'Default', 'yaga' ),
								'sticky_full' => esc_html__( 'Sticky, full', 'yaga' ),
								'sticky_center' => esc_html__( 'Sticky, center', 'yaga' ),
								'top_fixed_fixed' => esc_html__( 'Fixed Bar, no scrolling effect', 'yaga' ),
								'top_fixed_center' => esc_html__( 'Fixed Bar with centered navigation', 'yaga' )
							),
							'description' =>  esc_html__( 'Choose the type of navigation. "Sticky, full" will display the navigation aligned to the right and logo in the left corner.', 'yaga' ),
						),
					),
					'yaga_search_in_nav' => array(
						'setting_array' => array(
							'default' => '1'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Search in the Site Header', 'yaga' ),
							'description' => esc_html__( 'Add search to the main navigation menu.', 'yaga' ),
							'type' => 'checkbox',
						),
					),
				)
			),
			'yaga_preloader' => array(
				'section' => array(
					'title' => esc_html__( 'Preloader', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_preloader_in' => array(
						'setting_array' => array(
							'default' => 'on_check_and_archives'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Default Behavior', 'yaga' ),
							'type' => 'select',
							'description' =>  esc_html__( 'Choose on which pages you want to use a preloader.', 'yaga' ),
							'choices' => array(
								'on_check_and_archives' => esc_html__( 'Archive pages and Check-in/out for custom pages and posts.', 'yaga' ),
								'on_check' => esc_html__( 'Check-in/out for custom pages and posts.', 'yaga' ),
								'always' => esc_html__( 'Always', 'yaga' ),
								'never' => esc_html__( 'Never', 'yaga' ),
							),
						),
					),
				)
			),	
			'yaga_footer_and_scripts' => array(
				'section' => array(
					'title' => esc_html__( 'Custom Scripts and Footer', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_header_script' => array(
						'setting_array' => array(
							'transport' => 'postMessage',
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_texarea_with_scripts'
						),
						'control_array' => array(
							'label' => esc_html__( 'Header Tracking Code', 'yaga' ),
							'description' => esc_html__( 'Paste your header-destined tracking code here (e.g. Google Analytics).', 'yaga' ),
							'type' => 'textarea',
						)
					),
					'yaga_footer_script' => array(
						'setting_array' => array(
							'transport' => 'postMessage',
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_texarea_with_scripts'
						),
						'control_array' => array(
							'label' => esc_html__( 'Footer Tracking Code', 'yaga'),
							'description' => esc_html__( 'Paste your footer-destined tracking code here.', 'yaga' ),
							'type' => 'textarea',
						)
					),
					'yaga_footer_copy' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' => esc_html__( 'Custom copyright text (left)', 'yaga'),
							'description' => esc_html__( 'You can modify the text displayed in the left footer copyright area.', 'yaga' ),
							'type' => 'textarea',
						),
					),
					'yaga_footer_copy_right' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' => esc_html__( 'Custom copyright text (right)', 'yaga'),
							'description' => esc_html__( 'You can modify the text displayed in the right footer copyright area.', 'yaga' ),
							'type' => 'textarea',
						),
					),
					'yaga_fixed_footer' => array(
						'setting_array' => array(
							'default' => '1'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Fixed footer', 'yaga' ),
							'description' => esc_html__( 'Enable fixed (parallax) footer behavior applied on wide screens over 1280px.', 'yaga' ),
							'type' => 'checkbox',
						),
					),
				)
			),
			'yaga_login' => array(
				'section' => array(
					'title' => esc_html__( 'Dashboard Login', 'yaga' ),
					'panel' => 'yaga',
					'description' => sprintf( wp_kses( __( 'These settings concern the login screen and cannot be previewed within this customizer screen. To see the changes you need to Save and Publish first, then go to the <a href="%s" target="_blank">login screen.</a>', 'yaga' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( wp_login_url() ) )
				),
				'settings' => array(
					'yaga_login_logo' => array(
						'setting_array' => array(
							'transport' => 'postMessage',
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_image',
						),
						'control_array' => array(
							'type' => 'image',
							'label' =>  esc_html__( 'Login Logo', 'yaga' ),
							'description' => sprintf( esc_html__( 'Upload your logo, the default height is %s px', 'yaga'), 2*84 ),
						),
					),
				),
			),
			'yaga_sidebar' => array(
				'section' => array(
					'title' => esc_html__( 'Sidebar', 'yaga' ),
					'description' => esc_html__( 'The sidebar widgets are only displayed if there are widgets associated with the Sidebar Widgets Area.', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_sidebar_position' => array(
						'setting_array' => array(
							'default' => 'right',
						),
						'control_array' => array(
							'label' => esc_html__( 'Sidebar position', 'yaga' ),
							'description' => esc_html__( 'Choose the sidebar position.', 'yaga' ),
							'type' => 'radio',
							'choices' => array(
								'left' => esc_html__( 'Left', 'yaga' ),	
								'right' => esc_html__( 'Right', 'yaga' ),	
							),
						)
					),
					'yaga_blog_sidebar' => array(
						'setting_array' => array(
							'default' => '1'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Sidebar on blog page', 'yaga' ),
							'description' => esc_html__( 'Choose your blog layout.', 'yaga' ),
							'type' => 'checkbox',
							'active_callback' => array( $this, 'front_and_home' ),
						),
					),	
				)
			),
			'yaga_blog' => array(
				'section' => array(
					'title' => esc_html__( 'Blog', 'yaga' ),
					'description' => esc_html__( 'Customize the way the blog pages (index, categories) are displayed', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_pagination' => array(
						'setting_array' => array(
							'default' => 'standard',
						),
						'control_array' => array(
							'label' =>  esc_html__('Pagination', 'yaga'),
							'description' => esc_html__('Choose your pagination option.', 'yaga'),
							'type' => 'radio',
							'choices' => array(
								'standard' => esc_html__('Standard Pagination', 'yaga'),
								'loadmore' => esc_html__('Load More Button', 'yaga')
							)
						)
					),
					'yaga_blog_option' => array(
						'setting_array' => array(
								'default' => 'grid',
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Blog Layout', 'yaga' ),
							'description' => esc_html__( 'Choose your blog layout.', 'yaga' ),
							'type' => 'radio',
							'choices' => array(
								'grid' => esc_html__('Grid View', 'yaga' ),	
								'classic' => esc_html__('One Column View', 'yaga' ),	
							),
							//'active_callback' => 'is_home',
						)
					),
					'yaga_truncate_title' => array(
						'setting_array' => array(
							'default' => ''
						),
						'control_array' => array(
							'label' => esc_html__( 'Truncate title', 'yaga' ),
							'description' => esc_html__( 'Truncate the post title (...) so that it does not take more than one line.', 'yaga' ),
							'type' => 'checkbox'
						)
					),
					'yaga_top_meta' => array(
						'setting_array' => array(
							'default' => 'date',
						),
						'control_array' => array(
							'label' => esc_html__( 'Above the post title', 'yaga' ),
							'description' => esc_html__( 'Choose what to display above the post title', 'yaga' ),
							'type' => 'radio',
							'choices' => array(
								'date' => esc_html__( 'Date', 'yaga' ),
								'categories' => esc_html__( 'Category', 'yaga' ),
								'author' => esc_html__( 'Author', 'yaga' ),
								'empty' => esc_html__( 'Empty', 'yaga' )
							)
						)
					),
					'yaga_date_in_bottom_meta' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$entry_bottom_meta['date']
						),
						'control_array' => array(
							'label' => esc_html__( 'Date', 'yaga' ),
							'description' => esc_html__( 'Display date in bottom meta area', 'yaga' ),
							'type' => 'checkbox'
						)
					),
					'yaga_author_in_bottom_meta' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$entry_bottom_meta['author']
						),
						'control_array' => array(
							'label' => esc_html__( 'Author', 'yaga' ),
							'description' => esc_html__( 'Display author in bottom meta area', 'yaga' ),
							'type' => 'checkbox'
						)
					),
					'yaga_categories_in_bottom_meta' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$entry_bottom_meta['categories']
						),
						'control_array' => array(
							'label' => esc_html__( 'Categories', 'yaga' ),
							'description' => esc_html__( 'Display categories in bottom meta area', 'yaga' ),
							'type' => 'checkbox'
						)
					),
					'yaga_comments_in_bottom_meta' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$entry_bottom_meta['comments']
						),
						'control_array' => array(
							'label' => esc_html__( 'Comments', 'yaga' ),
							'description' => esc_html__( 'Display comments link in bottom meta area', 'yaga' ),
							'type' => 'checkbox'
						)
					),
				)
			),
			'yaga_comments' => array(
				'section' => array(
					'title' => esc_html__( 'Comments', 'yaga' ),
					'description' => esc_html__( 'Customize the way the comments are displayed', 'yaga' ),
					'active_callback' => array( $this, 'should_comments_display' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_comments_display' => array(
						'setting_array' => array(
							'default' => 'toggle_closed',
							),
						'control_array' => array(
							'label' => esc_html__( 'Comments display', 'yaga' ),
							'type' => 'radio',
							'choices' => array(
								'show' => esc_html__( 'Always show', 'yaga' ),	
								'toggle_closed' => esc_html__( 'Toggle (closed on page load)', 'yaga' ),	
								'toggle_opened' => esc_html__( 'Toggle (opened on page load)', 'yaga' ),	
							),
						),
					),
					'yaga_comments_area_title' => array(
						'setting_array' => array(
							'default' => esc_html__( 'Discussion', 'yaga' )
							),
						'control_array' => array(
							'label' => esc_html__( 'Comments area title', 'yaga' ),
							'type' => 'text'	
						)
					),
					'yaga_comments_area_subtitle' => array(
						'setting_array' => array(
							'default' => esc_html__( 'Leave a reply', 'yaga' )
							),
						'control_array' => array(
							'label' => esc_html__( 'Comments area subtitle', 'yaga' ),
							'type' => 'text'	
						)
					),
					'yaga_avatar_display' => array(
						'setting_array' => array(
							'default' => 'visible_round',
							),
						'control_array' => array(
							'label' => esc_html__( 'Avatars display', 'yaga' ),
							'type' => 'radio',
							'choices' => array(
								'visible_round' => esc_html__( 'Visible, circle', 'yaga' ),	
								'visible_square' => esc_html__('Visible, square', 'yaga' ),	
								'hidden' => esc_html__( 'Not displayed', 'yaga' ),	
							)
						),
					),
					'yaga_comment_notes_before' => array(
						'setting_array' => array(
							'default' => esc_html__( 'Your email address will not be published. Required fields are marked *', 'yaga' )
							),
						'control_array' => array(
							'label' => esc_html__( 'Note before form', 'yaga' ),
							'type' => 'textarea',	
						)
					),
				),
			),
			'yaga_fonts' => array(
				'section' => array(
					'title' => esc_html__( 'Fonts', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_body_font_face' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$body_font
						),
						'control_array' => array(
							'label' => esc_html__( 'Body Font', 'yaga' ),
							'description'  => sprintf ( wp_kses( __( 'Quickly add a custom Google Font for body from <a href="%s" target="_blank">Google Font Directory.</a> Make sure that the italic, bold and bold italic styles exist. Set the normal and bold weights in the fields below.', 'yaga' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( 'www.google.com/webfonts/' ) ),
							'type' => 'text'
						)
					),
					'yaga_body_font_family' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$body_font_family,
						),
						'control_array' => array(
							'label' => esc_html__('Body Font Family', 'yaga'),
							'description' => esc_html__('Generic font family for font subsitution.', 'yaga'),
							'type' => 'select',
							'choices' => array(
								'serif' => esc_html__( 'Serif', 'yaga' ),
								'sans-serif' => esc_html__( 'Sans Serif', 'yaga' ),
								'monospace' => esc_html__( 'Monospace', 'yaga' ),
								'cursive' => esc_html__( 'Cursive', 'yaga' ),
								'fantasy' => esc_html__( 'Fantasy', 'yaga' )
							)

						)
					),
					'yaga_body_normal_font_face_weight' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$body_normal_weight,
						),
						'control_array' => array(
							'label' => esc_html__( 'Base body font-face weight', 'yaga' ),
							'type' => 'select',
							'choices' => $weights,
						)
					),
					'yaga_body_bold_font_face_weight' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$body_bold_weight,
						),
						'control_array' => array(
							'label' => esc_html__( 'Bold body font-face weight', 'yaga' ),
							'type' => 'select',
							'choices' => $weights,
						)
					),
					'yaga_headings_font_face' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$headings_font
						),
						'control_array' => array(
							'label' => esc_html__( 'Headings Font', 'yaga' ),
							'type' => 'text'
						)
					),
					'yaga_headings_font_family' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$headings_font_family,
						),
						'control_array' => array(
							'label' => esc_html__( 'Headings Font Family', 'yaga' ),
							'description' => esc_html__( 'Generic font family for font subsitution.', 'yaga' ),
							'type' => 'select',
							'choices' => array(
								'serif' => esc_html__( 'Serif', 'yaga' ),
								'sans-serif' => esc_html__( 'Sans Serif', 'yaga' ),
								'monospace' => esc_html__( 'Monospace', 'yaga' ),
								'cursive' => esc_html__( 'Cursive', 'yaga' ),
								'fantasy' => esc_html__( 'Fantasy', 'yaga' )
							)

						)
					),
					'yaga_headings_font_face_weight' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$headings_weight,
						),
						'control_array' => array(
							'label' => esc_html__( 'Base body font-face weight', 'yaga' ),
							'type' => 'select',
							'choices' => $weights,
						)
					),
					'yaga_caps' => array(
						'setting_array' => array(
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Caps', 'yaga' ),
							'description' => esc_html__( 'Check here to capitalize all headings.', 'yaga' ),
							'type' => 'checkbox',
						)
					),
					'yaga_headings_in_navbar' => array(
						'setting_array' => array(
							'default' => 'sans-serif' === PeHaaThemes_Theme_Config::$headings_font_family ? '1' : '',
						),
						'control_array' => array(
							'label' => esc_html__( 'Navigation and Buttons', 'yaga' ),
							'description' => esc_html__( 'Check here to use the headings font family for the navigation and buttons.', 'yaga' ),
							'type' => 'checkbox',
						)
					)
				)
			),
			'colors' => array(
				'section' => array(
					'title' => esc_html__( 'Colors', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_link_color' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$link_color,
							'sanitize_callback'    => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Link', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom link color', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_link_color_1' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$link_color_1,
							'sanitize_callback'    => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Link on Hover', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom color for link hover', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_html_bg' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$html_bg,
							'sanitize_callback'    => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Body Background', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom body background color', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_text_color' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$color,
							'sanitize_callback'    => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Body Text', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom body text color', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_main_nav_drop_bg' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$main_nav_drop_bg,
							'sanitize_callback' => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Menu Drop-downs Background', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom background color for the menu drop-downs.', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_main_nav_drop_color' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$color,
							'sanitize_callback' => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Menu Drop-downs Text', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom text color for the menu drop-downs.', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_footer_bg' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$footer_bg,
							'sanitize_callback' => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Footer Background', 'yaga'),
							//'description'  => esc_html__( 'Choose a custom background color for the footer.', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_footer_color' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$footer_color,
							'sanitize_callback' => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Footer Text', 'yaga'),
							'type' => 'color'
						)
					),
					'yaga_footer_copy_bg' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$footer_copy_bg,
							'sanitize_callback' => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Footer Copyright Background', 'yaga'),
							'type' => 'color'
						)
					),
					'yaga_footer_copy_color' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$footer_color,
							'sanitize_callback' => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Footer Copyright Text', 'yaga'),
							'type' => 'color'
						)
					),
					'yaga_box_bg' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$box_bg,
							'sanitize_callback'    => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Boxes Background', 'yaga'),
							'description'  => esc_html__( 'Sidebar widgets, post content in index view, ...', 'yaga' ),
							'type' => 'color'
						)
					),
					'yaga_border_bg' => array(
						'setting_array' => array(
							'default' => PeHaaThemes_Theme_Config::$box_bg,
							'sanitize_callback'    => 'sanitize_hex_color',
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Site Border Color', 'yaga'),
							'type' => 'color'
						)
					),
				),
			),
			'yaga_css' => array(
				'section' => array(
					'title' => esc_html__( 'Custom css', 'yaga' ),
					'panel' => 'yaga'
				),
				'settings' => array(
					'yaga_custom_css' => array(
						'setting_array' => array(
							'transport' => 'postMessage'
						),
						'control_array' => array(
							'label' => esc_html__( 'Custom css', 'yaga' ),
							'description'  => esc_html__( 'Add custom styles, e.g. body {color:magenta}', 'yaga' ),
							'type' => 'textarea'
						)
					)
				)
			),
		);

		$this->template_name = 'yaga_customizer_css';

		add_action( 'customize_register', array( $this, 'custom_customize_register'), 11 );
		add_action( 'customize_preview_init', array( $this, 'preview_enqueue_scripts' ) );
		add_action( 'customize_controls_print_footer_scripts', array( $this, 'customizer_css_template' ) );
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'controls_enqueue_scripts' ) );
		add_action( 'customize_controls_print_styles', array( $this, 'enqueue_customizer_stylesheet' ) );

		add_action( 'wp_enqueue_scripts', array( $this, 'custom_styles' ), 11 );

	}

	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;

	}

	public function controls_enqueue_scripts() {
		wp_enqueue_script( 'yaga-color-controls', get_template_directory_uri() . '/js/min.yaga-color-controls.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), PeHaaThemes_Theme_Start::$theme_version, true );
		$settings = array(
			'yaga_text_color',
			'yaga_html_bg',
			'yaga_main_nav_drop_bg',
			'yaga_main_nav_drop_color',
			'yaga_footer_bg',
			'yaga_footer_color',
			'yaga_footer_copy_bg',
			'yaga_footer_copy_color',
			'yaga_box_bg',
			'yaga_border_bg',
			'yaga_link_color',
			'yaga_link_color_1',
			'yaga_caps',
			'yaga_custom_css'
		);
		wp_localize_script( 'yaga-color-controls', 'yaga_Settings', array( 'settings' => $settings, 'template' => $this->template_name ) );
	}

	/**
	 * Register the js.
	 *
	 * @since    1.0.0
	 */
	public function preview_enqueue_scripts() {

		wp_enqueue_script( 'yaga-customize-preview', get_template_directory_uri() . '/js/min.yaga-customizer.js', array( 'customize-preview' ), PeHaaThemes_Theme_Start::$theme_version, true );
		
	}

	public function enqueue_customizer_stylesheet() {
		wp_enqueue_style( 'yaga-customize-css', get_template_directory_uri() . '/css/customizer.css', array(), PeHaaThemes_Theme_Start::$theme_version );
	}

	public function custom_customize_register( $wp_customize ) {

		$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

		$wp_customize->add_panel( 'yaga', array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => sprintf( esc_html__( '%s Settings', 'yaga'), PeHaaThemes_Theme_Start::$theme_name ),
			'description'    => esc_html__( 'This theme specific settings', 'yaga' )
		) );

		self::fields_from_array( $wp_customize, $this->fields );

	}

	public static function fields_from_array( $wp_customize, $fields ) {

		foreach( $fields as $section => $section_fields ) {

			if ( ! isset(  $section_fields['section'] ) ) continue;
			$wp_customize->add_section(
				$section,
				$section_fields['section']
			);

			foreach ( $section_fields['settings'] as $setting => $setting_fields ) {

				if ( !isset(  $setting_fields['setting_array'] ) || !isset(  $setting_fields['control_array'] ) ) continue;

				$settings_array = $setting_fields['setting_array'];

				if ( ! isset( $settings_array['sanitize_callback'] ) ) {
					if ( method_exists( 'PeHaaThemes_Sanitization', 'sanitize_' . $setting_fields['control_array']['type'] ) ) {
						$settings_array['sanitize_callback'] = 'PeHaaThemes_Sanitization::sanitize_' . $setting_fields['control_array']['type'];
					} else {
						$settings_array['sanitize_callback'] = 'PeHaaThemes_Sanitization::sanitize_text';
					}

				}

				$wp_customize_method = 'add_setting';
				
				$wp_customize->$wp_customize_method(
					$setting,
					$settings_array
				);

				$control_array = $setting_fields['control_array'];
				$control_array['section'] = $section;

				if ( 'color' === $setting_fields['control_array']['type'] ) {

					$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $setting, $control_array ) );

				} elseif ( 'image' === $setting_fields['control_array']['type'] ) {

					$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $setting, $control_array ) );

				} elseif ( 'media' === $setting_fields['control_array']['type'] ) {

					unset($control_array['type']);

					$wp_customize->add_control( new WP_Customize_Media_Control( $wp_customize, $setting, $control_array ) );

				} else {
					$wp_customize->add_control(
						$setting,
						$control_array
					);
				}
				
			}

		}


	}

	/**
		 * Check if viewing one of this plugin's admin pages.
		 *
		 * @since   1.0.0
		 *
		 * @return  bool
		 */
	private function viewing_this_plugin() {		
			
		if ( ! isset( $this->plugin_screen_hook_suffix ) ) {
			return false;
		}

		$screen = get_current_screen();

		if ( in_array( $screen->id, $this->plugin_screen_hook_suffix ) ) {
			return true;
		} else {
			return false;
		}
			
	}

	public function should_comments_display() {
		return is_single() && ( comments_open() || get_comments_number() );
	}

	public function front_and_home() {
		return is_home() && is_front_page();
	}

	/**
	 * Output an Underscore template for generating CSS from the customizer settings
	 *
	 * The template generates the css dynamically for instant display in the Customizer
	 * preview.
	 *
	 * @since 1.0
	 */
	public function customizer_css_template() {


		$settings = array(
			'yaga_text_color'  => '{{ data.yaga_text_color }}',
			'yaga_html_bg'            => '{{ data.yaga_html_bg }}',
			'yaga_main_nav_drop_bg' => '{{ data.yaga_main_nav_drop_bg }}',
			'yaga_main_nav_drop_color' => '{{ data.yaga_main_nav_drop_color }}',
			'yaga_footer_bg'=> '{{ data.yaga_footer_bg }}',
			'yaga_footer_color'=> '{{ data.yaga_footer_color }}',
			'yaga_footer_copy_bg' => '{{ data.yaga_footer_copy_bg }}',
			'yaga_footer_copy_color' => '{{ data.yaga_footer_copy_color }}',
			'yaga_box_bg' => '{{ data.yaga_box_bg }}',
			'yaga_border_bg' => '{{ data.yaga_border_bg }}',
			'yaga_link_color' => '{{ data.yaga_link_color }}',
			'yaga_link_color_1' => '{{ data.yaga_link_color_1 }}',
			'yaga_link_color_1r' => '{{ (parseInt(data.yaga_link_color_1.replace("#", ""), 16) >> 16) & 255 }}',
			'yaga_link_color_1g' => '{{ (parseInt(data.yaga_link_color_1.replace("#", ""), 16) >> 8) & 255 }}',
			'yaga_link_color_1b' => '{{ parseInt(data.yaga_link_color_1.replace("#", ""), 16) & 255 }}',
			'yaga_text_transform' => '{{ data.yaga_caps == "1" ? "uppercase" : "none" }}',
			'yaga_custom_css' => '{{ data.yaga_custom_css }}'
		);
		?>
		<script type="text/html" id="tmpl-<?php echo esc_attr( $this->template_name ); ?>">
			<?php $this->customizer_css( $settings ); ?>
		</script>
		<?php
	}

	private	function customizer_css( $settings = NULL ) {
		
		$settings = wp_parse_args( $settings, array(
			'yaga_text_color' => pehaathemes_get_theme_mod_not_empty('yaga_text-color', PeHaaThemes_Theme_Config::$color ),
			'yaga_html_bg' => pehaathemes_get_theme_mod_not_empty('yaga_html_bg', PeHaaThemes_Theme_Config::$html_bg ),
			'yaga_main_nav_drop_bg' => pehaathemes_get_theme_mod_not_empty( 'yaga_main_nav_drop_bg', PeHaaThemes_Theme_Config::$main_nav_drop_bg ),
			'yaga_main_nav_drop_color' => pehaathemes_get_theme_mod_not_empty( 'yaga_main_nav_drop_color', PeHaaThemes_Theme_Config::$color ),
			'yaga_footer_bg' => pehaathemes_get_theme_mod_not_empty( 'yaga_footer_bg', PeHaaThemes_Theme_Config::$footer_bg ),
			'yaga_footer_color' => pehaathemes_get_theme_mod_not_empty( 'yaga_footer_color', PeHaaThemes_Theme_Config::$footer_color ),
			'yaga_footer_copy_bg' => pehaathemes_get_theme_mod_not_empty( 'yaga_footer_copy_bg', PeHaaThemes_Theme_Config::$footer_copy_bg ),
			'yaga_footer_copy_color' => pehaathemes_get_theme_mod_not_empty( 'yaga_footer_color', PeHaaThemes_Theme_Config::$footer_color ),
			'yaga_box_bg' => pehaathemes_get_theme_mod_not_empty( 'yaga_box_bg', PeHaaThemes_Theme_Config::$box_bg ),
			'yaga_border_bg' => pehaathemes_get_theme_mod_not_empty( 'yaga_border_bg', PeHaaThemes_Theme_Config::$box_bg ),
			'yaga_link_color' => pehaathemes_get_theme_mod_not_empty( 'yaga_link_color', PeHaaThemes_Theme_Config::$link_color ),
			'yaga_link_color_1' => pehaathemes_get_theme_mod_not_empty( 'yaga_link_color_1', PeHaaThemes_Theme_Config::$link_color_1 ),
			'yaga_link_color_1r' => '',
			'yaga_link_color_1g' => '',
			'yaga_link_color_1b' => '',
			'opacity' => PeHaaThemes_Theme_Config::$hover_overlay_opacity,
			'yaga_text_transform' => 'none',
			'yaga_custom_css' => ''
		) );
		echo <<<CSS
		html {
			background-color: {$settings['yaga_html_bg']};
			color:{$settings['yaga_text_color']};
			border-color:{$settings['yaga_border_bg']};

		}
		.phtpb_section {background-color: {$settings['yaga_html_bg']};}
		.pht-gallery {
			color: {$settings['yaga_html_bg']};
		}
		.pht-full-menu .main-nav__ctnr .sub-menu {
			background: {$settings['yaga_main_nav_drop_bg']};
			color: {$settings['yaga_main_nav_drop_color']};
		}
		.site-footer {
			background-color: {$settings['yaga_footer_bg']};
		}
		.site-footer__sidebar {
			color: {$settings['yaga_footer_color']};
		}
		.site-footer__info {
			background:{$settings['yaga_footer_copy_bg']};
			color:{$settings['yaga_footer_copy_color']};
		}
		.pht-box--highlight,.bypostauthor,.woocommerce-account .order-info,.woocommerce-cart .cart-collaterals .cart_totals, .pht-sidebar >:nth-child(n) {
			 background:{$settings['yaga_box_bg']};
		}
		.pht--top-fixed-navigation .site-header, .pht--top_fixed_fixed-navigation .site-header {
			 background:{$settings['yaga_border_bg']};
		}
		a {
			color:{$settings['yaga_link_color']};
		}
		a:hover,.container-a--h a:hover, .a-a--h:hover{
			color:{$settings['yaga_link_color_1']};
		}
		.pht-fig__link--hoverdir{
			background:rgba({$settings['yaga_link_color_1r']},{$settings['yaga_link_color_1g']},{$settings['yaga_link_color_1b']},{$settings['opacity']});
		}
		h1, h2, h3, h4, h5, h6, .pht-secondfont {
			text-transform:{$settings['yaga_text_transform']};
		}
		.subtitle, .pht-subtitle {text-transform:none}

		{$settings['yaga_custom_css']} 
CSS;
	}

	public function custom_styles() {

		$custom_css = '';

		$wc_styles = class_exists( 'Yaga_WooCommerce' ) && Yaga_WooCommerce::$woocommerce_is_activated;

		// Fonts
		$user_body_font = PeHaaThemes_Theme_Start::$body_font;
		$normal = PeHaaThemes_Theme_Start::$body_normal_weight;
	 	$body_bold_weight = PeHaaThemes_Theme_Start::$body_bold_weight;
	 	$headings_weight = PeHaaThemes_Theme_Start::$headings_weight;
	 	$body_font_family = get_theme_mod( 'yaga_body_font_family', PeHaaThemes_Theme_Config::$body_font_family );
	 	$headings_in_navbar = get_theme_mod( 'yaga_headings_in_navbar', true );

	 	$css_fragment_body_normal = $css_fragment_headings = '';

	 	if ( PeHaaThemes_Theme_Config::$body_normal_weight !== PeHaaThemes_Theme_Start::$body_normal_weight ) {
	 		$css_fragment_body_normal .= 'font-weight:' . PeHaaThemes_Theme_Start::$body_normal_weight .';';
		}

		if ( PeHaaThemes_Theme_Config::$body_font !== PeHaaThemes_Theme_Start::$body_font ) {
			
			$user_body_font_face = trim( PeHaaThemes_Theme_Start::$body_font );
			$css_fragment_body_normal .= "font-family: '{$user_body_font_face}', {$body_font_family};";	
		
		}

		if ( $css_fragment_body_normal ) {
			$selectors_body_normal = 'html, .firstfont, .subtitle, .pht-subtitle';
			$custom_css .= $selectors_body_normal . '{' . $css_fragment_body_normal .  '}';
		}
		
		if ( PeHaaThemes_Theme_Config::$body_bold_weight !== $body_bold_weight ) {
			$selectors_body_bold = '.strong, dt, .pht-btn, .button, th, strong, optgroup, b';
			$selectors_body_bold .= $headings_in_navbar ? '' : ', .pht-actionfont';
	 		$selectors_body_bold .= $wc_styles ? ', .woocommerce .added_to_cart,.woocommerce #reviews .submit,.woocommerce a.remove, .woocommerce .quantity .qty, .woocommerce .product .summary .price, .woocommerce .product .out-of-stock, .woocommerce .product form.cart .variations label, .woocommerce ul.products li.product .price ins, .woocommerce form .form-row label, .woocommerce form .form-row .required, .woocommerce ul#shipping_method .amount, .woocommerce .widget_layered_nav .chosen a, .woocommerce .widget_layered_nav_filters a, .woocommerce-account mark,.woocommerce-account .notes .meta, .woocommerce-tabs .tabs .active a,.product_list_widget a' : '';
	 		$custom_css .= $selectors_body_bold . "{font-weight:{$body_bold_weight};}";
		}

		$user_headings_font = PeHaaThemes_Theme_Start::$headings_font;
		$headings_font_family = PeHaaThemes_Theme_Config::$headings_font_family;

		if ( PeHaaThemes_Theme_Config::$headings_weight !== $headings_weight ) {
	 		$css_fragment_headings .= "font-weight:{$headings_weight};";
		}

		if ( PeHaaThemes_Theme_Config::$headings_font !== $user_headings_font ) {
			
			$user_headings_font_face = trim( $user_headings_font );
			$headings_font_family = get_theme_mod( 'yaga_headings_font_family', $headings_font_family );

			$css_fragment_headings .= "font-family: '{$user_headings_font_face}', {$headings_font_family};";	
		} 

		$caps = get_theme_mod( 'yaga_caps' );
		if ( $caps ) {
			$css_fragment_headings .= "text-transform:uppercase;";
		}


		if ( $css_fragment_headings ) {
			$selectors_headings = 'h1, h2, h3, h4, h5, h6, .pht-secondfont';
			$custom_css .= $selectors_headings . '{' . $css_fragment_headings .  '}';
		} 
		if ( $caps ) {
			$custom_css .= '.subtitle, .pht-subtitle {text-transform:none;}';
		}

		if ( $headings_in_navbar ) {
			if ( PeHaaThemes_Theme_Config::$headings_font !== $user_headings_font ) {
				$custom_css .=  ".pht-actionfont, .pht-btn, .button, .submit, .wpcf7-submit, .woocommerce .added_to_cart, .phtpb_timetable__day__label { font-family:'{$user_headings_font}', $headings_font_family;";
				if ( PeHaaThemes_Theme_Config::$headings_weight !== $headings_weight ) {
					$custom_css .= "font-weight:$headings_weight;}";
				} else {
					$custom_css .= "}";
				}
			} elseif ( PeHaaThemes_Theme_Config::$headings_weight !== $headings_weight ) {
				$custom_css .= ".pht-actionfont, .pht-btn, .button, .submit, .wpcf7-submit, .woocommerce .added_to_cart, .phtpb_timetable__day__label { font-weight:$headings_weight;}";
			}
			
		} else {
			$custom_css .=  ".pht-actionfont, .pht-btn, .button, .submit, .wpcf7-submit, .woocommerce .added_to_cart, .phtpb_timetable__day__label { font-family:'{$user_body_font}', $body_font_family;font-weight:$body_bold_weight;}";
		}

		$logo_height = pehaathemes_get_theme_mod_not_empty( 'yaga_logo_height', PeHaaThemes_Theme_Config::$logo_height );

		$extra_height = !get_theme_mod( 'yaga_hide_tagline' ) ? 24 : 0;
		$extra_height += !get_theme_mod( 'yaga_hide_title' ) ? 48 : 0;

		if ( 'top_fixed_center' === get_theme_mod( 'yaga_navigation' ) ) {
			$logo_height = Yaga_Site_Header::$fullpage_logo ? $logo_height : 0;
			$v = $logo_height + $extra_height;
			$v += $v ? 24 + 24 + 64 : 24 + 64;
			$v_tiny = $v - 12;
			$v_no = $v - 24;
			$v_large = $v + 8;
			if ( PeHaaThemes_Theme_Config::$logo_height !== $logo_height  ) {
				$custom_css .= ".h1-img img {height:{$logo_height}px;}";
			}
			$custom_css .= "@media screen and (min-width: 1024px){.pht--top_fixed_center-navigation .phtpb_section--full:first-of-type{height:calc(100vh - {$v}px);}.pht-html--tiny-ml.pht--top_fixed_center-navigation .phtpb_section--full:first-of-type{height:calc(100vh - {$v_tiny}px);}.pht-html--no-ml.pht--top_fixed_center-navigation .phtpb_section--full:first-of-type{height:calc(100vh - {$v_no}px);}}";
			$custom_css .= "@media screen and (min-width: 1400px){.pht--top_fixed_center-navigation .phtpb_section--full:first-of-type{height:calc(100vh - {$v_large}px);}}";
			if ( class_exists( 'RevSlider' ) ) {
			$custom_css .= "@media screen and (min-width: 1024px){.pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container, .pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container + .tp-fullwidth-forcer {height:calc(100vh - {$v}px)!important;}.pht-html--tiny-ml.pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container, .pht-html--tiny-ml.pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container + .tp-fullwidth-forcer{height:calc(100vh - {$v_tiny}px)!important;}.pht-html--no-ml.pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container, .pht-html--no-ml.pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container + .tp-fullwidth-forcer{height:calc(100vh - {$v_no}px)!important;}}";
			$custom_css .= "@media screen and (min-width: 1400px){.pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container, .pht--top_fixed_center-navigation .phtpb_section:first-of-type .forcefullwidth_wrapper_tp_banner .fullscreen-container + .tp-fullwidth-forcer{height:calc(100vh - {$v_large}px);}}";
			}

		} elseif ( PeHaaThemes_Theme_Config::$logo_height !== $logo_height  ) {
			$custom_css .= ".h1-img img {height:{$logo_height}px;}";
			
			if ( Yaga_Site_Header::$fullpage_logo && !in_array( get_theme_mod( 'yaga_navigation' ), array( 'top_fixed_full', 'top_fixed_center', 'top_fixed_fixed' ) ) ) {
				$extra_height = !get_theme_mod( 'yaga_hide_tagline' ) ? 24 : 0;
				$extra_height += !get_theme_mod( 'yaga_hide_title' ) ? 48 : 0;
				$header_height = max( $logo_height + $extra_height + 24, 96 );
				
					$custom_css .= "@media screen and (min-width: 1024px){.site-header, .js-body--nopageheader .phtpb_section:first-of-type:before, .pht-page-header--with-image:before{height:{$header_height}px}.js-body--nopageheader .phtpb_section:first-of-type, .pht-page-header--with-image, .js-body--nopageheader .phtpb_section:first-of-type .phtpb_flexslider:first-child {margin-top:-{$header_height}px!important;} .js-body--nopageheader .phtpb_section:first-of-type .phtpb_section__in { top:-{$header_height}px;}}";
				

			}
		} 
		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_text_color', PeHaaThemes_Theme_Config::$color );
		if ( PeHaaThemes_Theme_Config::$color !== $user_input ) {
			$custom_css .= "html{color:$user_input;}";
			if ( 'default' !==  PeHaaThemes_Theme_Config::$navigation ) {
				$custom_css .=".pht-full-menu .pht-sticky-pre-fixed .main-nav__a-depth-0, .pht-full-menu .pht-sticky-pre-fixed .main-nav__a-depth-0:hover{color:$user_input;}";
			}
			
		}
		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_html_bg', PeHaaThemes_Theme_Config::$html_bg );
		if ( PeHaaThemes_Theme_Config::$html_bg !== $user_input ) {
			$custom_css .= "html,.phtpb_section{background-color:$user_input;}.pht-gallery{color:$user_input;}";
		}
		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_main_nav_drop_bg', PeHaaThemes_Theme_Config::$main_nav_drop_bg );
		if ( PeHaaThemes_Theme_Config::$main_nav_drop_bg !== $user_input ) {
			$custom_css .= ".pht-full-menu .main-nav__ctnr .sub-menu{background:$user_input;}";
		}
		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_main_nav_drop_color', PeHaaThemes_Theme_Config::$color );
		if ( PeHaaThemes_Theme_Config::$footer_color !== $user_input ) {
			$custom_css .= ".pht-full-menu .main-nav__ctnr .sub-menu{color:$user_input;}"; 
		}

		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_footer_bg', PeHaaThemes_Theme_Config::$footer_bg );
		if ( PeHaaThemes_Theme_Config::$footer_bg !== $user_input ) {
			$custom_css .= ".site-footer{background-color:$user_input;}"; 
		}
		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_footer_color', PeHaaThemes_Theme_Config::$footer_color );
		if ( PeHaaThemes_Theme_Config::$footer_color !== $user_input ) {
			$custom_css .= ".site-footer__sidebar{color:$user_input;}"; 
		}

		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_footer_copy_bg', PeHaaThemes_Theme_Config::$footer_copy_bg );
		if ( PeHaaThemes_Theme_Config::$footer_copy_bg !== $user_input ) {
			$custom_css .= ".site-footer__info{background:$user_input;}"; 
		}

		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_footer_copy_color', PeHaaThemes_Theme_Config::$footer_color );
		if ( PeHaaThemes_Theme_Config::$footer_color !== $user_input ) {
			$custom_css .= ".site-footer__info{color:$user_input;}"; 
		}

		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_box_bg', PeHaaThemes_Theme_Config::$box_bg );
		if ( PeHaaThemes_Theme_Config::$box_bg !== $user_input ) {
			$selectors = '.pht-box--highlight,.bypostauthor,.pht-sidebar >:nth-child(n)';
			$selectors .= $wc_styles ? ',.woocommerce-account .order-info,.woocommerce-cart .cart-collaterals .cart_totals' : '';
			$custom_css .= "$selectors{background:$user_input;}";
		}

		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_border_bg', PeHaaThemes_Theme_Config::$box_bg );
		if ( PeHaaThemes_Theme_Config::$box_bg !== $user_input ) {
			$selectors = '.pht--top-fixed-navigation .site-header, .pht--top_fixed_fixed-navigation .site-header';
			$custom_css .= "$selectors{background:$user_input;}html{border-color:$user_input}";
		}

		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_link_color', PeHaaThemes_Theme_Config::$link_color ); 	
		if ( PeHaaThemes_Theme_Config::$link_color !== $user_input ) {
			$custom_css .= "a {color:{$user_input}}";
		}
		
		$user_input = pehaathemes_get_theme_mod_not_empty( 'yaga_link_color_1', PeHaaThemes_Theme_Config::$link_color_1 ); 	
		if ( PeHaaThemes_Theme_Config::$link_color_1 !== $user_input || 0.85 !== PeHaaThemes_Theme_Config::$hover_overlay_opacity ) {
			$rgba = pehaathemes_rgba( $user_input, PeHaaThemes_Theme_Config::$hover_overlay_opacity );
			$custom_css .= "a:hover,.container-a--h a:hover, .a-a--h:hover{color:{$user_input}}";
			if ( $rgba ) {
				$custom_css .= ".pht-fig__link--hoverdir{background:{$rgba}}";
			}			
		}

		$navigation_breakpoint = (int) PeHaaThemes_Theme_Config::$navigation_breakpoint;

		if ( 1280 !== $navigation_breakpoint && $navigation_breakpoint >= 1024 ) {
			$custom_css .= "@media screen and (min-width: {$navigation_breakpoint}px){.mobile-menu-closed .main-nav__ctnr {transition:opacity 1s, visibility 1s;}}";
			
		}
		
		$user_css = get_theme_mod( 'yaga_custom_css' );

		if ( $user_css ) {	
			$custom_css .=  stripslashes( htmlspecialchars_decode( $user_css ) );
		}
		
		if ( '' !== $custom_css ) {
			$deps = apply_filters( 'pehaathemes_load_stylesheet_css', true ) ? 'pehaathemes-s-style' : 'pehaathemes-t-style';
			wp_add_inline_style( $deps, $custom_css );
		}

	}
	
}

}

Yaga_Customizer::get_instance();