<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Entry' ) ) :

class Yaga_Entry {

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	protected $separator;
	
	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	protected function __construct() {
		$this->separator = apply_filters( 'yaga_inline_separator', ' &middot; ' );
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	public function entry( $layout = 'grid', $lightbox = true, $from_page_builder = false, $force_skip_summary = false, $post_classes = '', $thumb_size = '' ) { 

		$post_classes .= 'classic' === $layout ? ' index__item pht-mb pht-zeta' : ' pht-index--grid__item index__item pht-zeta pht-parent';
		
		if ( !$thumb_size ) {

			if ( 'classic' === $layout ) {

				$sidebar = isset( PeHaaThemes_Theme_Config::$sidebar->display ) && PeHaaThemes_Theme_Config::$sidebar->display;
				$thumb_size = $sidebar ? apply_filters( 'yaga_posts_classic_sidebar_thumb_size', 'yaga-post-view' ) : apply_filters( 'yaga_posts_classic_no_sidebar_thumb_size', 'yaga-full-width' );

			} else {

				$thumb_size = apply_filters( 'yaga_posts_grid_thumb_size', 'yaga-post-grid' );			
			
			}

		} ?>

		<?php if ( $from_page_builder ) { ?>

			<article <?php post_class( $post_classes ); ?>>

		<?php } else { ?>

			<article id="post-<?php the_ID(); ?>" <?php post_class( $post_classes ); ?>>

		<?php } ?>		

			<?php $this->entry_raw( $thumb_size, $lightbox, $layout, $force_skip_summary ); ?>
	
		</article>
		
	<?php }

	protected function entry_raw( $size, $lightbox = true, $layout = 'grid', $force_skip_summary ) {

		$post_type = get_post_type();

		$format = get_post_format() ? get_post_format() : 'standard';

		$output = false;

		if ( 'video' ===  $format  ) {

			$output = $this->get_post_video( 'pht-video pht-hider pht-parent pht-mb0' );

		} elseif ( 'gallery' === $format ) {
			
			$output = $this->get_post_gallery();
		} 
		
		if ( !$output && has_post_thumbnail( get_the_ID() ) ) {
				
			$this->entry_image( $size, $lightbox, NULL, 'readmore', NULL, 'pht-white' ); 
				
		} ?>

		<div class="pht-box pht-box--highlight pht-parent pht-border-hover">	
			<?php
			echo '<header class="entry-header pht-text-center">';
				$this->entry_meta_top( $post_type ); 
				$this->entry_title();
				do_action( 'yaga_after_entry_title' );
			echo '</header>';
			if ( ! $force_skip_summary ) { 
				$this->get_summary( $format ); 
			}
			do_action( 'yaga_before_entry_meta_bottom' );
			$this->entry_meta_bottom( $post_type );
			do_action( 'yaga_after_entry_meta_bottom' );
			?>
		</div>

	<?php }

	protected function separator() {
		echo esc_html( $this->separator );
	}


	public function showcase_entry( $size, $lightbox = true, $img = NULL, $link_style = '' ) {

		$this->entry_image( $size, $lightbox,  get_the_ID(), 'title', $img, 'pht-fig--filter' ); ?>

	<?php }

	public function showcase_retina_entry( $post_id, $attachment_id, $width, $height, $skip_array, $lightbox ) {

		if ( post_password_required() ) {
			return;
		}
		
		printf( '<figure class="pht-fig %s">', esc_attr( 'pht-fig--filter' ) );

		echo pehaathemes_get_att_img( $attachment_id, array( $width, $height), false, array( 'class' => 'pht-img--fill', 'width' => $width ), $skip_array );
		
		echo '<div class="pht-fig__link--ctnr">';	
		printf( '<a class="pht-fig__link pht-fig__link--hoverdir pht-fig__link--main pht-text-center a-a a-a--no-h" href="%1$s">',
			esc_url( get_permalink( $post_id ) )
		);
		echo '<div class="pht-fig__titles pht-epsilon">';
			$this->caption_title( $post_id );
		echo '</div>';
		echo '</a>';
		if ( $lightbox ) {
			$full_image = wp_get_attachment_image_src( $attachment_id, 'full' );
			printf( '<a href="%s" class="pht-fig__link js-pht-magnific_popup pht-fig__link--secondary a-a a-a--no-h"><i class="pht-fig__link__string pht-ic-f1-arrow-expand-alt"></i></a>', esc_url( $full_image[0] ) );
		}
		echo '</div>';		
		echo '</figure>';

	}


	protected function get_post_video( $class ) {

		$video = null;
	
		$url_pattern = '#https?://((www\.)?((vimeo|youtube|dailymotion)\.com|youtu\.be|dai.ly)/.*|.+?\.(' . join( '|', wp_get_video_extensions() ) . '*))#i';

		if ( preg_match_all( '/'. get_shortcode_regex() .'|(^|[\n|\r])https?:\/\/\S*(\r|\n|$)/s', get_the_content(), $matches, PREG_SET_ORDER ) ) {
			foreach ( $matches as $shortcode ) {
				if ( 'video' === $shortcode[2] ) {
					echo '<figure class="' . esc_attr( $class ) . '">';
					echo do_shortcode( $shortcode[0] );
					echo '</figure>';
					return true;
				} elseif ( 'embed' === $shortcode[2] || '' === $shortcode[2] ) {
					$is_embed = 'embed' === $shortcode[2];
					$subject_string = $is_embed ? $shortcode[5] : $shortcode[0];

					if ( preg_match( $url_pattern , $subject_string , $match ) ) {
						global $wp_embed;
						
						$shortcode = $is_embed ? $shortcode[0] : '[embed]'. esc_url( $shortcode[0] ) .'[/embed]';
						$check_embed = $wp_embed->run_shortcode( $shortcode );
						echo '<figure class="' . esc_attr( $class ) . '">';
						echo do_shortcode( $check_embed );
						echo '</figure>';
						return true;
					} else {
						return;
					}
				}
			}
		}

		return;

	}

	protected function get_post_gallery() {

		echo $gallery = get_post_gallery( get_the_ID(), true );

		if ( $gallery ) {
			return true;
		}
		return;
		
	}

	protected function get_post_audio() {

		$audio = null;
		
		$url_pattern = '#https?://((www\.)?((soundcloud|rdio|(open|play)\.spotify)\.com|rd\.io/x/)/.*|.+?\.(' . join( '|', wp_get_audio_extensions() ) . '*))#i';

		if ( preg_match_all( '/'. get_shortcode_regex() .'|(^|[\n|\r])https?:\/\/\S*(\r|\n|$)/s', get_the_content(), $matches, PREG_SET_ORDER ) ) {
			foreach ( $matches as $shortcode ) {
				if ( 'audio' === $shortcode[2] ) {
					echo do_shortcode( $shortcode[0] );
					break;
				} elseif ( 'embed' === $shortcode[2] | '' === $shortcode[2] ) {
					$is_embed = 'embed' === $shortcode[2];
					$subject_string = $is_embed ? $shortcode[5] : $shortcode[0];
					if ( preg_match( 	$url_pattern , $subject_string , $match ) ) {
						global $wp_embed;
						$shortcode = $is_embed ? $shortcode[0] : '[embed]'. esc_url( $shortcode[0] ) .'[/embed]';
						$check_embed = $wp_embed->run_shortcode( $shortcode );
						echo do_shortcode( $check_embed );
						break;
					} else {
						return;
					}
				}
			}
		}
		
		return $audio;
		
	}

	public function entry_image( $size = 'yaga-post-grid', $lightbox = true, $post_id = NULL, $figcaption = 'readmore', $img = NULL, $figure_class = '' ) {

		if ( post_password_required() ) {
			return;
		}

		if ( !$size && !$img ) {
			return;
		}

		if ( !$size && ( !isset( $img['url'] ) || !isset( $img['width'] ) || !isset( $img['height'] ) ) ) {
			return;
		}

		if ( !$post_id ) {
			$post_id = get_the_ID();
		}
		
		printf( '<figure class="pht-fig %s">', esc_attr( $figure_class ) );

		if ( $size ) {

			echo get_the_post_thumbnail( $post_id, $size, array( 'class' => 'pht-img--fill' ) );

		} else {
			$width = $img['width'];
			$height = $img['height'];
			$src = $img['url'];
			printf( '<img %1$s src="%2$s" class="pht-img--fill" alt="%3$s" />',
				image_hwstring( $width, $height ),
				esc_url( $src ),
				esc_attr( pehaathemes_image_alt( get_post_thumbnail_id( $post_id ) ) )
			);
		}
		
		echo '<div class="pht-fig__link--ctnr">';	
		printf( '<a class="pht-fig__link pht-fig__link--hoverdir pht-fig__link--main pht-text-center a-a a-a--no-h" href="%1$s">',
			esc_url( get_permalink( $post_id ) )
		);
		echo '<div class="pht-fig__titles pht-epsilon">';
		if ( 'readmore' === $figcaption ) {
			echo '<span class="pht-actionfont">' . esc_html__( 'Read more', 'yaga' ) . '</span>';
		} elseif ( 'title' === $figcaption ) {
			$this->caption_title( $post_id );
		}
		echo '</div>';
		echo '</a>';
		if ( $lightbox ) {
			$full_image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
			printf( '<a href="%s" class="pht-fig__link js-pht-magnific_popup pht-fig__link--secondary a-a a-a--no-h"><i class="pht-fig__link__string pht-ic-f1-arrow-expand-alt"></i></a>', esc_url( $full_image[0] ) );
		}
		echo '</div>';		
		echo '</figure>';

	}


	protected function entry_title() { 
		
		$post_id = get_the_ID();

		$truncate_class = get_theme_mod( 'yaga_truncate_title' ) ? 'pht-truncate' : '';

		printf( '<a href="%2$s" class="a-a a-a--h" rel="bookmark"><h2 class="entry-title pht-heading hN pht-mb0 %1$s">%3$s</h2></a>', 
			esc_attr( $truncate_class ), 
			esc_url( get_permalink( $post_id ) ), 
			esc_html( get_the_title( $post_id ) ) 
		);

	}

	protected function caption_title( $post_id = NULL ) { 
		
		if ( !$post_id ) {
			$post_id = get_the_ID();
		} 

		$truncate_class = get_theme_mod( 'yaga_truncate_title' ) ? 'pht-truncate' : '';
		printf( '<h2 class="entry-title pht-truncate pht-heading hN pht-mb0 %1$s">%2$s</h2>', 
			esc_attr( $truncate_class ),
			esc_html( get_the_title( $post_id ) )
		);

	}

	protected function get_summary( $format = 'standard' ) {

		if ( in_array( $format, array( 'image', 'gallery' ) ) ) return;
	
		$display_excerpt = in_array( $format, array( 'standard', 'video' ) ) && get_the_excerpt();
		$display_content = in_array( $format, array( 'aside' ) ) && get_the_content();
		$display_quote = 'quote' === $format && get_the_content();
	
		if ( $display_excerpt || $display_content || 'audio' === $format ) { ?>
			
			<div class="entry-summary pht-entry-summary pht-mt cf">

				<?php if ( 'audio' === $format ) {
					$this->get_post_audio();
				}
				if ( $display_excerpt ) {
					the_excerpt();
				} elseif ( $display_content ) {
					the_content();
				} ?>

			</div>
			
			
		<?php }

	}

	protected function entry_meta_top( $post_type = 'post' ) {
	
		if ( ! in_array( $post_type, apply_filters( 'yaga_post_types_with_meta', array( 'post' ) ) ) ) {
			return;
		} ?>

		<div class="pht-micro entry-meta entry-meta--top entry-meta-<?php echo esc_attr( get_theme_mod( 'yaga_top_meta', 'date' ) ); ?> pht-italic container-a container-a--h">
			<?php $meta_method = 'entry_meta_' . esc_attr( get_theme_mod( 'yaga_top_meta', 'date' ) );
			if ( method_exists( $this, $meta_method ) ) {
				$this->$meta_method();
			} ?>
		</div>
	<?php }

	protected function entry_meta_bottom( $post_type = 'post' ) {

		$display = array();

		foreach ( array( 'date', 'author', 'categories', 'comments' ) as $meta ) {
			if ( ! in_array( $post_type, apply_filters( 'yaga_post_types_with_meta_' . $meta, array( 'post' ) ) ) ) {
				continue; 
			}
			if ( get_theme_mod( 'yaga_' . $meta . '_in_bottom_meta', PeHaaThemes_Theme_Config::$entry_bottom_meta[ $meta ] ) ) {
				$display[] = $meta;
			}
		}
		
		if ( empty( $display ) ) {
			return; 
		}
		echo '<div class="entry-meta pht-micro entry-meta--bottom container-a container-a--h pht-text-center pht-italic pht-mt">';
		
		$string_started = false;

		foreach ( apply_filters( 'yaga_meta_order', array( 'date', 'author', 'categories', 'comments' ) ) as $meta ) {
	
			if ( ! in_array( $meta, $display ) ) {
				continue; 
			}
			$meta_method = 'entry_meta_' . $meta;
			if ( !method_exists( $this, $meta_method ) ) {
				continue; 
			}
			$string_started = $this->$meta_method( $string_started, $post_type ) || $string_started;

		} 
		
		echo '</div><!-- .entry-meta -->';

	}

	protected function entry_meta_date( $with_separator = false, $post_type = 'post' ) {

		if ( is_sticky() ) {
			return false;
		}

		if ( $with_separator ) {
			$this->separator();
		}
		echo '<a class="entry-date" href="' . esc_url( get_permalink() ) . '">';
		echo '<time class="entry-date" datetime="' . esc_attr( get_the_date( 'c' ) ) . '">' . esc_html( get_the_date() ) . '</time>';
		echo '</a>';

		return true;

	}

	protected function entry_meta_author( $with_separator = false, $post_type = 'post' ) {

		if ( $with_separator ) {
			$this->separator();
		}
		$by = apply_filters( 'yaga_author_by' , esc_html__( 'by ', 'yaga' ) );
		printf( '<span class="author byline">' . $by . ' <a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				sprintf( esc_attr__( 'View all posts by %s', 'yaga' ), get_the_author() ),
				get_the_author()
			);

		return true;

	}

	protected function entry_meta_categories( $with_separator = false, $post_type = 'post' ) {

		if ( $with_separator ) {
			$this->separator();
		}
		$in = apply_filters( 'yaga_category_in' , esc_html__( 'in ', 'yaga' ) );
		$taxonomy = apply_filters( 'yaga_meta_taxonomy_for_' . $post_type, 'category' );
		the_terms( get_the_ID(), $taxonomy, '<span class="categories-links">'. $in .' <span> ',', ','</span></span> ');
		return true;

	}
	
	protected function entry_meta_comments( $with_separator = false, $post_type = 'post' ) {

		if ( post_password_required() || ( !comments_open() && !get_comments_number() ) ) {
			return;
		}

		if ( $with_separator ) {
			$this->separator();
		}
		
		echo ' <span class="entry-meta nobr"><i class="pht-ic-f1-comments"></i>';
		comments_popup_link( ' <span class="leave-reply">' . esc_html__( ' 0', 'yaga' ) . '</span>', esc_html__( ' 1', 'yaga' ), esc_html__( ' %', 'yaga' ) );
		echo '</span> <!-- .comments-link -->';
		return true;
	}

	public function pagination( $query ) {

		$paged = is_front_page() ? intval( get_query_var( 'page' ) ) : intval( get_query_var( 'paged' ) );
		$max_page = $query->max_num_pages;
		if ( empty( $paged ) || $paged == 0 ) {
			$paged = 1;
		}

		$big = 999999999;

		$paginate_links = paginate_links( array(
				'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
				'current' => max( 1, $paged ),
				'total' => $max_page,
				'mid_size' => 5,
				'prev_next' => True,
				'prev_text' => '&laquo;',
				'next_text' => '&raquo;',
				'type' => 'array'
			) );

		if ( $paginate_links ) {
			echo "<ol class='nav pht-pagination page-numbers pht-actionfont pht-box pht-box--highlight pht-mb'>\n\t<li>";
			echo join( '</li><!-- --><li>', $paginate_links );
			echo "</li>\n</ol>\n";
		}

	}

}

endif;