<?php
if ( ! class_exists( 'Yaga_MegaMenu_Walker_Nav_Menu' ) ) :
	
	class Yaga_MegaMenu_Walker_Nav_Menu extends Walker_Nav_Menu {

		private $total_num_of_columns = 0;

		private $maybe_megamenu_columns = 0;

		public function start_lvl( &$output, $depth = 0, $args = array() ) {
			
			$indent = str_repeat( "\t", $depth );
			$output .= "\n$indent<ul class=\"{main-nav__menutype} sub-menu container-a container-a--alt-h {megamenu_col_count}\">\n";
		
		}		

		/**
		 * @see Walker::end_lvl()
		 */
		public function end_lvl( &$output, $depth = 0, $args = array() ) {
			
			$indent = str_repeat( "\t", $depth );			
			$output .= "$indent</ul>\n";
			
		}

		/**
		 * Start the element output.
		 *
		 * @see Walker::start_el()
		 * @param string $output Passed by reference. Used to append additional content.
		 * @param object $item   Menu item data object.
		 * @param int    $depth  Depth of menu item. Used for padding.
		 * @param array  $args   An array of arguments. @see wp_nav_menu()
		 * @param int    $id     Current item ID.
		 */
		public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
			
			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
			
			$classes = empty( $item->classes ) ? array() : (array) $item->classes;

			if ( 0 === $depth ) {

				//reset
				$this->num_of_columns = $this->total_num_of_columns = $this->maybe_megamenu_columns = 0;

			} elseif ( 1 === $depth ) {

				$this->num_of_columns++;
				$this->total_num_of_columns++;
				if ( $args->has_children ) {
					$this->maybe_megamenu_columns++;
				}
				
			}
			
			
			$classes[] = 'menu-item-' . $item->ID;
			$classes[] = 'main-nav__li-depth-' . $depth;
			$classes[] = 'main-nav__li';

			if ( 0 === $depth && $args->has_children ) {
				
				$classes[] = ' main-nav__{mega}trigger {li_megamenu_col_count}';
				
			} elseif ( $depth === 1 ) {

				$classes[] = ' main-nav__li--{mega}';

			}

			$class_names = join( ' ', apply_filters( 'yaga_nav_menu_css_class', array_filter( $classes ), $item, $args ) );
			$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

			$id = apply_filters( 'yaga_nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
			$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

			$output .= $indent . '<li' . $id . $class_names .'>';

			$atts = array();
			$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
			$atts['target'] = ! empty( $item->target )     ? $item->target     : '';
			$atts['rel']    = ! empty( $item->xfn )        ? $item->xfn        : '';
			$atts['href']   = ! empty( $item->url )        ? $item->url        : '';

			if ( apply_filters( 'yaga_replace_hash_links', true ) ) {
				$atts['href'] = preg_replace( '/\A(#\S+)\z/', esc_url( home_url( '/' ) ) . '$1', $atts['href'] );
			}

			$main_nav_a0_class = 'a-a a-a--alt-h-inverse main-nav__a-depth-0--b ';

			$link_class = in_array( get_theme_mod( 'yaga_headings_font_family' ), array( 'cursive', 'fantasy' ) ) && get_theme_mod( 'yaga_headings_in_navbar', true ) ? ' pht-secondfont' : ' pht-actionfont';

			$atts['class'] = ( 0 == $depth ) ? $main_nav_a0_class . $link_class : '';
			if ( $args->has_children && 0 === $depth )  {
				$atts['class'] .= ' js-with-submenu ul-hidden';
			} elseif ( $args->has_children )  {
				//$atts['class'] .= '{maybe_with_submenu}';
			}
			$atts['class'] .= " pht-truncate main-nav__a main-nav__a-depth-$depth";

			$atts = apply_filters( 'yaga_nav_menu_link_attributes', $atts, $item, $args );

			$attributes = '';
			foreach ( $atts as $attr => $value ) {
				if ( ! empty( $value ) ) {
					$value = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
					$attributes .= ' ' . $attr . '="' . $value . '"';
					if ( 'class' === $attr ) {
						continue;
						
					}
				}
			}
			
			if ( $atts['href'] ) {
				$maybe_link_start = '<a'. $attributes .'>';
				$maybe_link_end = '</a>';
			} else {
				$maybe_link_start = '<span'. $attributes .'>';
				$maybe_link_end = '</span>';
			}
			$title =  apply_filters( 'yaga_the_title', $item->title, $item->ID ) . '';

			$item_output = $args->before;
			$item_output .= $maybe_link_start;
			$item_output .= $args->link_before . $title . $args->link_after;
			$item_output .= $args->has_children ? '<i class="main-nav__icon main-nav__icon--right pht-ic-f1-caret-up"></i>' : '';
			$item_output .= $maybe_link_end;					
			$item_output .= $args->after;

			$output .= apply_filters( 'yaga_walker_nav_menu_start_el', $item_output, $item, $depth, $args );

		}

		/**
		 * @see Walker::end_el()
		 *
		 * @param string $output Passed by reference. Used to append additional content.
		 * @param object $item Page data object. Not used.
		 * @param int $depth Depth of page. Not Used.
		 */
		function end_el( &$output, $item, $depth = 0, $args = array() ) {

			if ( $depth === 0 ) {
				if ( $this->total_num_of_columns === $this->maybe_megamenu_columns && $this->total_num_of_columns > 1 ) {

					$effective_num_of_columns = $this->total_num_of_columns;
					if ( $effective_num_of_columns > 4 ) {
						$mod4 = $effective_num_of_columns % 4;
						$mod3 = $effective_num_of_columns % 3;
						if ( 0 === $mod4 ) {
							$effective_num_of_columns = 4;
						} elseif ( 0 === $mod3 || $mod3 > $mod4 ) {
							$effective_num_of_columns = 3;
						} else {
							$effective_num_of_columns = 4;
						}
					}
					$output = str_replace( '{main-nav__menutype}', 'main-nav__megamenu', $output );
					//$output = str_replace( '{maybe-with-submenu}', ' js-with-submenu ul-hidden', $output );
					$output = str_replace( '{megamenu_col_count}', "megamenu-cols-$effective_num_of_columns", $output );
					$output = str_replace( '{li_megamenu_col_count}', "li_megamenu-cols-$effective_num_of_columns ", $output );
					$output = str_replace( '{mega}','mega', $output );
				} else {
					$output = str_replace( '{main-nav__menutype}','main-nav__dropmenu', $output );
					//$output = str_replace( '{maybe-with-submenu}', '', $output );
					$output = str_replace( '{megamenu_col_count}','', $output );
					$output = str_replace( '{li_megamenu_col_count}', '', $output );
					$output = str_replace( '{mega}', 'drop', $output );
				}
			}			
			
			$output .= "</li>\n";
		}

		/**
		 * Traverse elements to create list from elements.
		 *
		 * Display one element if the element doesn't have any children otherwise,
		 * display the element and its children. Will only traverse up to the max
		 * depth and no ignore elements under that depth.
		 *
		 * @param object $element Data object
		 * @param array $children_elements List of elements to continue traversing.
		 * @param int $max_depth Max depth to traverse.
		 * @param int $depth Depth of current element.
		 * @param array $args
		 * @param string $output Passed by reference. Used to append additional content.
		 * @return null Null on failure with no changes to parameters.
		 */
		public function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {

			if ( ! $element ) {
				return;
			}
				
			$id_field = $this->db_fields['id'];

			if ( is_object( $args[0] ) ) {
				$args[0]->has_children = ! empty( $children_elements[ $element->$id_field ] );
			}

			parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
		}

		/**
		 * Menu Fallback
		 * =============
		 *
		 * @param array $args passed from the wp_nav_menu function.
		 *
		 */
		public static function fallback( $args ) {

			if ( class_exists( 'Yaga_Site_Header' ) ) {
				Yaga_Site_Header::$display_menu = false;
			} 

			if ( current_user_can( 'manage_options' ) ) {

				$menu_link = '<li class="menu-item menu-item-depth-0"><a class="main-nav__a main-nav__a-depth-0 a-a a-a--alt-h" href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '">' . esc_html__( 'Add a menu', 'yaga' ) . '</a></li>';
				
				if ( $args['echo'] ) {
					printf( $args['items_wrap'], '', '', $menu_link );
				} else {
					return sprintf( $args['items_wrap'], '', '', $menu_link );
				}
			}
		}
	}
endif;  // end Yaga_MegaMenu_Walker_Nav_Menu() class