<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Page_Header' ) ) :

class Yaga_Page_Header {

	protected $page_id = NULL;

	protected $header_class = '';

	protected $display_header = true;

	public static $is_header = false;

	protected $separator;

	public $header_w_img = false;

	public function __construct( $id = NULL ) {

		if ( !$id ) {
			$this->page_id = is_singular() && get_queried_object_id() ? get_queried_object_id() : NULL;
		} else {
			$this->page_id = $id;
		}

		if ( is_home() && is_front_page() ) {
			$this->display_header = false;
		} else {
			self::$is_header = true;
		}

		$this->header_w_img = get_post_meta( $this->page_id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_header_checked', true );

		$text_color = get_post_meta( PeHaaThemes_Theme_Config::$id,  PeHaaThemes_Theme_Start::$mb_prefix . 'transparent_site_header_color', true );
			if ( $text_color && in_array( $text_color, array( 'dark', 'light', 'lap_up_dark', 'lap_up_light' ) ) ) {
				$this->header_class .= "page-header--$text_color ";
			}
		$this->header_class .= in_array( $this->header_w_img, array( 'yes', 'yes_all' ) ) ? 'pht-page-header--with-image pht-page-header--image-' . $this->header_w_img : '';

		$this->separator = apply_filters( 'yaga_inline_separator', ' &middot; ' );

	}

	public function display_header() {

		if ( !$this->display_header ) {
			return;
		} ?>

		<header class="page-header pht-parent <?php echo esc_attr( $this->header_class ); ?>">
			<?php $this->display_post_header_image(); ?>
			<div class="page-header__inner palm-maxwidth palm-centered pht-parent pht-wrapper">
				<?php
				
				$this->page_titles(); 
				$this->page_meta();
				?>
			</div>
		</header><!-- end page-header -->

	<?php }

	protected function separator() {

		echo esc_html( $this->separator );

	}

	protected function display_post_header_image() {

		if ( ! in_array( $this->header_w_img, array( 'yes', 'yes_all' ) ) ) {
			return;
		}

		$id = get_post_thumbnail_id();

		if ( !$id ) {
			return;
		}

		$img_opacity = get_post_meta( $this->page_id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_header_opacity', true );

		$img_opacity = in_array( $img_opacity, array( '1', '0.9', '0.85', '0.8', '0.75', '0.7', '0.65', '0.6', '0.55', '0.5', '0.45', '0.4', '0.35', '0.3', '0.25', '0.2', '0.15', '0.1', '0.05' ) ) ? $img_opacity : '1';

		$bg_color = get_post_meta( $this->page_id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_header_bg_color', true );

		$bg_color_style = $bg_color && ( '1' !== $img_opacity ) ? 'style="background:' . esc_attr( $bg_color ) .';"' : '';
		$palm_class = 'yes_all' === $this->header_w_img ? 'js-force-palm' : 'hidden--palm';
		$style = 'style="opacity:' . esc_attr( $img_opacity ) . ';"';

		$inner_div = "<div class='pht-bg-ctnr__hider--in-post-header pht-bg-ctnr__hider pht-bg-ctnr__hider--parallax $palm_class' $bg_color_style><div class='js-pht-bg-ctnr js-pht-bg-ctnr-img pht-bg-ctnr js-phtpb_section_bg--parallax phtpb_section_bg--parallax  js-initial-hidden' $style>";

		$inner_div .= $this->image_to_be_loaded( $id );

		$inner_div .= '</div></div>';

		echo $inner_div;

	}

	protected function image_to_be_loaded( $id, $force_on_palm =  false ) {

		if ( wp_is_mobile() ) {

			return sprintf( '<div class="js-image-container js-pht-img-loader" data-imgurl="%1$s" %2$s></div>',
				esc_url( $img ), 
				$force_on_palm ? 'data-imgurl-palm="' . esc_url( $this->image_src_palm( $id ) ) . '"' : '' 
				);

		} else {
			$image_array = wp_get_attachment_image_src( $id, 'full' );
			if ( $image_array ) {
				$img = $image_array[0];
			}
			return sprintf( '<img class="js-image-container js-pht-img-loader" src="%1$s" data-imgurl="%2$s" alt="%3$s" >',
				esc_url( $img ), 
				esc_url( $img ),
				'' 
			);
		}
	}

	protected function image_src_palm( $id ) {
		
		if ( !$id ) {
			return;
		}

		if ( !wp_attachment_is_image( $id ) ) {
			return;
		}

		$resizer = PeHaaThemes_Resize_Image::get_instance();
		$img = $resizer->resize_image( $id, '' , apply_filters( 'pht_palm_background_width', 800 ), 0, true );
		if ( $img ) {
			return $img['url'];
		}
		return;

	}

	protected function page_titles() {
		$this->page_titles_raw();
		$title = $this->page_title();
		$subtitle = $this->page_subtitle();
		echo apply_filters( 'yaga_page_titles', $title . $subtitle, $title, $subtitle );
	}

	protected function page_title() {
		$title = $this->page_title_raw;
		$title_in_tags = "<h1 class='page-title'>$title</h1>";
		return apply_filters( 'yaga_page_title', $title_in_tags, $title );
	}

	protected function page_subtitle() {
		$subtitle = $this->page_subtitle_raw;
		$subtitle_in_tags = $subtitle ? "<h2 class='pht-subtitle pht-mb0 pht-gamma'>$subtitle</h2>" : '';
		return apply_filters( 'yaga_page_subtitle', $subtitle_in_tags, $subtitle );
	}

	protected function page_titles_raw() {

		$filter = $title = $subtitle = '';	

		if ( is_author() ) {
		
			if ( get_query_var( 'author_name' ) ) {
		    	$curauth = get_user_by( 'login', get_query_var( 'author_name' ) );

				} else {
		  			$curauth = get_userdata(get_query_var( 'author' ));
			}
				if ( $curauth ) {
					$author_id = $curauth->ID; 			
					$title = esc_html__( 'Posts by: ', 'yaga' );
					$subtitle = get_the_author_meta('display_name', $author_id);
					$filter = 'author';		
 				} 
	
		} elseif ( is_archive() && !$this->page_id ) {				
			if ( is_category() ) { 
				$title = esc_html__( 'Posts Categorized:', 'yaga' );
				$subtitle = single_cat_title( '', false ); 	
				$filter = 'category';
			} elseif ( is_tag() ) {
				$title = esc_html__( 'Posts Tagged:', 'yaga' ); 
				$subtitle = single_cat_title( '', false );
				$filter = 'tag';	
			} elseif ( is_tax() ) {
				$queried_object = get_queried_object();
				$title = $queried_object->name;
				//$subtitle = $queried_object->name;
				$filter = 'taxonomy';					
			} elseif ( is_day() ) { 
				$title = esc_html__( 'Daily Archives:', 'yaga' );
				$subtitle = get_the_date( esc_html_x( 'l, F j, Y', 'daily archives date format', 'yaga' ) );
				$filter = 'day';
			} elseif ( is_month() ) { 
				$title = esc_html__( 'Monthly Archives:', 'yaga' );
				$subtitle = get_the_date( esc_html_x( 'F Y', 'monthly archives date format', 'yaga' ) );
				$filter = 'month';
			} elseif ( is_year() ) { 
				$title = esc_html__( 'Yearly Archives:', 'yaga' ); 
				$subtitle = get_the_date( esc_html_x( 'Y', 'yearly archives date format', 'yaga' ) );
				$filter = 'year'; 
			} elseif ( $format = get_post_format() ) { 
				$title = esc_html__( 'Post format:', 'yaga' );
				$subtitle = get_post_format_string( $format );
				$filter = 'format'; 
			} elseif ( is_search() ) { 		
				$title = esc_html__( 'Search Results for:', 'yaga' );
				$subtitle = get_search_query(); 
				$filter = 'search';
			}
			
		} elseif ( is_search() ) { 		
			$title = esc_html__( 'Search Results for:', 'yaga' );
			$subtitle = get_search_query(); 
			$filter = 'search';
		}	elseif ( is_404() ) { 		
			$title = esc_html__( '404 error', 'yaga' ); 
			$subtitle = esc_html__( 'Page Not Found.', 'yaga' );
			$filter = '404';	
		} elseif ( is_attachment() ) {		
			$title = get_the_title();	
		} elseif ( $this->page_id ) {		
			$title = apply_filters( 'yaga_page_id_title', get_the_title( $this->page_id ),  $this->page_id );	
		}

		$this->page_title_raw = $filter ? apply_filters( 'yaga_page_title_' . $filter, $title ) : $title;
		$this->page_subtitle_raw = $filter ? apply_filters( 'yaga_page_subtitle_' . $filter, $subtitle ) : $subtitle;
	}

	protected function page_meta() {
	
		if ( !is_singular( apply_filters( 'yaga_display_meta_in_page_header', 'post' ) ) ) {
			return;
		}

		$this->check_display_meta();

		if ( $this->display_meta ) {
			echo '<div class="entry-meta pht-mt page-header-meta">';
				$this->display_date();
				$this->display_author();
				$this->display_categories();
				$this->display_comments();
			echo '</div><!-- .entry-meta -->'; 
		}
	}

	protected function check_display_meta() {

		$this->display_date = apply_filters( 'yaga_display_date_in_page_header', true );
		$this->display_author = apply_filters( 'yaga_display_author_in_page_header', true );
		$this->display_categories = apply_filters( 'yaga_display_categories_in_page_header', true );
		$this->display_comments = apply_filters( 'yaga_display_comments_in_page_header', true );

		$this->display_meta = $this->display_date || $this->display_author || $this->display_categories || $this->display_comments;
	}
	

	protected function display_date() {

		if ( !$this->display_date ) {
			return;
		}
		echo '<time class="entry-date" datetime="' . esc_attr( get_the_date( "c" ) ) . '">' . esc_html( get_the_date() ) . '</time>';

	}

	protected function display_author() {

		if ( !$this->display_author ) {
			return;
		}
		if ( $this->display_date ) {
			$this->separator();
		}
		$by = apply_filters( 'yaga_single_header_author_by' , esc_html__( 'by ', 'yaga' ) );
		printf( '<span class="author byline">'. $by .' <a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_attr( sprintf( esc_html__( 'View all posts by %s', 'yaga' ), get_the_author() ) ),
			get_the_author()
		);
	}

	protected function display_categories() {

		if ( !$this->display_categories ) {
			return;
		}
		$in = apply_filters( 'yaga_single_header_category_in' , esc_html__( 'in ', 'yaga' ) );

		if ( $this->display_date || $this->display_author ) {
			$this->separator();
		}
		the_terms( get_the_ID(), 'category', '<span class="categories-links">'. $in .' <span> ',', ','</span></span> ');

	}

	protected function display_comments() {

		if ( !$this->display_comments ) {
			return;
		}	
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {

			if ( $this->display_date || $this->display_author || $this->display_categories ) {
				$this->separator();
			}
			echo	' <span id="js-comments-link" class="entry-meta pointer nobr"><i class="pht-ic-f1-comments"></i>';
			comments_popup_link( ' <span class="leave-reply">' . esc_html__( '0', 'yaga' ) . '</span>', esc_html__( ' 1', 'yaga' ), esc_html__( ' %', 'yaga' ) );
			echo '</span> <!-- .comments-link -->';
		} 
	
	}

}

endif;