<?php
/**
 * Adds or overrides some PeHaa Themes Page Builder modules
 *
 *
 * @package Yaga
 * @author  PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_PHTPB_Addons' ) ) :

class Yaga_PHTPB_Addons {

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	public static $showcases_array = array();

	public static $contact_forms = array();

	public static $contact_form_ids = array();
	
	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {
		
		add_filter( 'phtpb_shortcode_template', array( $this, 'phtpb_shortcode_template' ), 10, 2 );
		add_filter( 'phtpb_config_data', array( $this, 'phtpb_config_data' ) );
		add_filter( 'phtpb_available_sidebars', array( $this, 'phtpb_available_sidebars' ) );

	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	public function phtpb_shortcode_template( $content, $name ) {
		return apply_filters( 'yaga_phtpb_shortcode_template', new Yaga_PeHaa_Themes_Page_Builder_Shortcode_Template( $name ), $name );
	}

	public function phtpb_available_sidebars( $sidebars ) {
	
		if ( isset( $sidebars['sidebar-2'] ) ) {
			unset( $sidebars['sidebar-2'] );
		}
	
		return $sidebars;
	}

	public function phtpb_config_data( $data ) {

		$margin_b_item = array(
			'title' => esc_html__( 'Bottom margin', 'yaga' ),
			'type' => 'checkbox',
			'default' => 'yes',
		);
		$options_array = PeHaa_Themes_Page_Builder::$phtpb_available_post_types;
		unset( $options_array['page'] );
		$lightbox_item = array(
			'title' => esc_html__( 'Open in Lightbox', 'yaga' ),
			'type' => 'checkbox',
			'default' => '',
			'description' => esc_html__( 'Check here if you want your image to open in a lightbox (full size).', 'yaga' )
		);

		$data_section_fields = $data['phtpb_section']['fields'];

		$data['phtpb_section']['fields'] = array(
			'admin_collapsed' => $data_section_fields['admin_collapsed'],
			'use_bg_color' => $data_section_fields['use_bg_color'],
			'bg_color' => $data_section_fields['bg_color'],
			'use_color' => $data_section_fields['use_color'],
			'color' => $data_section_fields['color'],
			'layout_option' => $data_section_fields['layout_option'],
			'scroll_down' => array(
				'title' => esc_html__( 'Scroll Down Link', 'yaga' ),
				'type' => 'select',
				'description' => esc_html__( 'Will be placed in the bottom of the section and smoothly scroll to the next section when clicked. Visible on screens that are minimum 1024px wide.', 'yaga' ),
				'options' => array(
					'default' => esc_html__( 'Display if section is set full height', 'yaga' ),
					'yes' => esc_html__( 'Display', 'yaga' ),
					'no' => esc_html__( 'Do not display', 'yaga' ),
				),
				'default' => 'default'
			),
			'background_image' => $data_section_fields['background_image'],
			'phtpb_id' => $data_section_fields['phtpb_id'],
			'opacity' => $data_section_fields['opacity'],
			'r_w' => $data_section_fields['r_w'],
			'r_h' => $data_section_fields['r_h'],
			'bg_video' => array(
				'title' => esc_html__( 'Background Video', 'yaga' ),
				'type' => 'video',
				'description' => esc_html__( 'Upload a mp4 video.', 'yaga' ),
				'default' => '',
			),
			'parallax' => array(
				'title' => esc_html__( 'Parallax effect', 'yaga' ),
				'type' => 'select',
				'description' => esc_html__( 'Choose a background effect while scrolling. Note that it will be applied on non-touch screens wider than 1024px.', 'yaga' ),
				'options' => array(
					'noparallax' => esc_html__( 'None', 'yaga' ),
					'parallax' => esc_html__( 'Subtle', 'yaga' ),
					'parallax2' => esc_html__( 'Fixed', 'yaga' ),
				),
				'default' => 'none'
			),
			'phtpb_type' => $data_section_fields['phtpb_type'],
		);

		$data['phtpb_section']['fields']['layout_option']['options']['full'] = esc_html__( 'Full height, no padding on small screens', 'yaga' );
		$data['phtpb_section']['fields']['layout_option']['options']['full-48'] = esc_html__( 'Full height, 48px padding on small screens', 'yaga' );
		$data['phtpb_section']['fields']['layout_option']['options']['full-96'] = esc_html__( 'Full height, 96px padding on small screens', 'yaga' );

		$data['phtpb_column']['fields']['animation']['options']['fly'] = $data['phtpb_column_inner']['fields']['animation']['options']['fly'] = esc_html__( 'Move Vertically on Scroll', 'yaga' );
		$data['phtpb_column']['fields']['animation']['options']['fade-fly'] = $data['phtpb_column_inner']['fields']['animation']['options']['fade-fly'] = esc_html__( 'Fade-in and Move Vertically on Scroll', 'yaga' );
		$data['phtpb_column']['fields']['animation']['description'] = $data['phtpb_column_inner']['fields']['animation']['description'] = esc_html__( 'A subtle fade-in effect. Move Vertically on Scroll/Fade-in and Move Vertically on Scroll apply to screens at least 1280px wide.', 'yaga' );
		$data['phtpb_column']['fields']['move_h'] = $data['phtpb_column_inner']['fields']['move_h'] = array(
			'title' => esc_html__( 'Move horizontally', 'yaga' ),
			'type' => 'text',
			'description' => esc_html__( 'You can shift your column horizontally, positive values correspond to the shift to the right, negative - shift to the left. The units used here are pixels. Use only numbers without units. Applies only to screens at least 1280px wide. Example: 48.', 'yaga' ),
			'default' => '0'
		);
		$data['phtpb_column']['fields']['move_v'] = $data['phtpb_column_inner']['fields']['move_v'] = array(
			'title' => esc_html__( 'Move vertically', 'yaga' ),
			'type' => 'text',
			'description' => esc_html__( 'You can shift your column vertically, positive values correspond to the shift down, negative - shift up. The units used here are pixels. Use only numbers without units. Applies only to screens at least 1280px wide. Example: 48.', 'yaga' ),
			'default' => '0'
		);
		$data['phtpb_column']['fields']['width'] = $data['phtpb_column_inner']['fields']['width'] = array(
			'title' => esc_html__( 'Increase width', 'yaga' ),
			'type' => 'text',
			'description' => esc_html__( 'You can increase/decrease the width of the column. The units used here are pixels. Use only numbers without units. Applies only to screens at least 1280px wide. Example: 48.', 'yaga' ),
			'default' => '0'
		);
		$data['phtpb_column']['fields']['z_index'] = $data['phtpb_column_inner']['fields']['z_index'] = array(
			'title' => esc_html__( 'Z index', 'yaga' ),
			'type' => 'select',
			'description' => esc_html__( 'You may need to use the z-index settings if your columns overlap and you want to change their order. The level values correspond to the order in which they are positioned, the column with a higher value will be positioned over the column with a lower value. Auto means a left to right natural order (the right column is positioned over its left neighbour).', 'yaga' ),
			'default' => 'auto',
			'options' => array(
				'auto' => esc_html__( 'Auto', 'yaga' ),
				'pht-z-204' => esc_html__( 'Level 1 (bottom)', 'yaga' ),
				'pht-z-205' => esc_html__( 'Level 2', 'yaga' ),
				'pht-z-206' => esc_html__( 'Level 3', 'yaga' ),
				'pht-z-207' => esc_html__( 'Level 4 (top)', 'yaga' ),
			),
		);

		$data['phtpb_image']['fields']['src1'] = array(
			'title' => esc_html__( 'Image on Hover', 'yaga' ),
			'type' => 'image',
			'description' => esc_html__( 'Optional.', 'yaga' ),
			'default' => ''
		);
		$data['phtpb_image']['fields']['phtpb_id1'] = array(
			'type' => 'image_id',
			'default' => '',
		);
		$data['phtpb_image']['fields']['d_w'] = array(
			'type' => 'hidden',
			'default' => '',
		);

		$data['phtpb_divider']['fields']['hide']['options']['portable'] =  esc_html__( 'Only on screens 1024px and more', 'yaga' );
		$data['phtpb_divider']['fields']['hide']['options']['below-wide'] = esc_html__( 'Only on screens 1280px and more', 'yaga' );

		$data['phtpb_posts'] = array(
			'label' =>  'phtpb_posts',
			'title' => esc_html__( 'Posts Grid', 'yaga' ),
			'icon' => 'fa fa-th-large',
			'phtpb_admin_type' => 'module',
			'fields' => array(
				'phtpb_type' => array(
					'title' => esc_html__( 'Post type', 'yaga' ),
					'type' => 'select',
					'options' => $options_array,
					'description' => esc_html__( 'Choose the query.', 'yaga' ),
				),
				'count' => array(
					'title' => esc_html__( 'Posts count', 'yaga' ),
					'type' => 'text',
					'default' => '',
					'description' => esc_html__( 'Number of posts. Set -1 to display all posts.', 'yaga' ),
				),
				'pagination' => array(
					'title' => esc_html__( 'Pagination', 'yaga' ),
					'type' => 'checkbox',
					'description' => esc_html__( 'Check to turn on the pagination', 'yaga' ),
				),
				'phtpb_query' => array(
					'title' => esc_html__( 'Custom query', 'yaga' ),
					'type' => 'text',
					'description' => esc_html__( 'You can modify the query here, e.g. ', 'yaga' ) . '<em>orderby=title&order=ASC</em>',
				),
				'skip' => array(
					'title' => esc_html__( 'Skip summary', 'yaga' ),
					'type' => 'checkbox',
					'default' => ''
				),
				'fixed_height' => array(
					'title' => esc_html__( 'All images with the same height', 'yaga' ),
					'type' => 'checkbox',
					'default' => ''
				),
				'margin_b' => $margin_b_item,
			),
			'phtpb_admin_mode' => 'simple',
			'create_with_settings' => true
		);


		$options_array = $options_array_string = array();
		$showcase_post_types = PeHaa_Themes_Page_Builder::$phtpb_available_post_types;
		unset( $showcase_post_types['page'] );

		if ( count( $showcase_post_types ) ) {

			foreach ( $showcase_post_types as $showcase_post_type_key => $showcase_post_type_name ) {
				$taxonomy_names = get_object_taxonomies( $showcase_post_type_key );
				$options_array[] = $showcase_post_type_name . esc_html__( ' (no filtering)', 'yaga' );
				$options_array_string[ $showcase_post_type_key.'::__' ] = $showcase_post_type_name . esc_html__( ' (no filtering)', 'yaga' );
				self::$showcases_array[] = array( 'item' => $showcase_post_type_key, 'taxonomy' => '' );
				if ( count( $taxonomy_names ) ) {
					foreach ( $taxonomy_names as $taxonomy_name ) {
						$options_array_string[ $showcase_post_type_key.'::'.$taxonomy_name ] = $showcase_post_type_name . ' :: ' . get_taxonomy( $taxonomy_name )->labels->name;
						$options_array[] = $showcase_post_type_name . ' :: ' . get_taxonomy( $taxonomy_name )->labels->name;
						self::$showcases_array[] = array( 'item' => $showcase_post_type_key, 'taxonomy' =>$taxonomy_name );
					}
				}

			}
			
			if ( count( self::$showcases_array ) ) {
				$data['phtpb_showcase'] = array(
					'label' =>  'phtpb_showcase',
					'title' => esc_html__( 'Filtrable Portfolio', 'yaga' ),
					'icon' => 'fa fa-th',
					'phtpb_admin_type' => 'module',
					'fields' => array(
						'phtpb_type' => array(
							'title' => esc_html__( 'Post type:: Filtered by', 'yaga' ),
							'type' => 'select',
							'options' => $options_array_string,
							'description' => esc_html__( 'Choose the query.', 'yaga' ),
						),
						'phtpb_query' => array(
							'title' => esc_html__( 'Custom query', 'yaga' ),
							'type' => 'text',
							'description' => esc_html__( 'You can modify the query here, e.g.', 'yaga' ) . '<em>orderby=title&order=ASC</em>',
						),
						'layout_option' => array(
							'title' => esc_html__( 'Layout Option', 'yaga' ),
							'type' => 'select',
							'default' => '2c',
							'options' => array(
								'2c' => esc_html__( 'Classic 2 columns', 'yaga' ),
								'3c' => esc_html__( 'Classic 3 columns', 'yaga' ),
								'4c' => esc_html__( 'Classic 4 columns', 'yaga' ),
								'5c' => esc_html__( 'Classic 5 columns', 'yaga' ),
								'6c' => esc_html__( 'Classic 6 columns', 'yaga' ),
								'2' => esc_html__( 'Masonry 2 columns', 'yaga' ),
								'3' => esc_html__( 'Masonry 3 columns', 'yaga' ),
								'4' => esc_html__( 'Masonry 4 columns', 'yaga' ),
								'5' => esc_html__( 'Masonry 5 columns', 'yaga' ),
								'6' => esc_html__( 'Masonry 6 columns', 'yaga' ),
								'1' => esc_html__( 'One column', 'yaga' ),
							),
						),
						'gutter' => array(
							'title' => esc_html__( 'Gutter', 'yaga' ),
							'type' => 'select',
							'default' => '24',
							'options' => array(
								'24' => '24px',
								'12' => '12px',
								'6' => '6px',
								'none' => esc_html__( 'None', 'yaga' )
							),
						),
						'count' => array(
							'title' => esc_html__( 'Posts count', 'yaga' ),
							'type' => 'text',
							'default' => -1,
							'description' => esc_html__( 'Number of posts. Set -1 to display all posts.', 'yaga' ),
						),
						'all_label' => array(
							'title' => esc_html__( 'All items label', 'yaga' ),
							'type' => 'text',
							'default' => esc_html__( 'All', 'yaga' ),
							'description' => esc_html__( 'The label for all items - will be used for filtrable portfolios.', 'yaga' ),
						),
						'lightbox' => $lightbox_item,
						'margin_b' => $margin_b_item,
					),
					'phtpb_admin_mode' => 'simple',
					'create_with_settings' => true,
				);

			}

		}

		$post_types = array();
		foreach ( PeHaaThemes_Theme_Start::$single_items as $post_slug ) {
			$post_types[ $post_slug ] = $post_slug;
		}
		
		$data['phtpb_widget_recent_posts'] = array(
			'label' =>  'phtpb_widget_recent_posts',
			'title' => esc_html__( 'Recent Posts with Thumbnails', 'yaga' ),
			'icon' => 'fa fa-wordpress',
			'widget' => 'Yaga_Widget_Recent_Posts',
			'phtpb_admin_type' => 'module',
			'fields' => array(
				'title' => array(
					'title' => esc_html__( 'Title', 'yaga' ),
					'type' => 'text',
					'default' => '',
					'description' => esc_html__( 'What text use as a widget title. Leave blank to use default widget title.', 'yaga' )
				),
				'post_type' => array(
					'title' => esc_html__( 'Post type', 'yaga' ),
					'type' => 'select',
					'options' => $post_types,
					'default' => 'post',
					'description' => esc_html__( 'Choose the Post Type to display', 'yaga' )
				),
				'number' => array(
					'title' => esc_html__( 'Number of posts to show', 'yaga' ),
					'type' => 'text',
					'default' => 5,
				),
				'show_date' => array(
					'title' => esc_html__( 'Display post date?', 'yaga'  ),
					'type' => 'checkbox',
				),
				'margin_b' => $margin_b_item,
			),
			'phtpb_admin_mode' => 'simple',
			'create_with_settings' => true
		);

		self::$contact_forms = array();
		if ( class_exists( 'WPCF7_ContactForm' ) && is_admin() ) {
			global $wpdb;
			$cf7 = $wpdb->get_results(
				"
			  SELECT ID, post_title
			  FROM $wpdb->posts
			  WHERE post_type = 'wpcf7_contact_form'
			  "
			);
			
			if ( $cf7 ) {
				foreach ( $cf7 as $cform ) {
					self::$contact_forms[ $cform->ID ] = $cform->post_title;
					self::$contact_form_ids[] = $cform->ID;
				}
			} else {
				self::$contact_forms[0] = esc_html__( 'No contact forms found', 'yaga' );
			}
		} // if contact form7 plugin active
		$phtpb_config_data['phtpb_contact_form7'] = array(
			'label' =>  'phtpb_contact_form7',
			'title' => esc_html__( 'Contact Form', 'yaga' ),
			'icon' => 'fa fa-envelope',
			'phtpb_admin_type' => 'module',
			'fields' => array(
				'phtpb_id' => array(
					'title' => 'Contact form',
					'type' => 'select',
					'options' => self::$contact_forms,
				),
				'margin_b' => $margin_b_item,
			),
			'phtpb_admin_mode' => 'simple',
			'create_with_settings' => true,
			'is_disabled' => ! class_exists( 'WPCF7_ContactForm' )
		);

		if ( apply_filters( 'phtpb_supports_revolution_slider', false ) ) {

			$rev_sliders = array();

			if ( class_exists( 'RevSlider' ) ) {

				$slider = new RevSlider();
				
				$arrSliders = $slider->getArrSliders();
				
				if ( $arrSliders ) {

					foreach ( $arrSliders as $rev_slider ) {
						
						$rev_sliders[ $rev_slider->getAlias() ] = $rev_slider->getTitle();
						
					}	
				}
			}

			$data['phtpb_revslider'] = array(
				'label' =>  'phtpb_revslider',
				'title' => esc_html__( 'Revolution Slider', 'yaga' ),
				'icon' => 'fa fa-tags',
				'phtpb_admin_type' => 'module',
				'fields' => array(
					'phtpb_id' => array(
						'title' => esc_html__( 'Choose slider', 'yaga' ),
						'type' => 'select',
						'options' => $rev_sliders
					),
				),
				'phtpb_admin_mode' => 'simple',
				'create_with_settings' => true,
				'is_disabled' => ! class_exists( 'RevSlider' )
			);		

		}


	$data_gallery_fields = $data['phtpb_gallery']['fields'];
	$data['phtpb_gallery']['fields'] = array();
	$data['phtpb_gallery']['fields']['phtpb_ids'] =  $data_gallery_fields['phtpb_ids'];
	$data['phtpb_gallery']['fields']['layout_option'] = array(
		'title' => esc_html__( 'Layout Option', 'yaga' ),
		'type' => 'select',
		'default' => 'default',
		'options' => array(
			'default' => esc_html__( 'Default Gallery', 'yaga' ),
			'1c' => esc_html__( 'Classic one column', 'yaga' ),
			'2c' => esc_html__( 'Classic 2 columns', 'yaga' ),
			'3c' => esc_html__( 'Classic 3 columns', 'yaga' ),
			'4c' => esc_html__( 'Classic 4 columns', 'yaga' ),
			'5c' => esc_html__( 'Classic 5 columns', 'yaga' ),
			'6c' => esc_html__( 'Classic 6 columns', 'yaga' ),
			'2' => esc_html__( 'Masonry 2 columns', 'yaga' ),
			'3' => esc_html__( 'Masonry 3 columns', 'yaga' ),
			'4' => esc_html__( 'Masonry 4 columns', 'yaga' ),
			'5' => esc_html__( 'Masonry 5 columns', 'yaga' ),
			'6' => esc_html__( 'Masonry 6 columns', 'yaga' ),
		),
	);
	$data['phtpb_gallery']['fields']['border_width'] =  $data_gallery_fields['border_width'];
	$data['phtpb_gallery']['fields']['lightbox'] =  $data_gallery_fields['lightbox'];
	$data['phtpb_gallery']['fields']['margin_b'] =  $data_gallery_fields['margin_b'];
	


		return $data;

	}

}
endif;