<?php
/**
 * Detects if there a sidebar to be displayed and if it's a woocommerce specific one or a standard one.
 *
 *
 * @package Yaga
 * @author  PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Sidebar' ) ) :

class Yaga_Sidebar {

	protected static $instance;

	protected $wc_sidebar_is_defined;

	protected $sidebar_id;

	protected $wc_sidebar_id = NULL;

	protected $is_woocommerce = false;

	public $display = false;

	public $display_id = NULL;

	public $position = 'right';

	public $display_footer = false;

	public $display_footer_id = NULL;

	private function __construct() {

		$this->wc_sidebar_is_defined = (boolean) apply_filters( 'yaga_wc_sidebar', NULL );

		$this->wc_footer_is_defined = (boolean) apply_filters( 'yaga_wc_footer', NULL );

		$this->sidebar_id = 'sidebar-1';

		$this->wc_sidebar_id = apply_filters( 'yaga_wc_sidebar', NULL );

		$this->footer_id = 'sidebar-2';

		$this->wc_footer_id = apply_filters( 'yaga_wc_footer', NULL );

		$this->is_woocommerce();

		$this->detect_sidebar();

		$this->detect_footer();

	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	private function is_woocommerce() {

		if ( ! class_exists( 'woocommerce' ) ) {
			return;
		}
		if ( ! function_exists( 'is_woocommerce' ) ) {
			return;
		}
		if ( is_woocommerce() ) {
			$this->is_woocommerce = true;
			return;
		}
		$this->is_woocommerce = class_exists( 'Yaga_WooCommerce' ) && Yaga_WooCommerce::pages_with_wc_sidebar();

	}

	private function wc_sidebar_is_active() {

		if ( !$this->wc_sidebar_id ) {
			return;
		}

		return is_active_sidebar( $this->wc_sidebar_id );
	}

	private function detect_sidebar() {

		if ( $this->is_woocommerce && $this->wc_sidebar_is_defined ) {

			if  ( !$this->wc_sidebar_is_active() ) {
				return;
			}
			if ( is_shop() ) {
				if ( ! get_theme_mod( 'yaga_sidebar_on_shop_page' ) ) {
					return;
				}
			} elseif ( is_archive() ) {
				if ( ! get_theme_mod( 'yaga_sidebar_on_wc_archives' ) ) {
					return;
				}
			} elseif ( is_singular( 'product' ) ) {
				if ( ! get_theme_mod( 'yaga_sidebar_on_single_product' ) ) {
					return;
				}
			} elseif ( !$this->check_skip_sidebar_meta( PeHaaThemes_Theme_Config::$id ) ) {
				return;
			}

			$this->display_id = $this->wc_sidebar_id;

		} else {

			if ( PeHaaThemes_Theme_Config::$use_phtpb ) {
				return;
			}

			if ( ! is_active_sidebar( $this->sidebar_id ) ) {
				return;
			}

			if ( is_home() && is_front_page() ) {

				if ( ! get_theme_mod( 'yaga_blog_sidebar', '1' ) ) {
					return;
				}

			} elseif ( PeHaaThemes_Theme_Config::$id ) {
				if ( ! $this->check_skip_sidebar_meta( PeHaaThemes_Theme_Config::$id ) ) {
					return;
				}
			}

			

			$this->display_id = $this->sidebar_id;
		}

		$this->display = true;
		$this->position = get_theme_mod( 'yaga_sidebar_position', 'right' );

	}

	private function detect_footer() {

		if ( $this->is_woocommerce &&  $this->wc_footer_is_defined ) {

			if ( ! is_active_sidebar( $this->wc_footer_id ) ) {
				return;
			}

			$this->display_footer = true;
			$this->display_footer_id = $this->wc_footer_id;

		} else {

			if ( ! is_active_sidebar( $this->footer_id ) ) {
				return;
			}
			$this->display_footer = true;
			$this->display_footer_id = $this->footer_id;
		}

	}

	private function check_skip_sidebar_meta( $id ) {

		if ( ! $id ) {
			return;
		}
		$skip_elements = get_post_meta( $id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_skip_elements' , true );
		if ( $skip_elements && in_array( 'sidebar', $skip_elements ) ) {
			return;
		}
		return true;
	}

}

endif;