<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Single_View' ) ) :

class Yaga_Single_View extends Yaga_View {

	private $extras_layout_class = '';

	public function __construct( $post = 0 ) {

		if ( ! $post = get_post( $post ) ) {
			return;
		}
			
		PeHaaThemes_Theme_Config::$sidebar = Yaga_Sidebar::get_instance();
		$this->post = $post;
		$this->post_type = $this->post->post_type;
		$this->id = $this->post->ID;
		$this->post_type = get_post_type( $this->id );
		$this->sidebar = isset( PeHaaThemes_Theme_Config::$sidebar->display ) ? PeHaaThemes_Theme_Config::$sidebar->display : true;
		$this->sidebar_position = isset( PeHaaThemes_Theme_Config::$sidebar->position ) ? PeHaaThemes_Theme_Config::$sidebar->position : 'right';

		$this->display_elements();
		$this->check_use_PHTPB();

		$this->is_on_next_page = get_query_var( 'page' );
	
	}

	private function check_use_PHTPB() {
 
		$this->use_PHTPB = PeHaaThemes_Theme_Config::$use_phtpb;
		
		if ( $this->use_PHTPB ) {
			$this->extras_layout_class = 'pht-wrapper';
		}
	}

	public function header() {
		if ( !in_array( 'header', $this->skip_elements ) || post_password_required( $this->id ) ) {
			$this->header = new Yaga_Page_Header( $this->id, $this->is_on_next_page );
			$this->header->display_header();
		}
	}

	private function display_elements() {

		$elements = array( 'featured', 'author', 'taxonomies', 'comments', 'related' );

		$this->skip_elements = get_post_meta( $this->id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_skip_elements', true ) ? get_post_meta( $this->id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_skip_elements', true ) : array();

		foreach ( $elements as $el ) {

			if ( 'comments' === $el ) {
				$default = in_array( $this->post_type, apply_filters( 'yaga_post_types_with_' . $el . '_displayed', array_merge( array( 'page' ), PeHaaThemes_Theme_Start::$single_items ), $this->post_type ) );
			} else {
				$default = in_array( $this->post_type, apply_filters( 'yaga_post_types_with_' . $el . '_displayed', PeHaaThemes_Theme_Start::$single_items, $this->post_type ) );
			}
			
			$this->$el = $default && !in_array( $el, $this->skip_elements );
		}
		if ( $this->comments ) {

			$this->comments = ( comments_open() || get_comments_number() );

		}

		$this->display_extras = $this->author || $this->taxonomies || $this->comments;
	}

	public function start_container() {
		$this->start_wrapper();
		$this->start_grid();
	}

	public function end_container() {
		$this->end_grid();
		$this->end_wrapper();
	}

	private function start_wrapper() {
		$class = 'content-and-sidebar-area pht-wrapper';
		
		if ( $this->use_PHTPB ) {
			$class = 'content-and-sidebar-area content-and-sidebar-area__fpb';
		}
			
		echo "<div id='content-and-sidebar-area' class='$class'>";
	}

	public function end_wrapper() {
		echo '</div>';
	}

	private function start_grid() {

		if ( $this->use_PHTPB ) {
			return;
		}
		if ( !$this->sidebar ) {
			return;
		}
		echo "<div class='" . esc_attr( $this->layout_class() ) . "'>";
	}

	private function end_grid() {
		
		if ( $this->use_PHTPB ) {
			return;
		}
		if ( !$this->sidebar ) {
			return;
		}
		echo '</div>';
	}

	private function post_thumbnail() {

		if ( post_password_required() ) {
			return;
		}

		if ( $this->is_on_next_page ) {
			return;
		}

		if ( !has_post_thumbnail() || !$this->featured ) {
			return;
		}

		echo "<figure class='post-thumbnail $this->extras_layout_class'>"; 
			the_post_thumbnail( $this->thumbnail_size(), array( 'class' => 'single-thumbnail' ) ); 
			do_action( 'yaga_after_the_post_thumbnail' );
		echo '</figure>';
		

	}


	public function content() {

		if ( !$this->post ) {
			return;
		} ?>

		<article id="post-<?php the_ID(); ?>" <?php post_class( $this->post_class() ); ?>>
			<?php $this->post_thumbnail(); ?>

			<div class="entry-content cf">
				<?php
				do_action( 'yaga_just_before_the_content' );
				the_content();
				do_action( 'yaga_just_after_the_content' );
				wp_link_pages( array(
					'before'      => '<p class="nav pht-box pht-box--highlight pht-mt pht-wplp pht-actionfont container-a container-a--h">',
					'after'       => '</p>',
					'link_before' => '<span>',
					'link_after'  => '</span>',
				) ); ?>
			</div><!-- .entry-content -->
			<?php $this->extras();
		if ( $this->use_PHTPB ) {
			echo '</article>';
		} else {
			echo '</article><!--';
		}
			
	}

	public function get_sidebar() {

		if ( $this->use_PHTPB ) {
			return;
		}
		get_sidebar();
	}

	private function extras() {

		if ( ! $this->display_extras ) {
			return;
		}

		echo '<div class="pht-wrapper">';

		$this->taxonomies_terms_links();
		$this->author_bio();
		$this->comments();

		echo '</div>';

	}

	private function taxonomies_terms_links() {

		if ( ! $this->taxonomies ) {
			return;
		}
		$out = '';
		$separator = apply_filters( 'yaga_inline_separator', ' &middot; ' );
		$taxonomies = get_object_taxonomies( $this->post->post_type, 'objects' );

		if ( empty( $taxonomies ) ) {
			return;
		}
		
		$taxonomies_array = array();

		foreach ( $taxonomies as $taxonomy_slug => $taxonomy ) {
			//only post tags for posts
			if ( 'post' === $this->post->post_type && 'post_tag' !== $taxonomy_slug ) {
				continue;
			}

			$terms = 'post_tag' === $taxonomy_slug ? get_the_tags( $this->id ) : get_the_terms( $this->id, $taxonomy_slug );

			if ( !empty( $terms ) ) {
				
				$taxonomies_array[] = array( 
					'slug' => $taxonomy_slug,
					'terms' => $terms,
					'label' =>  $taxonomy->label );
			}
		
		}

		if ( !empty( $taxonomies_array ) ) { ?>
			<div class="pht-zeta pht-box pht-box--hlines container-a--h">
			<?php
				foreach ( $taxonomies_array as $taxonomies_row ) {
					printf( '<h5 class="pht-heading pht-mb0">%s</h5>', esc_html( apply_filters( 'yaga_taxonomy_term_links_title_' . $taxonomies_row['slug'], $taxonomies_row['label'] ) ) );
					echo '<p>';
					$i = 0;
					$count_terms = count( $taxonomies_row['terms'] );
					foreach ( $taxonomies_row['terms'] as $term ) {
						$i++;
						printf( ' <span><a href="%1$s">%2$s</a></span>%3$s',
							esc_url( get_term_link( $term->slug, $taxonomies_row['slug'] ) ),
							esc_html( $term->name ),
							$i === $count_terms ? '' : esc_html( $separator )
						);	
					}
					echo '</p>';
				}
			?>
			</div>
		<?php }

	}

	public function author_bio() {

		if ( ! $this->author || !( get_the_author_meta( 'ID' ) ) || ! get_the_author_meta( 'description' ) ) {
			return;
		}

		echo '<div class="author-info pht-box pht-box--highlight pht-mb pht-mt pht-zeta">';
		get_template_part( 'author-bio' );
		echo '</div><!-- .author-info -->';
	}

	private function comments() {
		if ( ! $this->comments ) {
			return;
		}
		comments_template();
	}


	public function related_posts_slider() {

		if ( ! $this->related ) {
			return;
		}

		$related_posts = self::related_posts( $this->id, $this->post_type, apply_filters( 'yaga_related_posts_count', 5 ) );

		if ( $related_posts && count( $related_posts ) >= apply_filters( 'yaga_related_starts_display_from', 5 ) ) { ?>
			
			<section class="posts-carousel pht-parent pht-text-center pht-box--highlight cf">
				<div class="posts-carousel__wrapper">
					<header class="pht-text-center pht-box">
						<?php printf( '<h2 class="pht-heading pht-mb0">%s</h2>', apply_filters( 'yaga_related_posts_title', esc_html__( 'You may also like', 'yaga' ) ) ); ?>	
					</header>
					<?php self::posts_carousel( $related_posts, 'yaga-post-grid-gallery', apply_filters( 'yaga_related_starts_display_from', 5 ) ); ?>
				</div>
			</section><!-- .posts-carousel -->	
		
		<?php }

	}

	static function related_posts( $post_id, $post_type, $default_count = 5, $only_with_thumbnail = true ) {

		if ( 'post' !== $post_type ) {
			return self::related_posts_for_custom_post_type( $post_id, $post_type, $default_count, $only_with_thumbnail );
		}
		$tags = wp_get_post_tags( $post_id, array( 'fields' => 'ids' ) );
		$args = array(
			'posts_per_page' => $default_count,
			'post__not_in' => array( $post_id ),
			'ignore_sticky_posts' => 0 );
		if ( $only_with_thumbnail )
			$args['meta_key'] = '_thumbnail_id';
		if ( $tags ) {
			$args['tag__in'] = $tags;
			$used_taxonomy = 'tags';
		} else {
			$args['category__in'] = wp_get_post_categories( $post_id );
			$used_taxonomy = 'categories';
		}
		$posts = get_posts( $args );

		if ( $posts ) {
			$count = count( $posts );
			if ( $default_count === $count ) { 
				return $posts;
			}
			foreach ( $posts as $post ) {
				$args['post__not_in'][] = $post->ID;
			}

			$args['posts_per_page'] = $default_count - $count;	
			$args['tag__in'] = '';
			if ( 'tags' === $used_taxonomy ) {
				$args['category__in'] = wp_get_post_categories( $post_id );
			} else {
				$args['category__in'] = '';
			}
			
			$new_posts = get_posts( $args );
			$posts = array_merge( $posts, $new_posts );
			$count = count( $posts );
			if ( $default_count === $count || 'categories' === $used_taxonomy ) {
				return $posts;
			}
			foreach ( $posts as $post ) {
				$args['post__not_in'][] = $post->ID;
			}
			$args['posts_per_page'] = $default_count - $count;
			$args['category__in'] = '';
			$new_posts = get_posts( $args );
			$posts = array_merge( $posts, $new_posts );
		}

		return $posts;

	}

	private static function related_posts_for_custom_post_type( $post_id, $post_type, $default_count = 5, $only_with_thumbnail = true ) {

		$post_not_in = array( $post_id );
		$args = array(
			'post_type' => $post_type,
			'posts_per_page' => $default_count,
			'post__not_in' => $post_not_in,
			'ignore_sticky_posts' => 0 );
		if ( $only_with_thumbnail ) {
			$args['meta_key'] = '_thumbnail_id';
		}
			

		$posts = get_posts( $args );

		return $posts;

	}

	public function post_nav() {

		if ( ! $this->post ) {
			return;
		}
		
		$previous = is_attachment() ? get_post( $this->post->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );
		$icon_link_prev = "<span class='pht-gamma icon-link pht-text-center pht-ic-f1-caret-left hidden--portable'></span>";
		$icon_link_next = "<span class='pht-gamma icon-link pht-text-center pht-ic-f1-caret-right hidden--portable'></span>";

		if ( ! $next && ! $previous ) {
			return;
		}
			
		$next_thumbnail = $prev_thumbnail = '';

		if ( $next ) {
			$next_thumbnail = get_the_post_thumbnail( $next->ID, 'thumbnail', array( 'class' => 'media__img' ) );
		}

		if ( $previous ) {
			$prev_thumbnail = get_the_post_thumbnail( $previous->ID, 'thumbnail', array( 'class' => 'media__img' ) );
		} ?>

		<nav class="navigation post-navigation post-navigation--sticky pht-wrapper cf">

			<h3 class="screen-reader-text"><?php esc_html_e( 'Post navigation', 'yaga' ); ?></h3>

			<div class="prev-link pht-layout__item u-1-of-2-lap u-1-of-2-desk">

			<?php $media_class = 'side' === get_theme_mod( 'yaga_navigation', 'default' ) ? 'pht-box--highlight' : ''; 

			previous_post_link( '%link', $icon_link_prev . '<div class="media media--tiny pht-mb pht-mt ' . $media_class . '">' . $prev_thumbnail . '<div class="post-title media__body pht-box pht-box--small pht-secondfont pht-truncate"><div class="pht-subtitle">' . apply_filters( 'yaga_link_text_previous_' . $this->post->post_type, esc_html__( 'Previous', 'yaga' ) ) . '</div>%title</div></div>' ); ?>

			</div><!--
			--><div class="next-link pht-layout__item u-1-of-2-lap u-1-of-2-desk">

			<?php next_post_link( '%link', $icon_link_next . '<div class="media media--tiny media--rev pht-mb pht-mt ' . $media_class . '">' . $next_thumbnail . '<div class="post-title media__body pht-box pht-box--small pht-secondfont pht-truncate"><div class="pht-subtitle">' . apply_filters( 'yaga_link_text_next_' . $this->post->post_type, esc_html__( 'Next', 'yaga' ) ) . '</div>%title</div></div>' ); ?>

			</div>


	</nav><!-- .navigation -->
	
	<?php }

}

endif;