<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Site_Header' ) ) :

class Yaga_Site_Header {

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	protected $headings_font_face_class;

	public static $display_preloader  = false;

	public static $fullpage_logo = false;

	public static $display_site_title = false;

	public static $display_site_tagline = false;

	public static $display_menu = true;

	private $logo_alt = false;

	private $search_in_nav;

	protected $transparency_css_class = '';

	/**
	 * Initialize the plugin by loading admin scripts & styles and adding a
	 * settings page and menu.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		self::$display_site_title = !get_theme_mod( 'yaga_hide_title' );
		self::$display_site_tagline = !get_theme_mod( 'yaga_hide_tagline' );

		$this->search_in_nav = PeHaaThemes_Theme_Config::$search_in_nav && get_theme_mod( 'yaga_search_in_nav', '1' );

		$this->check_for_preloader();
		$this->check_for_fullpage_logo();
 		if ( !post_password_required( PeHaaThemes_Theme_Config::$id ) && !in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_fixed', 'top_fixed_center' ) ) ) {
 			$this->logo_choice = get_post_meta( PeHaaThemes_Theme_Config::$id,  PeHaaThemes_Theme_Start::$mb_prefix . 'choose_logo', true );
 		} else {
 			$this->logo_choice = false;
 		}
		add_filter( 'yaga_site_header_class', array( $this, 'check_transparency' ) );
	
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;
	}

	public function site_header_classes() {
		
		$classes =  array();
		$classes[] = $this->search_in_nav ? 'header--search' : 'header--no-search';
		$classes[] = 'side' === PeHaaThemes_Theme_Config::$navigation ? 'pht-box--highlight' : '';
		$classes =  apply_filters( 'yaga_site_header_class', $classes );
		return implode( ' ', $classes );

	}

	public function check_transparency( $classes ) {
		
		if ( PeHaaThemes_Theme_Config::$id ) {

			if ( post_password_required( PeHaaThemes_Theme_Config::$id ) ) {
				return $classes;
			}
						
			if ( !in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_full', 'top_fixed_center', 'top_fixed_fixed' ) ) ) {
				$text_color = get_post_meta( PeHaaThemes_Theme_Config::$id,  PeHaaThemes_Theme_Start::$mb_prefix . 'transparent_site_header_color', true );
				if ( $text_color && in_array( $text_color, array( 'dark', 'light', 'lap_up_dark', 'lap_up_light' ) ) ) {
					$classes[] = "site-header--$text_color";
					$this->transparency_css_class = "pht--$text_color";
				}
			}

			if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'sticky_center', 'sticky_full' ) ) ) {
				$skip_elements = get_post_meta( PeHaaThemes_Theme_Config::$id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_skip_elements', true ) ? get_post_meta( PeHaaThemes_Theme_Config::$id, PeHaaThemes_Theme_Start::$mb_prefix . 'post_skip_elements', true ) : array();
				if ( in_array( 'navigation', $skip_elements ) ) {
					$classes[] = "site-header--skip-non-sticky";
				}
				if ( in_array( 'title', $skip_elements ) ) {
					$classes[] = "site-header--hide-title";
				}
			}
		}

		return $classes;

	}

	public function header_html() { ?>

		<header id="masthead" class="cf site-header pht-parent site-navigation site-header--container <?php echo esc_attr( $this->site_header_classes() );?>">
			
			<?php 
			if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_full', 'top_fixed_center', 'top_fixed_fixed' ) ) ) { ?>
			<div class="site-header__bar">
			<?php }
			$this->display_logo_area();
			 			
			self::$display_menu = apply_filters( 'yaga_display_main_navigation', true );
			
			if ( self::$display_menu ) { 
				$nav_class = 'default' === PeHaaThemes_Theme_Config::$navigation ? 'pht-closed' : ''; 
				$nav_class .= $this->search_in_nav ? ' main-nav__ctnr--w-srch' : ' main-nav__ctnr--no-srch'; 
				$nav_class .= ' main-nav__ctnr--' . PeHaaThemes_Theme_Config::$navigation;
				if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_full', 'top_fixed_center' ) ) ) {
					$nav_class .= ' main-nav__ctnr--top_fixed';
				}
				if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'sticky_full', 'sticky_center' ) ) ) {
					$nav_class .= ' main-nav__ctnr--sticky';
				}
				if ( in_array( pehaathemes_get_theme_mod_not_empty( 'yaga_ml', 'normal' ), array( 'normal', 'tiny', 'no' ) ) ) {
					$nav_class .= ' main-nav__ctnr--' . get_theme_mod( 'yaga_ml' ) . '-ml';
				}
				?>
				<nav id="pht-main-nav__ctnr" class="main-nav__ctnr js-main-nav__ctnr main-nav__ctnr-m-closed <?php echo esc_attr( $nav_class ); ?>">
					<?php if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'sticky_full', 'sticky_center', 'top_fixed_center' ) ) ) {
							$this->home_link( NULL, 'pht-mini-logo__link', $this->mini_logo() );
						} ?>
					<ul class="main-nav__ul">
						<?php
						$this->main_navigation();
						$this->cart_and_search();
						?>
					</ul>
				</nav>
				<?php
			if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_full', 'top_fixed_center', 'top_fixed_fixed' ) ) ) { ?>
			</div>
			<?php }
				$this->toggle_menu();
				$this->search_area();
			} else {
				do_action( 'yaga_replace_main_navigation' );
			} ?>
			
			
		</header><!-- #masthead -->

	<?php }

	protected function mini_logo( $class = 'pht-mini-logo__img' ) {

		$url = get_theme_mod( 'yaga_mini_logo' );


		if ( !$url ) {
			return;
		}

		return $this->img_wrap( $url, $class );
		
		
		
	}

	private function check_for_preloader() {

		if ( is_404() ) {
			return;
		}

		$preloader_in = get_theme_mod( 'yaga_preloader_in', 'on_check_and_archives' );
		
		if ( 'never' === $preloader_in ) {
			return;
		}
		if ( 'always' === $preloader_in ) {
			self::$display_preloader = true;
			return;
		}
		if ( 'on_check_and_archives' === $preloader_in ) {
			if ( is_archive() || ( is_home() && is_front_page() ) ) {
				self::$display_preloader = true;
				return;
			}
		}
		if ( PeHaaThemes_Theme_Config::$id ) {
			self::$display_preloader = get_post_meta( PeHaaThemes_Theme_Config::$id,  PeHaaThemes_Theme_Start::$mb_prefix . 'page_preloader', true );
		}
	}

	private function check_for_fullpage_logo() {

		self::$fullpage_logo = pehaathemes_get_theme_mod_not_empty( 'yaga_logo' ) ? 'standard' : false;

		if ( !PeHaaThemes_Theme_Config::$id || !self::$fullpage_logo ) {
			
			return;
		}

		if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_fixed', 'top_fixed_center' ) ) ) {
			return;
		} else {
			$logo_meta_choice = get_post_meta( PeHaaThemes_Theme_Config::$id,  PeHaaThemes_Theme_Start::$mb_prefix . 'choose_logo', true );
		}

		if ( !$logo_meta_choice || 'standard' === $logo_meta_choice ) {
			return;
		}
		
		if ( pehaathemes_get_theme_mod_not_empty( 'yaga_logo_alt' ) && in_array( $logo_meta_choice, array( 'alt', 'both' ) ) ) {
			self::$fullpage_logo = 'alt';
			return;
		}
		
		return;
	}

	private function home_link( $id = NULL, $class, $content ) {

		if ( ! $content ) {
			return;
		}

		$id_string = '';

		if ( $id ) {
			$id_string = 'id="' . esc_attr( $id ) . '"';
		}

		echo "<a $id_string class='$class' href='" . esc_url( home_url( '/' ) ) . "' title='" . esc_attr( get_bloginfo( 'name', 'display' ) ) . "' rel='home'>$content</a>";

	}

	private function check_display_logo_area() {

		$this->standard_logo = pehaathemes_get_theme_mod_not_empty( 'yaga_logo' );

		if ( $this->logo_choice ) {
					
			if ( 'alt' === $this->logo_choice || 'both' === $this->logo_choice ) {
				$this->logo_alt = pehaathemes_get_theme_mod_not_empty( 'yaga_logo_alt' );
			}			
		}
		return true;
	}

	public function display_logo_area( $id = 'site-header-home-link', $class = 'site-header--home-link a-a a-a--no-h' ) {
		
		if ( !$this->check_display_logo_area() ) {
			return;
		}
		
		$content = '';

		$class .= " $this->transparency_css_class"; 

		if ( $this->standard_logo ) {
			$text_size_class = ( 'top_fixed_fixed' === PeHaaThemes_Theme_Config::$navigation ) ? 'pht-beta' : 'pht-alpha';
			$h1_class = self::$display_site_title ? "h1-img-title  pht-mb0" : 'h1-img-no-title';
			$content .= "<span class='h1-img logo $h1_class'>";
			$content .= $this->mini_logo( 'logo-image h1-img__img logo-image--small' );
			$content .= $this->display_logo_img( $this->standard_logo, 'logo-image h1-img__img' );
			$content .= $this->display_site_title( "site-title site-title-span pht-secondfont $text_size_class", 'span' );
			$content .= '</span>';
		} else {
			$content .= $this->display_site_title( 'site-title pht-mb0' );
		}
		$content .= $this->display_site_tagline( 'site-description pht-subtitle pht-mb0 pht-zeta' );
		
		$this->home_link( $id, $class, $content );
	}

	private function display_site_title( $class = '', $tag = 'h1' ) {
		if ( !self::$display_site_title ) {
			return;
		}
		if ( !$tag ) {
			return esc_html( get_bloginfo( 'name' ) );
		}
		return "<$tag class='$class'>" . esc_html( get_bloginfo( 'name' ) ) . "</$tag>";
	}

	private function display_site_tagline( $class = '', $tag = 'h2' ) {
		if ( !self::$display_site_tagline ) {
			return;
		}
		return "<$tag class='$class'>" . esc_html( get_bloginfo( 'description' ) ) . "</$tag>";
	}

	private function display_logo_img( $logo, $class = '' ) {

		if ( $this->logo_alt ) {
			$return_string = '';
			if ( $this->standard_logo && 'both' === $this->logo_choice ) {
				$return_string = $this->img_wrap( $this->standard_logo,  "$class hidden--lap-and-up" );
				$class .= ' hidden--palm';
			}
			$return_string .= $this->img_wrap( $this->logo_alt,  "$class logo-image--alt");
			return $return_string;
			
		}
		if ( 'both' === $this->logo_choice ) {
			$class .= ' hidden--lap-and-up';
		}
		$return_string = $this->img_wrap( $this->standard_logo,  $class );

		return $return_string;
	}

	private function img_wrap( $url, $class = '' ) {
		
		if ( !$url ) {
			return;
		}
		if ( is_ssl() ) {
			$url = preg_replace( "/^http:/i", "https:", $url );
		}
		$class = $class ? "class='$class'" : '';
		return "<img src='" . esc_url( $url ) . "' $class alt='" . esc_html( get_bloginfo( 'name' ) ) . "'>";
	}

	public function check_main_navigation() {

		

	}

	public function main_navigation() {

		if ( class_exists( 'Yaga_MegaMenu_Walker_Nav_Menu' ) ) {

			$args = array(
				'theme_location' => 'main_navigation',
				'depth'    => 0,
				'container'   => false,
				'menu_id'    => 'nav',
				'items_wrap'   => '%3$s',
				'menu_class'        => 'nav',
				'fallback_cb'       => 'Yaga_MegaMenu_Walker_Nav_Menu::fallback',
			);

			$args['walker'] = new Yaga_MegaMenu_Walker_Nav_Menu();

			$args = apply_filters( 'yaga_main_navigation_menu_args', $args );
			
			wp_nav_menu( $args );

		} else {

			wp_nav_menu();
		
		}

	}

	public function cart_and_search() {

		if ( !self::$display_menu ) {
			return;
		}

		$this->cart_in_menu();
		$this->search_in_menu();
	
	}

	public function toggle_menu() { 

		if ( !self::$display_menu ) {
			return;
		} ?>

		<a id="pht-mega-menu-toggle" class="pht-toggle-menu" href="#"><span class="pht-toggle-menu__span"></span></a>

	<?php }

	private function cart_in_menu() {
		if ( !class_exists( 'Yaga_WooCommerce' ) ) {
			return;
		}
		return Yaga_WooCommerce::cart_in_menu();
	}

	private function search_in_menu() {

		if ( ! $this->search_in_nav ) {
			return;
		} ?>

		<li class="search-toggle hidden--portable main-nav__li-depth-0">
			<a class="main-nav__a main-nav__a-depth-0 a-a a-a--no-h pht-ic-f1-search pointer"><span class="screen-reader-text"><?php esc_html_e( 'Search', 'yaga' ); ?></span>
			</a>
		</li>
		<li class="hidden--desk container-a container-a--alt-h li--search-form"><?php get_search_form(); ?></li>
	
	<?php }


	private function search_area() {

		if ( !self::$display_menu ) {
			return;
		}

		if ( ! $this->search_in_nav ) {
			return;
		}

		$ml_class = '';
		if ( in_array( pehaathemes_get_theme_mod_not_empty( 'yaga_ml', 'normal' ), array( 'normal', 'tiny', 'no' ) ) ) {
			$ml_class = 'search-form__wrapper--' . pehaathemes_get_theme_mod_not_empty( 'yaga_ml', 'normal' ) . '-ml';
		}
		
		?>

		<div id="search-container" class="search-form__wrapper search-form__wrapper--hidden hidden--portable <?php echo esc_attr( $ml_class ); ?>"><?php get_search_form(); ?></div>
	
	<?php }

}

endif;
