<?php

/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_View' ) ) :

class Yaga_View {

	public $sidebar = '';

	protected $post = NULL;

	protected $use_FPB = false;

	public function __construct( $post = 0 ) {

		$this->post = $post;
		$this->sidebar = isset( PeHaaThemes_Theme_Config::$sidebar->display ) ? PeHaaThemes_Theme_Config::$sidebar->display : true;
		$this->sidebar_position = isset( PeHaaThemes_Theme_Config::$sidebar->position ) ? PeHaaThemes_Theme_Config::$sidebar->position : 'right';


		if ( is_author() && !is_paged() ) {
			add_action( 'yaga_before_archive_loop', array( $this,  'author_bio' ) );
		}
		$this->header = new Yaga_Page_Header();

	}

	public function author_bio() {
		if ( !( get_the_author_meta( 'ID' ) ) || !( get_the_author_meta( 'description' ) ) ) return;
		echo '<article class="pht-index--grid__item">';
		echo '<div class="author-info pht-box pht-box--highlight pht-zeta">';
		get_template_part( 'author-bio' );
		echo '</div><!-- .author-info -->';
		echo '</article>';
	}

	public function header() {

		$this->header->display_header();
	}

	protected function layout_classes() {}

	protected function post_class() {
		return $this->sidebar ? 'pht-layout__item u-2-of-3-lap u-2-of-3-desk js-content' : 'js-content';
	}

	protected function layout_class() {
		if ( !$this->sidebar ) {
			return;
		} else {
			return 'right' === $this->sidebar_position ? 'pht-layout' : 'pht-layout pht-layout--rev';
		}
	}
 
	protected function thumbnail_size() {
		return $this->sidebar ? 'yaga-post-view' : 'yaga-full-width';
	}

	public function start_container() {
		$this->start_wrapper();
		$this->start_grid();
	}

	public function end_container() {
		$this->end_grid();
		$this->end_wrapper();
	}

	public function inner_container_starts() { ?>
		<div class="pht-parent pht-hider <?php echo esc_attr( $this->post_class() ); ?>">
	<?php }

	public function inner_container_ends() {
		echo "</div><!--";
	}

	public function grid_container_starts() {
		$this->inner_container_starts();

		echo '<div id="index-isotope" class="js-pht-lightboxgallery pht-index pht-index--grid index-isotope js-loadmore-into index-isotope-unloaded">';
		echo '<i class="js-index-isotope-preloader index-isotope-preloader pht-box pht-text-center pht-delta pht-ic-f1-preload pht-spin pht-transition hidden--palm"></i>';
	}

	public function grid_container_ends() {

		echo '</div><!-- #index-isotope -->';
		self::page_navi( '', 'content-grid' );
		$this->inner_container_ends();
	}

	public function classic_container_starts() {
		$this->inner_container_starts();
		echo '<div class="js-pht-lightboxgallery pht-index js-loadmore-into pht-index--classic">';
	}

	public function classic_container_ends() {

		echo '</div>';
		self::page_navi( '', 'content-classic' );
		$this->inner_container_ends();
	}

	private function start_wrapper() {
		$class = 'content-and-sidebar-area pht-wrapper';
		if ( $this->use_FPB ) {
			$class = 'content-and-sidebar-area content-and-sidebar-area__fpb';
		}	
		echo "<div id='content-and-sidebar-area' class='$class'>";
	}

	public function end_wrapper() {
		echo '</div>';
	}

	private function start_grid() {
		if ( $this->use_FPB ) {
			return;
		}
		if ( !$this->layout_class() ) {
			return;
		}
		echo "<div class='" . esc_attr( $this->layout_class() ) . "'>";
	}

	private function end_grid() {
		if ( $this->use_FPB ) {
			return;
		}
		if ( !$this->layout_class() ) {
			return;
		}
		echo '</div>';
	}

	public function get_sidebar() {

		if ( $this->use_FPB ) {
			return;
		}
		get_sidebar();
	}

	public static function page_navi( $custom_query = '', $data_template  = '',  $layout_option = NULL ) {

		if ( ! $data_template && $layout_option ) {
			$data_template = "content-$layout_option";
		}			

		$pagination_option = $data_template ? get_theme_mod( 'yaga_pagination' , 'standard' ) : 'standard';

		if ( 'standard' === $pagination_option ) {

			self::standard_navi();
			return;

		}

		global $wp_query;

		$paged = intval( get_query_var( 'paged' ) );

		$max_page = $wp_query->max_num_pages;

		if ( empty( $paged ) || $paged == 0 ) {
			$paged = 1;
		}

		if ( $max_page > $paged ) {
			$archive = '';
			if ( $custom_query ) {
				$archive = $custom_query;
			} elseif ( is_archive() ) {
				if ( is_tax( 'project_cat' ) ) { $archive = 'project_cat='. get_query_var( 'project_cat' );}
				elseif ( is_tax( 'project_tag' ) ) { $archive = 'project_tag='. get_query_var( 'project_tag' );}
				elseif ( is_category() ) { $archive = 'cat='. get_query_var( 'cat' ); }
				elseif ( is_tag() ) { $archive = 'tag_id='. get_query_var( 'tag_id' ); }
				elseif ( is_day() ) { $archive = 'year='. get_the_time( 'Y' ) .'&monthnum='. get_the_time( 'n' ) .'&day='. get_the_time( 'j' ); }
				elseif ( is_month() ) { $archive = 'year='. get_the_time( 'Y' ) .'&monthnum='. get_the_time( 'n' ); }
				elseif ( is_year() ) { $archive = 'year='. get_the_time( 'Y' ); }
				elseif ( is_author() ) { $archive = 'author='. get_query_var( 'author' ); }
				elseif ( $format = get_post_format() ) { $archive = 'post-format-'. $format; }

			} elseif ( is_search() ) {
				$archive = 's=' . get_search_query();
			}

			echo '<nav class="nav pht-box pht-box--highlight pht-text-center pht-actionfont pht-zeta pht-mb parent">';
			printf( '<a href="#" id="load-more" class="a-a a-a--no-h" data-query="%1$s" data-template="%2$s" data-maxpage="%3$s" data-currentpage="%4$s">',
				esc_attr( $archive ),
				esc_attr( $data_template ),
				esc_attr( $max_page ),
				esc_attr( $paged )
			);
			echo '<span class="js-load-more-span">' . apply_filters( 'yaga_load_more_text', esc_html__( 'Load More', 'yaga' ) ) . '</span>';
			echo '<span class="js-loading-state js-hidden">' . apply_filters( 'yaga_loading_text', '<i class="pht-ic-f1-preload pht-spin"></i>' ) . '</span>';
			echo '</a></nav>';

		}

	}


	public static function standard_navi() {

		global $wp_query;

		$paged = intval( get_query_var( 'paged' ) );
		$max_page = $wp_query->max_num_pages;
		if ( empty( $paged ) || $paged == 0 ) {
			$paged = 1;
		}

		$big = 999999999; // This needs to be an unlikely integer

		// For more options and info view the docs for paginate_links()
		// http://codex.wordpress.org/Function_Reference/paginate_links
		$paginate_links = paginate_links( array(
				'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
				'current' => max( 1, $paged ),
				'total' => $max_page,
				'mid_size' => 5,
				'prev_next' => True,
				'prev_text' => '&laquo;',
				'next_text' => '&raquo;',
				'type' => 'array'
			) );

		if ( !$paginate_links ) {
			return;
		}
		?>

		<ol class='nav pht-box pht-box--highlight pht-pagination page-numbers pht-actionfont landmark container-a container-a--h'>
			<li>
			<?php echo join( "</li><!-- --><li>", $paginate_links ); ?>
			</li>
		</ol>

	<?php }

	public static function posts_carousel( $carousel_query, $image_size, $display_starts = 3  ) {

		if ( count( $carousel_query ) < $display_starts ) {
			return;
		} 
		$yaga_post = Yaga_Entry::get_instance(); ?>
		<div class="posts_carousel__slider js-carousel" data-dots="false">
		
		<?php foreach ( (array) $carousel_query as $carousel_query_post ) { ?>
			<div class="posts-carousel__item parent">
				<?php
				$yaga_post->entry_image( $image_size, false, $carousel_query_post->ID, 'title', NULL, 'posts-carousel__figure pht-white' ); 
				?>
			</div><!-- .carousel__item -->		
		<?php } ?>

		</div><!-- .carousel -->

	<?php }

} 

endif;