<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Walker_Comment' ) ) :

class Yaga_Walker_Comment extends Walker_Comment {

	/**
	 * Output a comment in the HTML5 format.
	 *
	 * @access protected
	 * @since 3.6.0
	 *
	 * @see wp_list_comments()
	 *
	 * @param object  $comment Comment to display.
	 * @param int     $depth   Depth of comment.
	 * @param array   $args    An array of arguments.
	 */
	protected function html5_comment( $comment, $depth, $args ) {
		$tag = ( 'div' === $args['style'] ) ? 'div' : 'li'; ?>
		<<?php echo esc_attr( $tag ); ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
			<article id="div-comment-<?php comment_ID(); ?>" class="comment-body pht-layout pht-mb">
				<footer class="comment-meta pht-layout__item u-1-of-3-desk pht-micro pht-mb">
					<div class="comment-author vcard">
						<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
						<?php printf( '<b class="fn">%s</b> ', get_comment_author_link() );
						echo '<span class="says">' . esc_html__( 'says', 'yaga' ) . '</span>';
						?>
					</div><!-- .comment-author -->

					<div class="comment-metadata media__body pht-italic">
						<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID, $args ) ); ?>">
							<time datetime="<?php comment_time( 'c' ); ?>">
								<?php printf( esc_html_x( '%1$s at %2$s', '1: date, 2: time', 'yaga' ), get_comment_date(), get_comment_time() ); ?>
							</time>
						</a>
						<?php edit_comment_link( esc_html__( 'Edit', 'yaga' ), '<span class="edit-link">', '</span>' ); ?>
					</div><!-- .comment-metadata -->

					<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'yaga' ); ?></p>
					<?php endif; ?>
				</footer><!-- .comment-meta --><!--

				--><div class="comment-content pht-layout__item u-2-of-3-desk">
					<?php comment_text(); ?>
				</div><!-- .comment-content --><!--

				--><div class="reply pht-layout__item pht-text-right pht-secondfont">
					<?php comment_reply_link( array_merge( $args, array( 'add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div><!-- .reply -->
			</article><!-- .comment-body -->
<?php }

}

endif;