<?php
/**
 * Recent_Posts with thumbnailswidget class
 *
 */
class Yaga_Widget_Recent_Posts extends Yaga_Widget {

	public function __construct() {
		$widget_ops = array( 
			'classname' => 'widget_recent_entries yaga_widget_recent_posts', 
			'description' => esc_html__( "Most Recent Posts with Thumbnails.", 'yaga' ) 
		);
		parent::__construct( 'yaga_widget_recent_posts', sprintf( esc_html__( '%s - Recent Entries with Thumbnails', 'yaga' ), PeHaaThemes_Theme_Start::$theme_name ), $widget_ops );
		$this->alt_option_name = 'yaga_widget_recent_posts';

	}

	public function widget( $args, $instance ) {

		ob_start();

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Recent Posts', 'yaga' );

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$post_type = isset( $instance['post_type'] ) ? esc_attr( $instance['post_type'] ) : 'post';

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number ) {
			$number = 5;
		}
			
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		$show_subtitle = isset( $instance['show_subtitle'] ) ? $instance['show_subtitle'] : false;

		/**
		 * Filter the arguments for the Recent Posts widget.
		 *
		 * @since 3.4.0
		 *
		 * @see WP_Query::get_posts()
		 *
		 * @param array $args An array of arguments used to retrieve the recent posts.
		 */
		$r = new WP_Query( apply_filters( 'widget_posts_args', array(
			'post_type' => $post_type,
			'posts_per_page'      => $number,
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true
		) ) );

		if ($r->have_posts()) :
			$this->yaga_before_widget( $args );
			$this->yaga_widget_title( $title, $args ); ?>
			<ul>
				<?php 
				while ( $r->have_posts() ) : $r->the_post(); ?>
					<li class="media media--small pht-widget_recent_entries__entry">
						<?php 
						$image = pehaathemes_get_post_thumb( get_the_ID(), array( 144, 96 ), false, array( 'class' => 'pht-widget_recent_entries__img pht-mb0' ) );
						if ( has_post_thumbnail( get_the_ID() ) ) { ?>
							<a class="media__img" href="<?php the_permalink(); ?>"><?php echo pehaathemes_get_post_thumb( get_the_ID(), array( 144, 96 ), false, array( 'class' => 'pht-widget_recent_entries__img pht-mb0' ) ); ?></a>
						<?php } ?>
						<div class="media__body">
							<?php if ( $show_date ) { ?>
								<div class="pht-micro pht-italic post-date"><?php echo get_the_date(); ?></div>
							<?php } ?>
							<a href="<?php the_permalink(); ?>" class="pht-secondfont pht-truncate"><?php get_the_title() ? the_title() : the_ID(); ?></a>	
						</div>
					</li>
				<?php endwhile; ?>
			</ul>
			<?php $this->yaga_after_widget( $args );

			// Reset the global $the_post as this query will have stomped on it
			wp_reset_postdata();

		endif;

		ob_end_flush();
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['post_type']	= isset( $new_instance['post_type'] ) ? esc_attr( $new_instance['post_type'] ) : 'post';
		$instance['number'] = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;

		return $instance;
	}

	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$post_type	= isset( $instance['post_type'] ) ? esc_attr( $instance['post_type'] ) : 'post';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false; ?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'yaga' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>"><?php esc_html_e( 'Choose the Post Type to display:', 'yaga' ); ?></label> 
    		<select name="<?php echo esc_attr( $this->get_field_name( 'post_type' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>" class="widefat">
    			<?php foreach ( PeHaaThemes_Theme_Start::$single_items as $post_slug ) {
    				printf ( '<option id="%1$s" value="%2$s" %3$s>%4$s</option>',
    					esc_attr( $post_slug ),
    					esc_attr( $post_slug ),
    					$post_type === $post_slug ? ' selected="selected"' : '',
    					esc_html( $post_slug )
    				);
				} ?>
    		</select>
    	</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'yaga' ); ?></label>
			<input id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" size="3" />
		</p>
		<p>
			<input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>" />
			<label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php esc_html_e( 'Display post date?', 'yaga' ); ?></label>
		</p>
	<?php
	}
}