<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_Social_Widget' ) ) :

class Yaga_Widget_Social extends Yaga_Widget {

	private $socials;

	public function __construct() {
		$widget_ops = array(
			'classname' => 'yaga_social_widget',
			'description' => esc_html__( 'A theme built-in widget that displays your Social Links.', 'yaga' )
		);
		$control_ops = array(
			'width' => 200,
			'height' => 350,
			'id_base' => 'yaga_social_widget'
		);

		parent::__construct( 'yaga_social_widget', sprintf( esc_html__( '%s - Social Links', 'yaga' ), PeHaaThemes_Theme_Start::$theme_name ), $widget_ops, $control_ops );

		$this->socials = array(
			'twitter' => array( 'icon' => 'twitter', 'field' => 'twitter_url', 'label' => esc_html__( 'Twitter profile url:', 'yaga' ) ),
			'google-plus' => array( 'icon' => 'googleplus', 'field' => 'google_plus_url', 'label' => esc_html__( 'Google-plus profile url:', 'yaga' ) ),
			'facebook' => array( 'icon' => 'facebook', 'field' => 'facebook_url', 'label' => esc_html__( 'Facebook profile url:', 'yaga' ) ),
			'dribbble' => array( 'icon' => 'dribbble', 'field' => 'dribbble_url', 'label' => esc_html__( 'Dribbble profile url:', 'yaga' ) ),
			'pinterest' => array( 'icon' => 'pinterest', 'field' => 'pinterest_url', 'label' => esc_html__( 'Pinterest profile url:', 'yaga' ) ),
			'instagram' => array( 'icon' => 'instagram', 'field' => 'instagram_url', 'label' => esc_html__( 'Instagram profile url:', 'yaga' ) ),
			'flickr' => array( 'icon' => 'flickr', 'field' => 'flickr_url', 'label' => esc_html__( 'Flickr profile url:', 'yaga' ) ),
			'tumblr' => array( 'icon' => 'tumblr', 'field' => 'tumblr_url', 'label' => esc_html__( 'Tumblr profile url:', 'yaga' ) ),
			'linkedin' => array( 'icon' => 'linkedin', 'field' => 'linkedin_url', 'label' => esc_html__( 'Linkedin profile url:', 'yaga' ) ),
			'vimeo' => array( 'icon' => 'vimeo', 'field' => 'vimeo_url', 'label' => esc_html__( 'Vimeo profile url:', 'yaga' ) ),
			'youtube' => array( 'icon' => 'youtube', 'field' => 'youtube_url', 'label' => esc_html__( 'Youtube profile url:', 'yaga' ) ),
			'behance' => array( 'icon' => 'behance', 'field' => 'behance_url', 'label' => esc_html__( 'Behance profile url:', 'yaga' ) ),
		);
		
	}

	function widget( $args, $instance ) {

		$title = apply_filters( 'widget_title', $instance['title'] );

		$this->yaga_before_widget( $args );

		$this->yaga_widget_title( $title, $args ); ?>
		
		<div class="pht-social-container pht-text-center">
		
		<?php

			foreach ( $this->socials as $key => $social ) {

				if ( $instance[ $social['field'] ] ) {
					$title = sprintf( esc_html__( 'Link to %s profile', 'yaga' ), esc_html( $key ) );
					printf( '<a class="pht-icon pht-icon--tiny pht-icon--border pht-btn--pill" href="%1$s" title="%2$s" target="_blank"><i class="%3$s"></i></a> ',
						esc_url( $instance[ $social['field'] ] ),
						esc_attr( $title ),
						'pht-ic-f1-' . esc_attr( $social['icon'] )
					 );
				}

			} ?>
		</div>

		<?php $this->yaga_after_widget( $args );
	}


	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$fields = array();
		foreach ( $this->socials as $key => $social ) {

			$fields[] = $social['field'];

		}
		$instance['title'] = strip_tags( $new_instance['title'] );
		foreach ( $fields as $field ) {
			$instance[ $field ] = esc_url( $new_instance[ $field ] );
		}

		return $instance;
	}

	function form( $instance ) {

		$defaults = array( 'title' => esc_html__( 'Social Links', 'yaga' ) );

		foreach ( $this->socials as $key => $social ) {

			$defaults[ $social['field'] ] = '';

		}

		$form_elements = array( 'title' => esc_html__( 'Title:', 'yaga' ) );

		foreach ( $this->socials as $key => $social ) {

			$form_elements[ $social['field'] ] = $social['label'];

		}

		$instance = wp_parse_args( (array) $instance, $defaults );

		foreach ( $form_elements as $key => $value ) { ?>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>"><?php echo esc_html( $value ); ?></label>
				<?php if ( $key === 'title' ) { ?>
					<input class="widefat" type="text" id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $key ) ); ?>" value="<?php echo esc_attr( $instance[ $key ] ); ?>" />
				<?php } else { ?>
				<input class="widefat" type="text" id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $key ) ); ?>" value="<?php echo esc_url( $instance[ $key ] ); ?>" />
				<?php } ?>
			</p>
		<?php
		}
	}
}

endif;