<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */

if ( ! class_exists( 'Yaga_WooCommerce' ) ) :

class Yaga_WooCommerce {

	private static $instance = null;

	static $woocommerce_is_activated;

	private $sidebar_id ='wc-side-sidebar';

	private $footer_id = 'wc-footer-sidebar';

	private $default_product_in_loop = 12;

	private $customizer_fields = array();

	private function __construct() {

		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-slider' );

		self::$woocommerce_is_activated = class_exists( 'woocommerce' );

		if ( !self::$woocommerce_is_activated ) {
			return;
		}

		add_action( 'template_redirect', array( $this, 'id_for_shop_page' ) );
		add_filter( 'woocommerce_single_product_carousel_options', array( $this, 'yaga_wc_single_product_carousel_options' ) );	
		add_filter( 'woocommerce_enqueue_styles', array( $this, 'dequeue_wc_styles' ) );
		add_filter( 'pehaathemes_main_stylesheet', array( $this, 'stylesheet' ) );
		add_filter( 'woocommerce_output_related_products_args', array( $this, 'output_related_products_args' ) );
		add_filter( 'loop_shop_per_page', array( $this, 'loop_shop_per_page' ) );
		$add_to_cart_fragments_hook_name = 'add_to_cart_fragments';
		if ( defined( 'WOOCOMMERCE_VERSION' ) && version_compare( WOOCOMMERCE_VERSION, '3.0', '>=' ) ) {
			$add_to_cart_fragments_hook_name = 'woocommerce_add_to_cart_fragments';
		}
		add_filter( $add_to_cart_fragments_hook_name, array( $this, 'add_to_cart_fragments' ) );
		add_filter( 'woocommerce_cart_item_remove_link', array( $this, 'cart_item_remove_link' ) ,10 , 2 );

		$this->add_wc_sidebar();

		$this->add_wc_footer();

		$this->define_global_functions();

		add_filter( 'woocommerce_product_additional_information_heading', '__return_false' );
		
		$this->remove_actions();

		add_action( 'yaga_woocommerce_form_start' , array( $this, 'woocommerce_form_start' ) );
		add_action( 'yaga_woocommerce_form_end', array( $this, 'woocommerce_form_end' ) );

		$this->customizer_fields = array(
			'yaga_woocommerce' => array(
				'section' => array(
					'title' => esc_html__( 'WooCommerce', 'yaga' ),
					'panel' => 'yaga',
					'active_callback' => array( $this, 'should_woocommerce_section_display' ),
				),
				'settings' => array(
					'yaga_products_in_loop' => array(
						'setting_array' => array(
							'default' => $this->default_product_in_loop,
							'sanitize_callback' => 'PeHaaThemes_Sanitization::sanitize_text_with_int'
						),
						'control_array' => array(
							'label' =>  esc_html__( 'Products per page.', 'yaga' ),
							'description' => esc_html__( 'Set the number of products per page.', 'yaga' ),
							'type' => 'text',
						)
					),
					'yaga_sidebar_on_shop_page' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' => esc_html__( 'Shop page sidebar', 'yaga' ),
							'description' => esc_html__( 'Check here to display side widgets on the Shop page', 'yaga' ),
							'type' => 'checkbox',
						)
					),
					'yaga_sidebar_on_wc_archives' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' => esc_html__( 'Sidebar on archive', 'yaga' ),
							'description' => esc_html__( 'Check here to display sidebar on the shop archive pages (categories, tags, etc.)', 'yaga' ),
							'type' => 'checkbox',
						)
					),
					'yaga_sidebar_on_single_product' => array(
						'setting_array' => array(
						),
						'control_array' => array(
							'label' => esc_html__( 'Sidebar on product', 'yaga' ),
							'description' => esc_html__( 'Check here to display sidebar in a single product view', 'yaga' ),
							'type' => 'checkbox',
						)
					),
				)
			)
        );

		add_action( 'customize_register', array( $this, 'wc_customize_register'), 12 );

	}


	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		return self::$instance;

	}

	public function yaga_wc_single_product_carousel_options( $array ) {
		
		unset( $array['directionNav'] ); 
		return $array;

	}

	public function dequeue_wc_styles( $enqueue_styles ) {
		unset( $enqueue_styles['woocommerce-general'] );	
		unset( $enqueue_styles['woocommerce-layout'] );		
		unset( $enqueue_styles['woocommerce-smallscreen'] );
		return $enqueue_styles;
	}

	public function stylesheet( $stylesheet ) {
		return $stylesheet . '-wc';
	}

	public static function pages_with_wc_sidebar() {
	
		if ( !self::$woocommerce_is_activated ) 
			return;
		return apply_filters( 'yaga_pages_with_wc_sidebar', is_cart() || is_account_page() || is_checkout() );
	
	}

	public static function cart_in_menu() {

		if ( !self::$woocommerce_is_activated ) {
			return;
		}
		if ( !get_option( 'woocommerce_cart_page_id' ) ) {
			return;
		}
		
		global $woocommerce;

		$links_in_menu = array(
			'cart' => array( 
				'id_option' => 'woocommerce_cart_page_id',
				'title' => esc_html__( 'View Cart', 'yaga' ),
				'class' => 'cart-link'
			),
			'checkout' => array(
				'id_option' => 'woocommerce_checkout_page_id',
				'title' => esc_html__( 'Checkout', 'yaga' ),
				'class' => 'checkout-link'
			)
		);

		$links_in_menu = apply_filters( 'yaga_wc_links_in_menu', $links_in_menu );

		if ( !$woocommerce->cart->cart_contents_count ) : ?>
			<li id="masthead-cart" class="cart menu-item main-nav__li main-nav__li-depth-0">
				<a class="my-cart-link a-a a-a--no-h pht-ic-f1-cart js-with-submenu ul-hidden main-nav__a main-nav__a-depth-0" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_cart_page_id' ) ) ); ?>"></a>
			</li>
		<?php else: ?>
			<li id="masthead-cart" class="cart menu-item main-nav__li-depth-0 menu-item-has-children main-nav__droptrigger">
				<a class="my-cart-link my-cart-link-active a-a a-a--no-h js-with-submenu ul-hidden main-nav__a main-nav__a-depth-0" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_cart_page_id' ) ) ); ?>">
					<i class="pht-ic-f1-cart"></i> <span class="my-cart-link-cart-count"><?php echo (int) $woocommerce->cart->cart_contents_count; ?></span>
					<i class="main-nav__icon main-nav__icon--right pht-ic-f1-caret-up"></i>
				</a>
				<ul class="cart-contents sub-menu container-a container-a--alt-h pht-mb0">
				<?php foreach ( $woocommerce->cart->cart_contents as $cart_item ) : ?>
					<li class="cart-content pht-box--tiny main-nav__li-depth-1">
						<a class="media main-nav__a main-nav__a-depth-1" href="<?php echo esc_url( get_permalink( $cart_item['product_id'] ) ); ?>">
							<?php echo get_the_post_thumbnail( $cart_item['product_id'], 'thumbnail', array( 'class' => 'media__img' ) ); ?>
							<div class="cart-desc media__body">
								<?php $cart_item_as_post = get_post( $cart_item['data']->get_id() ); ?>
								<span class="cart-title strong"><?php echo esc_html( $cart_item_as_post->post_title ); ?></span>
								<span class="product-quantity"><?php echo esc_html( $cart_item['quantity'] ); ?> x <?php echo strip_tags( $woocommerce->cart->get_product_subtotal( $cart_item['data'], 1 ) ); ?></span>
							</div>
						</a>
					</li>
				<?php endforeach; ?>
					<li class="cart-checkout">
						<?php foreach ( $links_in_menu as $link_in_menu ) : ?>
							<div class="<?php echo esc_attr( $link_in_menu['class'] );?> main-nav__li-depth-1">
								<a class="main-nav__a main-nav__a-depth-1 strong" href="<?php echo esc_url( get_permalink( get_option( esc_attr( $link_in_menu['id_option'] ) ) ) ); ?>"><?php echo esc_html( $link_in_menu['title'] ); ?></a>
							</div>
						<?php endforeach; ?>
					</li>
				</ul>
			</li>
		<?php endif; 
	}

	private function add_wc_sidebar() {
		
		$wc_side = array(
 			'name' => esc_html__( 'WC Sidebar Widgets Area', 'yaga' ),
 			'description' => esc_html__( 'Right sidebar widget area.', 'yaga' ),
 			'id' => $this->sidebar_id,
 		);
 		$wc_side = wp_parse_args( PeHaaThemes_Theme_Config::$yaga_sidebar_widget_areas_defaults, $wc_side );
 		$wc_side_sidebar = new PeHaaThemes_Widgets_Area( $wc_side, 'woocommerce' );
 		add_filter( 'yaga_wc_sidebar', array( $this, 'sidebar_id' ) );

	}

	
	private function add_wc_footer() {
		return;
		$wc_footer = array(
			'name' => esc_html__( 'WC Footer Widgets Area', 'yaga' ),
			'description' => esc_html__( 'Footer widget area.', 'yaga' ),
			'id' => $this->footer_id
		);
		$wc_footer = wp_parse_args( PeHaaThemes_Theme_Config::$yaga_footer_widget_areas_defaults, $wc_footer );
		$wc_footer_sidebar = new PeHaaThemes_Widgets_Area( $wc_footer, 'woocommerce');
		add_filter( 'yaga_wc_footer', array( $this, 'footer_id' ) );
	}

	public function sidebar_id() {
		return $this->sidebar_id;
	}

	public function footer_id() {
		return $this->footer_id;
	}

	private function define_global_functions() {

		if ( ! function_exists( 'woocommerce_get_product_thumbnail' ) ) :

			function woocommerce_get_product_thumbnail( $size = 'yaga-post-grid-shop', $placeholder_width = 0, $placeholder_height = 0  ) {
	
				global $post, $product;

				if ( !apply_filters( 'yaga_use_theme_product_catalog_sizes', true ) ) {
					$size = 'shop_catalog';
				}

				$outofstock = 'outofstock' ===  get_post_meta( $post->ID, '_stock_status', true );

				if ( has_post_thumbnail() ) {

					$thumb_class = 'post-thumbnail';
					
					$return_string = "<figure class='pht-fig'>";

					$return_string .= get_the_post_thumbnail( $post->ID, $size, array( 'class' => $thumb_class ) );
					
					if ( $outofstock ) {
						$availability = array( 'availability' => esc_html__( 'Out of Stock', 'yaga' ) ); 
						if ( method_exists( $product, 'get_availability' ) ) {
							$av = $product->get_availability();
							if ( isset( $av['availability'] ) ) {
								$availability = $av;
							}
						}
						$return_string .= '<figcaption class="pht-fig__caption out-of-stock-overlay">';
						if ( $availability['availability'] ) {
							$return_string .= '<span>'. esc_html( $availability['availability'] ) .'</span>';
						}
						$return_string .= '</figcaption>';
					}
					$return_string .= '<div class="pht-fig__link--ctnr pht-white">';
					$return_string .= '<a href="' . esc_url( get_permalink( $post ) ) . '" class="pht-fig__link pht-fig__link--hoverdir pht-fig__link--main pht-text-center a-a a-a--no-h pht-text-center pht-actionfont pht-zeta">';
					$return_string .= '<div class="pht-fig__titles">';
					$return_string .= esc_html__( 'Go to Product Page', 'yaga' );
					$return_string .= '</div>';
					$return_string .= '</a>';
					$return_string .= '</div>';
	
					$return_string .= '</figure>';
					return $return_string;
					
				}
		
				elseif ( wc_placeholder_img_src() ) {
					return wc_placeholder_img( $size );
				}
					
			}
		endif;
		if ( ! function_exists( 'woocommerce_subcategory_thumbnail' ) ) {

			function woocommerce_subcategory_thumbnail( $category ) {
				if ( !apply_filters( 'yaga_use_theme_product_catalog_sizes', true ) ) {
					$size = 'shop_catalog';
				} else {
					$size = 'yaga-post-grid-shop';
				}
				$small_thumbnail_size  	= apply_filters( 'single_product_small_thumbnail_size', $size );
				$dimensions    			= wc_get_image_size( $small_thumbnail_size );
				$thumbnail_id  			= get_woocommerce_term_meta( $category->term_id, 'thumbnail_id', true  );

				if ( $thumbnail_id ) {
					$image = wp_get_attachment_image_src( $thumbnail_id, $small_thumbnail_size  );
					$image = $image[0];
				} else {
					$image = wc_placeholder_img_src();
				}

				if ( $image ) {
					// Prevent esc_url from breaking spaces in urls for image embeds
					// Ref: http://core.trac.wordpress.org/ticket/23605
					$image = str_replace( ' ', '%20', $image );
					echo '<figure class="pht-fig">';

					echo '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( $category->name ) . '" width="' . esc_attr( $dimensions['width'] ) . '" height="' . esc_attr( $dimensions['height'] ) . '" />';
					echo '<div class="pht-fig__link--ctnr pht-white">';
					echo '<a href="' . esc_url( get_term_link( $category->slug, 'product_cat' ) ) . '" class="pht-fig__link pht-fig__link--hoverdir pht-fig__link--main pht-text-center a-a a-a--no-h pht-text-center pht-actionfont pht-zeta">';
					echo '<div class="pht-fig__titles">';
					echo esc_html__( 'Browse the Category', 'yaga' );
					echo '</div>';
					echo '</a>';
					echo '</div>';
					echo '</figure>';

				}
			}
		}
		if ( ! function_exists( 'woocommerce_review_display_comment_text' ) ) {
			function woocommerce_review_display_comment_text() {
				echo '<div itemprop="description" class="description pht-zeta pht-mb">' . get_comment_text() . '</div>';
			}
		}
		
	}

	private function remove_actions() {
		remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
		remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
		remove_action( 'woocommerce_before_subcategory', 'woocommerce_template_loop_category_link_open', 10 );
		remove_action( 'woocommerce_after_subcategory', 'woocommerce_template_loop_category_link_close', 10 );
	}

	public function woocommerce_form_start() {
		echo '<fieldset class="pht-box pht-box--small pht-mb pht-zeta">';
	}

	public function woocommerce_form_end() {
		echo '</fieldset>';
	}

	public function output_related_products_args( $args ) {
		
		$args['posts_per_page'] = 2;
		return $args;
	
	}

	public function loop_shop_per_page() {

		$option_value = get_theme_mod( 'yaga_products_in_loop', $this->default_product_in_loop );

		if ( (int) $option_value ) {
			return (int) $option_value;
		}
	
		return $this->default_product_in_loop;
	}
	
	public function add_to_cart_fragments( $fragments ) {
		
		global $woocommerce;
		ob_start();
		self::cart_in_menu();
		$header_cart = ob_get_clean();
		$fragments['#masthead-cart'] = $header_cart;

		return $fragments;

	}

	public function wc_customize_register( $wp_customize ) {

		Yaga_Customizer::fields_from_array( $wp_customize, $this->customizer_fields );

	}

	public function should_woocommerce_section_display() {
		return true;
	}

	public function cart_item_remove_link( $woo_string, $cart_item_key ) {
		return sprintf( '<a href="%s" class="remove pht-ic-f1-close" title="%s"></a>', esc_url( WC()->cart->get_remove_url( $cart_item_key ) ), esc_html__( 'Remove this item', 'yaga' ) );
	} 

	public function id_for_shop_page() {
		if ( is_shop() ) {
			PeHaaThemes_Theme_Config::$id = get_option( 'woocommerce_shop_page_id' );
		}
	}

}

endif;

Yaga_WooCommerce::get_instance();