<?php
/**
 * Text widget class
 *
 */
class Yaga_Widget_Image_and_Text extends Yaga_Widget {

	public function __construct() {
		$widget_ops = array( 
			'classname' => 'widget_text yaga_widget_image_and_text', 
			'description' => esc_html__( 'Arbitrary text or HTML starting with a rounded image. It works great for some short introductory about text.', 'yaga' ) 
			);
		$control_ops = array( 'width' => 400, 'height' => 350 );

		parent::__construct( 'yaga_widget_image_and_text', sprintf( esc_html__( '%s - About Widget', 'yaga' ), PeHaaThemes_Theme_Start::$theme_name ), $widget_ops, $control_ops );

		add_action( 'admin_enqueue_scripts', array( $this, 'upload_scripts' ) );
	}

	public function upload_scripts() {

		$screen = get_current_screen();

		if ( NULL === $screen ) {
			return;
		}
		if ( ! in_array( $screen->id, array( 'widgets', 'customize' ) ) ) {
			return;
		}
		wp_enqueue_script( 'yaga-media-widget-scipt',  PEHAATHEMES_INCLUDES_URI . '/image-text-widget/assets/js/upload-media.js', array( 'jquery', 'media-upload' ) );
		wp_enqueue_style( 'yaga-media-widget-style', PEHAATHEMES_INCLUDES_URI . '/image-text-widget/assets/css/style.css' );
	}

	public function widget( $args, $instance ) {

		$img_dimension = 144;

		/** This filter is documented in wp-includes/default-widgets.php */
		$title = apply_filters( 'yaga_widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		
		$text = apply_filters( 'yaga_widget_text', empty( $instance['text'] ) ? '' : $instance['text'], $instance );
		$img_id = apply_filters( 'yaga_widget_img', empty( $instance['img_id'] ) ? '' : $instance['img_id'], $instance );
		$style = apply_filters( 'yaga_widget_style', empty( $instance['style'] ) ? '' : $instance['style'], $instance );
		$link = empty( $instance['link'] ) ? '' : $instance['link'];
		
		$this->yaga_before_widget( $args );
		$this->yaga_widget_title( $title, $args ); 

		if ( $img_id && wp_get_attachment_image( $img_id ) ) {
			$image = pehaathemes_get_att_img( $img_id, array( 2*$img_dimension, 2*$img_dimension ), false, array( 'width' => $img_dimension, 'height' => $img_dimension, 'class' => 'pht-rounded' ) ); 
			if ( trim( $link ) ) {
				$image = sprintf( '<a href="%1$s">%2$s</a>', esc_url( $link ), $image );
			}
			if ( $image ) {
				printf( '<p class="pht-text-center">%s</p>', $image );
			}
		} 

		$class = $style ? 'textwidget pht-spacedletters pht-text-center' : 'textwidget'; ?>
		
		<div class="<?php echo esc_attr( $class ); ?>"><?php echo wpautop( $text ); ?></div>

		<?php $this->yaga_after_widget( $args );
	}

	public function update( $new_instance, $old_instance ) {

		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can( 'unfiltered_html' ) ) {
			$instance['text'] =  $new_instance['text'];
		} else {
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes( $new_instance['text'] ) ) ); // wp_filter_post_kses() expects slashed
		}
			
		$instance['style'] = ! empty( $new_instance['style'] );
		$instance['img_id'] = (int) $new_instance['img_id'];
		$instance['link'] = esc_url( $new_instance['link'] );
		return $instance;
	}

	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '', 'img_id' => '', 'link' => '' ) );
		$title = strip_tags( $instance['title'] );
		$text = esc_textarea( $instance['text'] );
		$img_id = (int) $instance['img_id'];
		$link = esc_url( $instance['link'] );
?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'yaga' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<textarea class="widefat" rows="16" cols="20" id="<?php echo esc_attr( $this->get_field_id('text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('text') ); ?>"><?php echo wp_kses_post( $text ); ?></textarea>

		<p>
			<input id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>" type="checkbox" <?php checked( isset($instance['style'] ) ? $instance['style'] : 0); ?> />
			<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"><?php esc_html_e( 'Center and increase the letter spacing.', 'yaga' ); ?></label>
		</p>
		<div class="pht-clear">
			<a href="#" class="js-yaga-upload-thumbnail pht-upload-thumbnail button button-primary"><?php esc_html_e( 'Set Image', 'yaga' ); ?></a>
			<input type="hidden" id="<?php echo esc_attr( $this->get_field_name( 'img_id' ) ); ?>" class="pht-new-media-image widefat code edit-menu-item-thumbnail" name="<?php echo esc_attr( $this->get_field_name( 'img_id' ) ); ?>" value="<?php echo esc_attr( $img_id ); ?>" />
			<?php $image_set =  $img_id && wp_get_attachment_image( $img_id ); ?>
			<div class="js-img-ctnr pht-img__ctnr pht-img__ctnr--<?php echo $image_set ? 'set' : 'empty'; ?>">
				<?php if (  $image_set ) {  
					echo wp_get_attachment_image( $img_id, 'thumbnail', '', array( 'class' => 'pht-img-placeholder' ) ); 
				} else { ?>
					<img class="pht-img-placeholder" src="">
				<?php } ?>
			</div>
			<a href="#" class="js-yaga-remove-thumbnail pht-remove-thumbnail"><?php esc_html_e( 'Remove Image', 'yaga' ); ?></a>			
		</div>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>"><?php esc_html_e( 'Link:', 'yaga' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link' ) ); ?>" type="text" value="<?php echo esc_url( $link ); ?>" />
		</p>
<?php
	}
}