<?php

add_action( 'cmb2_init', 'yaga_mb_register_post_metabox' );

if ( !function_exists( 'yaga_mb_register_post_metabox' ) ) :
/**
 * Define the metabox and field configurations.
 *
 * @param array   $meta_boxes
 * @return array
 */
function yaga_mb_register_post_metabox() {

	$prefix = PeHaaThemes_Theme_Start::$mb_prefix;
	$yaga_metabox_post_types_slugs = PeHaaThemes_Theme_Start::$single_items;

	$add_colors_choice_metabox = false;
	if ( !in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_fixed', 'top_fixed_center' ) ) ) {
		$site_header_color = array(
			'name' => esc_html__( 'Site Header Text Colors', 'yaga' ),
			'desc' => esc_html__( 'Define the colors for the navigation bar and the title/tagline.', 'yaga' ),
			'id'   => $prefix . 'transparent_site_header_color',
			'type' => 'select',
			'options' => array(
				'inherit' => esc_html__( 'Do not change color', 'yaga' ),
				'dark' => esc_html__( 'Dark', 'yaga' ),
				'light' => esc_html__( 'Light', 'yaga' ),
				'lap_up_dark' => esc_html__( 'Change to dark on large screens only (800px)', 'yaga' ),
				'lap_up_light' => esc_html__( 'Change to light on large screens only (800px)', 'yaga' ),
			)
		);
		$add_colors_choice_metabox = true;
	}
	

	$add_logo_choice_metabox = false;
	$logo_options = array( 'standard' => esc_html__( 'Standard Logo', 'yaga' ) );	

	if ( get_theme_mod( 'yaga_logo_alt' ) && !in_array( PeHaaThemes_Theme_Config::$navigation, array( 'top_fixed_fixed', 'top_fixed_center' ) ) ) {
		$logo_options['alt'] = esc_html__( 'Alternative Logo', 'yaga' );
		$logo_options['both'] = esc_html__( 'Standard on small screens, Alternative on large screens (800px)', 'yaga' );
		$add_logo_choice_metabox = true;
	}

	$site_header_choose_logo = array(
		'name' => esc_html__( 'Choose Logo', 'yaga' ),
		'desc' => esc_html__( 'Check the logo version.', 'yaga' ),
		'id'   => $prefix . 'choose_logo',
		'type' => 'select',
		'options' => $logo_options,
	);

	$preloader = array(
		'name' => esc_html__( 'Page Preloader', 'yaga' ),
		'desc' => esc_html__( 'Check here to use a page preloader.', 'yaga' ),
		'id'   => $prefix . 'page_preloader',
		'type' => 'checkbox',
	);	

	$display_preloader_metabox = in_array( get_theme_mod( 'yaga_preloader_in', 'on_check_and_archives' ), array( 'on_check', 'on_check_and_archives' ) );

	$skip_elements_single = $skip_elements_page = array(
		'name' => esc_html__( 'Skip Elements', 'yaga' ),
		'desc' => esc_html__( 'Check the items that you do not want to display.', 'yaga' ),
		'id'   => $prefix . 'post_skip_elements',
		'type' => 'multicheck',
		'inline' => true,
	);

	$skip_elements_single['options'] = array(
		'header' => esc_html__( 'Header', 'yaga' ),
		'featured' => esc_html__( 'Featured Image', 'yaga' ),
		'author' => esc_html__( 'Author\'s bio', 'yaga' ),
		'taxonomies' => esc_html__( 'Taxonomies', 'yaga' ),
		'sidebar' => esc_html__( 'Sidebar', 'yaga' ),
		'related' => esc_html__( 'Related articles slider', 'yaga' ),
	);

	$skip_elements_page['options'] = array(
		'header' => esc_html__( 'Header', 'yaga' ),
		'sidebar' => esc_html__( 'Sidebar', 'yaga' )
	);

	if ( in_array( PeHaaThemes_Theme_Config::$navigation, array( 'sticky_center', 'sticky_full' ) ) ) {
		$skip_elements_page['options']['navigation'] = $skip_elements_single['options']['navigation'] = esc_html__( 'Navigation when page not scrolled', 'yaga' );
		$skip_elements_page['options']['title'] = $skip_elements_single['options']['title'] = esc_html__( 'Logo/title area', 'yaga' );
		$skip_elements_page['desc'] .=  ' ' . esc_html__( 'The "Logo/title area" and "Navigation when page not scrolled" apply only if the sticky navigation is chosen.', 'yaga' );
	}

	$cmb_post = new_cmb2_box( array(
		'id'            => $prefix . 'single_settings',
		'title'         => sprintf( esc_html__( '%s Custom Settings', 'yaga' ), PeHaaThemes_Theme_Start::$theme_name ),
		'object_types'  => $yaga_metabox_post_types_slugs,
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true,
	) );

	$cmb_page = new_cmb2_box( array(
		'id'            => $prefix . 'page_settings',
		'title'         => sprintf( esc_html__( '%s Custom Settings', 'yaga' ), PeHaaThemes_Theme_Start::$theme_name ),
		'object_types'  => array( 'page' ),
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true,
	) );

	$cmb_post_header = new_cmb2_box( array(
		'id'            => $prefix . 'post_header_settings',
		'title'         => sprintf( esc_html__( '%s Post Header Settings', 'yaga' ), PeHaaThemes_Theme_Start::$theme_name ),
		'object_types'  => array( 'post' ),
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true,
	) );

	$post_header_check = array(
		'name' => esc_html__( 'Image in Background', 'yaga' ),
		'desc' => esc_html__( 'Check here enable the featured image as your post header background.', 'yaga' ),
		'id'   => $prefix . 'post_header_checked',
		'type' => 'select',
		'default' => 'none',
		'options' => array(
			'none' => esc_html__( 'No image', 'yaga' ),
			'yes' => esc_html__( 'Use featured image on large screens ( > 800px)', 'yaga' ),
			'yes_all' => esc_html__( 'Use featured image on all screens', 'yaga' )
		)
	);

	$post_header_bg_opacity = array(
		'name' => esc_html__( 'Header Image Opacity', 'yaga' ),
		'id'   => $prefix . 'post_header_opacity',
		'type' => 'select',
		'options' => array(
			'1' => '100%',
				'0.95' => '95%',
				'0.9' => '90%',
				'0.85' => '85%',
				'0.80' => '80%',
				'0.75' => '75%',
				'0.7' => '70%',
				'0.6' => '60%',
				'0.5' => '50%',
				'0.4' => '40%',
				'0.3' => '30%',
				'0.25' => '25%',
				'0.2' => '20%',
				'0.15' => '15%',
				'0.1' => '10%',
				'0.05' => '5%',
		)
	);

	$post_header_bg_color = array(
		'name'    => esc_html__( 'Post Header Background Color', 'yaga' ),
		'id'      => $prefix . 'post_header_bg_color',
		'type'    => 'colorpicker',
		'default' => '#ffffff',
	);

	$cmb_post_header->add_field( $post_header_check );
	$cmb_post_header->add_field( $post_header_bg_opacity );
	$cmb_post_header->add_field( $post_header_bg_color );

	if ( $add_colors_choice_metabox ) {
		$cmb_page->add_field( $site_header_color );
	}
	
	if ( $add_colors_choice_metabox ) {
		$site_header_color['description'] = sprintf( esc_html__( 'Define the colors for the navigation bar and the title/tagline. The same settings will be applied to the post header if the Image in Background is enabled (see %s Post Header Settings).', 'yaga' ),  PeHaaThemes_Theme_Start::$theme_name );
		$cmb_post->add_field( $site_header_color );
	}
	if ( $add_logo_choice_metabox ) {
		$cmb_post->add_field( $site_header_choose_logo );
		$cmb_page->add_field( $site_header_choose_logo );
	}

	if ( $display_preloader_metabox ) {
		$cmb_post->add_field( $preloader );
		$cmb_page->add_field( $preloader );
	}

	$cmb_post->add_field( $skip_elements_single );
	$cmb_page->add_field( $skip_elements_page );

}
endif;