<?php
/**
 *
 * @package   PeHaa Themes Library
 * @author    PeHaa THEMES <info@pehaa.com>
 * @license   GPL-2.0+
 * @copyright 2015 PeHaa THEMES
 */

/**
 *
 * @package PeHaa Themes Library
 * @author  PeHaa THEMES <info@pehaa.com>
 */

if ( !class_exists( 'PeHaaThemes_Theme_Start' ) ) :
	
class PeHaaThemes_Theme_Start {

	private static $instance = null;

	public static $theme_name;

	public static $theme_slug;

	public static $theme_version;

	public static $theme_author;

	public static $theme_author_uri;

	public static $theme_textdomain;

	public static $mb_prefix;

	public static $single_items;

	private $theme_supports;

	public static $body_font;

  	public static $headings_font;

  	public static $body_normal_weight; 

	public static $body_bold_weight; 

	public static $headings_weight;

	public static $uses_PHTPB = false;

	public static $post_types_with_PHTPB = array();

	private function __construct() {

		$this->theme_data();

		if ( ! $this->check_WP_compatibility() ) {
			return;
		}

		$this->load_textdomain();

		$this->theme_metaboxes();

		$this->remove_WP_version();

		$this->remove_inline_styles();

		$this->check_page_title();

		$this->admin_footer();

		$this->login_screen();

		$this->remove_postcustom_meta_boxes();

		$this->documentation_page();

		$this->content_filters();

		$this->load_library_classes();

		if ( class_exists( 'PeHaaThemes_Theme_Config' ) ) {

			$this->theme_config = PeHaaThemes_Theme_Config::get_instance();

			$this->theme_supports();

			$this->theme_filter_hooks();

			$this->wp_head_hooks();

			$this->nice_excerpts();

			$this->add_tiled_gallery();
		
			$this->set_fonts();

			$this->load_theme_styles_action();

			$this->load_theme_scripts_action();

		}
		
		add_action( 'customize_preview_init', array( $this, 'refresh_for_preview' ), 11 );

		self::$uses_PHTPB = class_exists( 'PeHaa_Themes_Page_Builder' );

		if ( self::$uses_PHTPB ) {
			self::$post_types_with_PHTPB = PeHaa_Themes_Page_Builder::$phtpb_post_types;
		}

		self::$single_items = $this->add_spt();

		do_action( 'pehaathemes_theme_started' );

	}

	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self();
		}
		return self::$instance;

	}

	private function set_fonts() {

		self::$body_font = pehaathemes_get_theme_mod_not_empty( 'yaga_body_font_face', PeHaaThemes_Theme_Config::$body_font );
		self::$headings_font = pehaathemes_get_theme_mod_not_empty( 'yaga_headings_font_face', PeHaaThemes_Theme_Config::$headings_font );
		self::$body_normal_weight = get_theme_mod( 'yaga_body_normal_font_face_weight', PeHaaThemes_Theme_Config::$body_normal_weight );
		self::$body_bold_weight = get_theme_mod( 'yaga_body_bold_font_face_weight', PeHaaThemes_Theme_Config::$body_bold_weight );
		self::$headings_weight = $this->heading_weight = get_theme_mod( 'yaga_headings_font_face_weight', PeHaaThemes_Theme_Config::$headings_weight );

	}

	public function refresh_for_preview() {

		$this->set_fonts();
	}

	private function check_WP_compatibility() {

		if ( version_compare( $GLOBALS['wp_version'], PEHAATHEMES_THEME_WP_VERSION_REQUIRED, '<' ) ) {
			require_once( PEHAATHEMES_LIBRARY_DIR . '/classes/class-pht-back-compat.php');
			new PeHaaThemes_Back_Compat( $this->theme_name, PEHAATHEMES_THEME_WP_VERSION_REQUIRED );
			return false;
		}
		return true;

	}

	private function load_library_classes() {

		require_once( PEHAATHEMES_LIBRARY_DIR . '/classes/class-pht-resize-image.php' );
		require_once( PEHAATHEMES_LIBRARY_DIR . '/classes/class-pht-widget-areas.php' );
		require_once( PEHAATHEMES_LIBRARY_DIR . '/classes/class-pht-sanitization.php' );
	
	}

	private function remove_WP_version() {

		add_action( 'init', array( $this, 'head_cleanup' ) );
		
	}

	private function remove_inline_styles() {

		add_action( 'wp_head', array( $this, 'remove_recent_comments_style' ), 1 );
		add_filter( 'use_default_gallery_style', '__return_false' );

	}

	private function admin_footer() {

		add_filter( 'admin_footer_text', array( $this, 'custom_admin_footer' ) );
		
	}

	private function theme_data() {
		
		$this->get_my_theme_data();

	}

	private function load_textdomain() {

		add_action( 'after_setup_theme', array( $this, 'load_theme_textdomain' ) );
	
	}

		public function load_theme_textdomain() {

		$languages_dir = '/languages';

		if ( class_exists( 'PeHaaThemes_Theme_Config' ) && isset( PeHaaThemes_Theme_Config::$languages_dir ) ) {
			$languages_dir = PeHaaThemes_Theme_Config::$languages_dir;
		}

		$loaded = load_theme_textdomain ( self::$theme_textdomain, get_stylesheet_directory() . $languages_dir );
		
		if ( !$loaded ) {
			add_filter( 'theme_locale', array( $this, 'change_locale' ), 10, 2 );
			$loaded = load_theme_textdomain ( self::$theme_textdomain, get_stylesheet_directory() . $languages_dir );

		}

		if ( !$loaded ) {
			remove_filter( 'theme_locale', array( $this, 'change_locale' ), 10, 2 );
			$loaded = load_theme_textdomain ( self::$theme_textdomain, get_template_directory() . $languages_dir );
			if ( !$loaded ) {
				add_filter( 'theme_locale', array( $this, 'change_locale' ), 10, 2 );
				$loaded = load_theme_textdomain ( self::$theme_textdomain, get_stylesheet_directory() . $languages_dir );

			}

		}

	}

	public function change_locale( $locale, $domain ) {
		return $domain . '-' . $locale;
	}


	public function theme_supports() {

		add_action( 'after_setup_theme', array( $this, 'add_theme_supports' ) );

	}

	public function add_theme_supports() {

		foreach ( $this->theme_config->get_theme_supports() as $support ) {

			if ( !isset( $support['feature'] ) ) {
				continue;
			}

			if ( isset( $support['args'] ) ) {
				add_theme_support( $support['feature'], $support['args'] ); 
			} else {
				add_theme_support( $support['feature'] );
			}

		}
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
	}

	public function get_my_theme_data() {

		if ( !function_exists( 'wp_get_theme' ) ) {
			return;
		}

		if ( is_child_theme() ) {
			$temp_obj = wp_get_theme();
			$theme_obj = wp_get_theme( $temp_obj->get( 'Template' ) );
		} else {
			$theme_obj = wp_get_theme();
		}

		self::$theme_name = $theme_obj->get( 'Name' );
		self::$theme_slug = preg_replace( "/\W/", "_", strtolower( self::$theme_name ) );
		self::$theme_version = $theme_obj->get( 'Version' );
		self::$theme_author = $theme_obj->get( 'Author' );
		self::$theme_author_uri = $theme_obj->get( 'AuthorURI' );
		self::$theme_textdomain = $theme_obj->get( 'TextDomain' );

	}

	private function theme_metaboxes() {

		self::$mb_prefix = '_' . self::$theme_slug . '_';

	}

	public function custom_admin_footer() {
	
		echo '<span id="footer-thankyou">';
		printf( esc_html__( 'WordPress Theme Developed by %s', 'yaga' ), '<a href="' . esc_url( self::$theme_author_uri ) .'" target="_blank">' . self::$theme_author . '</a>' );
		echo '</span>';

	}

	private function check_page_title() {

		if ( function_exists( '_wp_render_title_tag' ) ) {
			return;
		}
		add_action( 'wp_head', array( $this, 'render_title' ) );
		add_filter( 'wp_title', array( $this, 'page_title' ), 10, 2 );
	}

	public function render_title() { ?>

		<title><?php wp_title( '|', true, 'right' ); ?></title>
	
	<?php }

	public function page_title ( $title, $sep ) {
	
		global $paged, $page;

		if ( is_feed() ) {
			return $title;
		}

		$title .= esc_attr( get_bloginfo( 'name' ) );

		$site_description = esc_attr( get_bloginfo( 'description', 'display' ) );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title = "$title $sep $site_description";
		}

		if ( $paged >= 2 || $page >= 2 ) {
			$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'yaga' ), max( $paged, $page ) );
		}

		return $title;
	}
	

	public function head_cleanup() {
	
		remove_action( 'wp_head', 'rsd_link' );
		remove_action( 'wp_head', 'wlwmanifest_link' );
		remove_action( 'wp_head', 'index_rel_link' );
		remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
		remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
		remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
		remove_action( 'wp_head', 'wp_generator' );
		//add_filter( 'style_loader_src', array( $this, 'remove_wp_ver_css_js' ), 9999 );
		//add_filter( 'script_loader_src', array( $this, 'remove_wp_ver_css_js' ), 9999 );

	}

	public function remove_wp_ver_css_js( $src ) {
		
		if ( strpos( $src, 'ver=' ) ) {
			$src = remove_query_arg( 'ver', $src );
		}
			
		return $src;
	}

	public function remove_recent_comments_style() {
	
		global $wp_widget_factory;

		if ( isset( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'] ) ) {
			remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
		}
	}

	private function login_screen() {

		add_filter( 'login_headerurl', array( $this, 'login_url' ) );
		add_filter( 'login_headertitle', array( $this, 'login_title' ) );
		add_action( 'login_enqueue_scripts', array( $this, 'login_css' ), 10 );
	}

	public function login_url() {  
		return esc_url( home_url( '/' ) ); 
	}


	public function login_title() { 
		return get_option( 'blogname' ); 
	}

	public function login_css() {

		wp_enqueue_style( 'pehaathemes_login_css', apply_filters( 'pehaathemes_login_styles_uri', get_template_directory_uri() . '/css/login.css' ) );
		
		$this->login_inline_style();
		
	}

	private function login_inline_style() {

		$user_logo_id = get_theme_mod( self::$theme_slug . '_login_logo_id' );

		if ( $user_logo_id ) {
			
			$att_src = wp_get_attachment_image_src( $user_logo_id, 'full' );

			if ( $att_src ) {

				$logo_url = $att_src[0];

			}	
		} elseif ( isset( PeHaaThemes_Theme_Config::$user_logo ) ) {

			$logo_url = PeHaaThemes_Theme_Config::$user_logo;

			if ( $logo_url && is_ssl() ) {
				$logo_url = preg_replace( "/^http:/i", "https:", $logo_url );
			}
		}
		if ( !empty( $logo_url ) ) {
			wp_add_inline_style( 'pehaathemes_login_css', '.login h1 a {background-image:url(' . esc_url( $logo_url ) . ');}' );
		}
	}

	private function content_filters() {

		add_filter( 'the_content', array( $this, 'remove_p_tags_around_img') );

	}

	
	public function remove_p_tags_around_img( $content ) {
		/* http://css-tricks.com/snippets/wordpress/remove-paragraph-tags-from-around-images/ */
		return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);

	}

	private function documentation_page() {
		add_action( 'admin_menu', array( $this, 'add_documentation_link' ) );
	}

	public function add_documentation_link() {

		if ( !isset( PeHaaThemes_Theme_Config::$documentation_link ) ) {
			return;
		}

		add_theme_page( __( 'Documentation', 'yaga' ), __( 'Documentation', 'yaga' ), 'manage_options', 'documentation', array( $this, 'redirect_for_documentation' ) ); 
	}

	public function redirect_for_documentation() { ?>
		<script type="text/javascript">
			//<![CDATA[
			window.location.replace( "<?php echo esc_url( PeHaaThemes_Theme_Config::$documentation_link ); ?>" );
			//]]>
		</script>
	<?php }



	private function nice_excerpts() {
		if ( !isset( $this->theme_config->nice_excerpts ) || !$this->theme_config->nice_excerpts ) {
			return;
		}
		add_filter( 'excerpt_more', '__return_empty_string' );
	}

	private function remove_postcustom_meta_boxes() {

		add_action( 'admin_menu', array( $this, 'remove_meta_boxes' ) );

	}

	public function remove_meta_boxes() {

		remove_meta_box('postcustom', 'post', 'normal');
		remove_meta_box('postcustom', 'page', 'normal');

	}

	private function add_tiled_gallery() {
		
		if ( !isset( $this->theme_config->tiled_gallery ) || !$this->theme_config->tiled_gallery ) {
			return;
		}
		require_once( PEHAATHEMES_LIBRARY_DIR . '/classes/class-pht-tiled-gallery.php' );
		if (  isset( PeHaaThemes_Theme_Config::$override_post_gallery ) && PeHaaThemes_Theme_Config::$override_post_gallery ) {
			add_action( 'init', array( 'PeHaaThemes_Tiled_Gallery', 'init' ) );
		}
		
	}
	
	private function wp_head_hooks() {}

	private function theme_filter_hooks() {

		if ( !class_exists( 'PeHaaThemes_Theme_Config' ) ) {
			return;
		}

		if ( !property_exists( 'PeHaaThemes_Theme_Config', 'theme_filter_hooks' ) ) {
			return;
		}

		foreach ( (array) PeHaaThemes_Theme_Config::$theme_filter_hooks as $filter_hook ) {

			if ( isset( $filter_hook['method'] ) && method_exists( 'PeHaaThemes_Theme_Config', $filter_hook['method'] ) ) {

				$priority = isset( $filter_hook['priority'] ) ? $filter_hook['priority'] : 10;

				$args = isset( $filter_hook['args'] ) ? $filter_hook['args'] : 1;
				
				add_filter( $filter_hook['hook'], array( 'PeHaaThemes_Theme_Config', $filter_hook['method'] ), $priority, $args );
			}
		}	
	}



	private function load_theme_styles_action() {
		add_action( 'wp_enqueue_scripts', array( $this, 'load_theme_styles' ) );
	}

	private function load_theme_scripts_action() {
		add_action( 'wp_enqueue_scripts', array( $this, 'load_theme_scripts' ) );
	}

	public function load_theme_styles() {

		$deps = (array) PeHaaThemes_Theme_Config::$public_style_deps;

		if ( PeHaaThemes_Theme_Config::$use_google_fonts ) {
			
			wp_register_style( 'pehaathemes-fonts', $this->fonts_url() );

			$deps[] = 'pehaathemes-fonts';
		}

		$main_stylesheet = apply_filters( 'pehaathemes_main_stylesheet', 'style' );
	
		if ( apply_filters( 'pehaathemes_load_template_css', is_child_theme() ) ) {
			wp_enqueue_style( 'pehaathemes-t-style', get_template_directory_uri(). '/css/' . $main_stylesheet . '.css', $deps, self::$theme_version, 'all' );
			$deps[] = 'pehaathemes-t-style';
		}
		if ( apply_filters( 'pehaathemes_load_stylesheet_css', true ) ) {
			if ( is_child_theme() ) {
				wp_enqueue_style( 'pehaathemes-s-style', get_stylesheet_directory_uri() .'/css/style.css', $deps, self::$theme_version, 'all' );
			} else {
				wp_enqueue_style( 'pehaathemes-s-style', get_stylesheet_directory_uri() .'/css/' . $main_stylesheet . '.css', $deps, self::$theme_version, 'all' );
			}		
		}		

	}

	public function load_theme_scripts() {

	}

	private function fonts_url() {

		$font_families = array();

		$font_families[] = self::$body_font .':'. self::$body_normal_weight . 'italic,'. self::$body_bold_weight .'italic,' . self::$body_normal_weight . ',' . self::$body_bold_weight;
		$font_families[] = self::$headings_font . ':' . self::$headings_weight;

		$fonts_query_args = array( 'family' => urlencode( implode( '|', array_filter( $font_families ) ) ) );

		$fonts_query_args['subset'] = apply_filters( 'yaga_fonts_subset', 'latin' );

		$protocol = is_ssl() ? 'https:' : 'http:';

		$fonts_url = add_query_arg( $fonts_query_args, "$protocol//fonts.googleapis.com/css" );

		return $fonts_url;

	}

	private function add_spt() {
		
		if ( class_exists( 'PeHaaThemes_Simple_Post_Types' ) ) {

			return array_merge( PeHaaThemes_Theme_Config::$single_items, PeHaaThemes_Simple_Post_Types::$post_type_slugs );
		}

		if ( class_exists( 'PeHaaThemes_Theme_Config' ) ) {
			return PeHaaThemes_Theme_Config::$single_items;
		}

		return array( 'post' );
	}

} 
endif;

PeHaaThemes_Theme_Start::get_instance();