<?php
/**
 *
 * @package   Yaga
 * @author    PeHaa THEMES <info@pehaa.com>
 */
if ( ! function_exists( 'pehaathemes_hex2rgb' ) ) :
function pehaathemes_hex2rgb( $colour ) {
	if ( $colour[0] == '#' ) {
		$colour = substr( $colour, 1 );
	}
	if ( strlen( $colour ) == 6 ) {
		list( $r, $g, $b ) = array( $colour[0] . $colour[1], $colour[2] . $colour[3], $colour[4] . $colour[5] );
	} elseif ( strlen( $colour ) == 3 ) {
		list( $r, $g, $b ) = array( $colour[0] . $colour[0], $colour[1] . $colour[1], $colour[2] . $colour[2] );
	} else {
		return false;
	}
	$r = hexdec( $r );
	$g = hexdec( $g );
	$b = hexdec( $b );
	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}
endif;

if ( ! function_exists( 'pehaathemes_rgba' ) ) :
function pehaathemes_rgba( $colour, $opacity = 1 ) {
	
	$hex2rgb = pehaathemes_hex2rgb( $colour );
	if ( $hex2rgb ) {
		$r = $hex2rgb['red'];
		$g = $hex2rgb['green'];
		$b = $hex2rgb['blue'];
		return "rgba( $r, $g, $b, $opacity )";
	}
	return;
}
endif;

if ( ! function_exists( 'pehaathemes_image_alt' ) ) :
function pehaathemes_image_alt( $id ) {

	if ( !$id ) {
		return;
	}

	if ( !wp_attachment_is_image( $id ) ) {
		return;
	}

	$alt = trim( strip_tags( get_post_meta( $id, '_wp_attachment_image_alt', true ) ) ); 
	if ( !$alt ) {
		$attachment = get_post( $id );
		$alt = trim( strip_tags( $attachment->post_excerpt ) );
	}
	if ( !$alt ) {
		$alt = trim( strip_tags( $attachment->post_title ) );
	}

	return $alt;

}
endif;

if ( !function_exists( 'pehaathemes_get_att_img' ) ) :
/**
 * Get an HTML img element representing an image attachment
 *
 * While `$size` will accept an array, it is better to register a size with
 * add_image_size() so that a cropped version is generated. It's much more
 * efficient than having to find the closest-sized image and then having the
 * browser scale down the image.
 *
 * @since 2.5.0
 *
 * @param int          $attachment_id Image attachment ID.
 * @param string|array $size          
 * @param bool         $icon          Optional. Whether the image should be treated as an icon. Default false.
 * @param string|array $attr          Optional. Attributes for the image markup. Default empty.
 * @return string HTML img element or empty string on failure.
 */
function pehaathemes_get_att_img( $attachment_id, $size, $icon = false, $attr = '', $skip_mime_types = array() ) {
	
	$html = '';

	if ( !class_exists( 'PeHaaThemes_Resize_Image' ) ) {
		return; 
	}
	if ( !is_array( $size ) ) {
		
		$resized = wp_get_attachment_image_src( $attachment_id, $size );

		if ( !$resized ) {
			return;
		}
		$img = array();
		$img['1x']['url'] = $resized[0];
		$img['1x']['width'] = $resized[1];
		$img['1x']['height'] = $resized[2];
	} else {
		list( $width, $height ) = $size;
		$resizer = PeHaaThemes_Resize_Image::get_instance();
		$img = $resizer->resize_image_srcset( $attachment_id, intval( $width ),  intval( $height ), $skip_mime_types );
	}
	

	if ( isset( $img['1x']['url'] ) && isset( $img['1x']['width'] ) && isset( $img['1x']['height'] ) ) {
		$default_attr = array(
			'src'	=> $img['1x']['url'],
			'class'	=> '',
			'alt'	=> pehaathemes_image_alt( $attachment_id )
		);
		if (  isset( $img['2x']['url'] ) && isset( $img['2x']['url'] ) && $img['2x']['url'] ) {
			$default_attr['srcset'] = $img['1x']['url'] .' 1x, ' . $img['2x']['url'] . ' 2x';
		}
		$attr = wp_parse_args( $attr, $default_attr );
		$attr = array_map( 'esc_attr', $attr );
		$html = '<img ';
		foreach ( $attr as $name => $value ) {
			$html .= " $name=" . '"' . $value . '"';
		}
		$html .= ' />';
	}

	return $html;
}
endif;

if ( !function_exists( 'pehaathemes_get_post_thumb' ) ) :
/**
 * Get an HTML img element representing an image attachment
 *
 * While `$size` will accept an array, it is better to register a size with
 * add_image_size() so that a cropped version is generated. It's much more
 * efficient than having to find the closest-sized image and then having the
 * browser scale down the image.
 *
 * @since 2.5.0
 *
 * @param int          $attachment_id Image attachment ID.
 * @param string|array $size          
 * @param bool         $icon          Optional. Whether the image should be treated as an icon. Default false.
 * @param string|array $attr          Optional. Attributes for the image markup. Default empty.
 * @return string HTML img element or empty string on failure.
 */
function pehaathemes_get_post_thumb( $post_id = null, $size, $icon = false, $attr = '' ) {

	$post_id = ( null === $post_id ) ? get_the_ID() : $post_id;
	$post_thumbnail_id = get_post_thumbnail_id( $post_id );
	
	$html = '';
	
	if ( $post_thumbnail_id ) {

		$html = pehaathemes_get_att_img( $post_thumbnail_id, $size, false, $attr );

	} 

	return $html;
}
endif;

if ( !function_exists( 'pehaathemes_get_theme_mod_not_empty' ) ) :
function pehaathemes_get_theme_mod_not_empty( $name, $default = false ) {

	$return = get_theme_mod( $name, $default );
	if ( '' === $return ) {
		return $default;
	}
	return $return;
}
endif;